@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import AcceleratorTypesTransport, DEFAULT_CLIENT_INFO
 
 
@@ -52,7 +46,7 @@ class AcceleratorTypesRestTransport(AcceleratorTypesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -62,7 +56,8 @@ class AcceleratorTypesRestTransport(AcceleratorTypesTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -79,20 +74,25 @@ class AcceleratorTypesRestTransport(AcceleratorTypesTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def aggregated_list(
         self,
@@ -104,8 +104,7 @@ class AcceleratorTypesRestTransport(AcceleratorTypesTransport):
 
         Args:
             request (~.compute.AggregatedListAcceleratorTypesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 AcceleratorTypes.AggregatedList. See the
                 method description for details.
 
@@ -125,30 +124,39 @@ class AcceleratorTypesRestTransport(AcceleratorTypesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListAcceleratorTypesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.AggregatedListAcceleratorTypesRequest.include_all_scopes in request:
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListAcceleratorTypesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListAcceleratorTypesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListAcceleratorTypesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if (
+            compute.AggregatedListAcceleratorTypesRequest.return_partial_success
+            in request
+        ):
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.AcceleratorTypeAggregatedList.from_json(response.content)
+        return compute.AcceleratorTypeAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def get(
         self,
@@ -160,8 +168,7 @@ class AcceleratorTypesRestTransport(AcceleratorTypesTransport):
 
         Args:
             request (~.compute.GetAcceleratorTypeRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 AcceleratorTypes.Get. See the method
                 description for details.
 
@@ -193,22 +200,23 @@ class AcceleratorTypesRestTransport(AcceleratorTypesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.AcceleratorType.from_json(response.content)
+        return compute.AcceleratorType.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def list(
         self,
@@ -220,8 +228,7 @@ class AcceleratorTypesRestTransport(AcceleratorTypesTransport):
 
         Args:
             request (~.compute.ListAcceleratorTypesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 AcceleratorTypes.List. See the method
                 description for details.
 
@@ -241,29 +248,34 @@ class AcceleratorTypesRestTransport(AcceleratorTypesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListAcceleratorTypesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListAcceleratorTypesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListAcceleratorTypesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListAcceleratorTypesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListAcceleratorTypesRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.AcceleratorTypeList.from_json(response.content)
+        return compute.AcceleratorTypeList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
 
 __all__ = ("AcceleratorTypesRestTransport",)
