@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.addresses import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import AddressesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import AddressesRestTransport
 
@@ -213,7 +210,7 @@ class AddressesClient(metaclass=AddressesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, AddressesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -344,7 +341,6 @@ class AddressesClient(metaclass=AddressesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -374,10 +370,8 @@ class AddressesClient(metaclass=AddressesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListAddressesRequest):
             request = compute.AggregatedListAddressesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -432,7 +426,6 @@ class AddressesClient(metaclass=AddressesClientMeta):
                 This corresponds to the ``address`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -484,10 +477,8 @@ class AddressesClient(metaclass=AddressesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteAddressRequest):
             request = compute.DeleteAddressRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -539,7 +530,6 @@ class AddressesClient(metaclass=AddressesClientMeta):
                 This corresponds to the ``address`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -595,10 +585,8 @@ class AddressesClient(metaclass=AddressesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetAddressRequest):
             request = compute.GetAddressRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -650,7 +638,6 @@ class AddressesClient(metaclass=AddressesClientMeta):
                 This corresponds to the ``address_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -702,10 +689,8 @@ class AddressesClient(metaclass=AddressesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertAddressRequest):
             request = compute.InsertAddressRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -750,7 +735,6 @@ class AddressesClient(metaclass=AddressesClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -781,10 +765,8 @@ class AddressesClient(metaclass=AddressesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListAddressesRequest):
             request = compute.ListAddressesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
