@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.autoscalers import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import AutoscalersTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import AutoscalersRestTransport
 
@@ -213,7 +210,7 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, AutoscalersTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -344,7 +341,6 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -374,10 +370,8 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListAutoscalersRequest):
             request = compute.AggregatedListAutoscalersRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -430,7 +424,6 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
                 This corresponds to the ``autoscaler`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -482,10 +475,8 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteAutoscalerRequest):
             request = compute.DeleteAutoscalerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -537,7 +528,6 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
                 This corresponds to the ``autoscaler`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -584,10 +574,8 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetAutoscalerRequest):
             request = compute.GetAutoscalerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -639,7 +627,6 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
                 This corresponds to the ``autoscaler_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -691,10 +678,8 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertAutoscalerRequest):
             request = compute.InsertAutoscalerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -740,7 +725,6 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
                 This corresponds to the ``zone`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -772,10 +756,8 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListAutoscalersRequest):
             request = compute.ListAutoscalersRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -833,7 +815,6 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
                 This corresponds to the ``autoscaler_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -885,10 +866,8 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchAutoscalerRequest):
             request = compute.PatchAutoscalerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -940,7 +919,6 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
                 This corresponds to the ``autoscaler_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -992,10 +970,8 @@ class AutoscalersClient(metaclass=AutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateAutoscalerRequest):
             request = compute.UpdateAutoscalerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
