@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.backend_buckets import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import BackendBucketsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import BackendBucketsRestTransport
 
@@ -215,7 +212,7 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, BackendBucketsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -363,7 +360,6 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
                 This corresponds to the ``signed_url_key_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -415,10 +411,8 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AddSignedUrlKeyBackendBucketRequest):
             request = compute.AddSignedUrlKeyBackendBucketRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_bucket is not None:
@@ -465,7 +459,6 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
                 This corresponds to the ``backend_bucket`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -517,10 +510,8 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteBackendBucketRequest):
             request = compute.DeleteBackendBucketRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_bucket is not None:
@@ -576,7 +567,6 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
                 This corresponds to the ``key_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -628,10 +618,8 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteSignedUrlKeyBackendBucketRequest):
             request = compute.DeleteSignedUrlKeyBackendBucketRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_bucket is not None:
@@ -680,7 +668,6 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
                 This corresponds to the ``backend_bucket`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -713,10 +700,8 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetBackendBucketRequest):
             request = compute.GetBackendBucketRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_bucket is not None:
@@ -760,7 +745,6 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
                 This corresponds to the ``backend_bucket_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -812,10 +796,8 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertBackendBucketRequest):
             request = compute.InsertBackendBucketRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_bucket_resource is not None:
@@ -853,7 +835,6 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -885,10 +866,8 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListBackendBucketsRequest):
             request = compute.ListBackendBucketsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -946,7 +925,6 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
                 This corresponds to the ``backend_bucket_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -998,10 +976,8 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchBackendBucketRequest):
             request = compute.PatchBackendBucketRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_bucket is not None:
@@ -1055,7 +1031,6 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
                 This corresponds to the ``backend_bucket_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1107,10 +1082,8 @@ class BackendBucketsClient(metaclass=BackendBucketsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateBackendBucketRequest):
             request = compute.UpdateBackendBucketRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_bucket is not None:
