@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.backend_services import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import BackendServicesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import BackendServicesRestTransport
 
@@ -215,7 +212,7 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, BackendServicesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -363,7 +360,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``signed_url_key_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -415,10 +411,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AddSignedUrlKeyBackendServiceRequest):
             request = compute.AddSignedUrlKeyBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_service is not None:
@@ -460,7 +454,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -492,10 +485,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListBackendServicesRequest):
             request = compute.AggregatedListBackendServicesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -544,7 +535,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``backend_service`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -596,10 +586,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteBackendServiceRequest):
             request = compute.DeleteBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_service is not None:
@@ -655,7 +643,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``key_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -707,10 +694,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteSignedUrlKeyBackendServiceRequest):
             request = compute.DeleteSignedUrlKeyBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_service is not None:
@@ -758,7 +743,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``backend_service`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -807,10 +791,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetBackendServiceRequest):
             request = compute.GetBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_service is not None:
@@ -866,7 +848,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``resource_group_reference_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -895,10 +876,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetHealthBackendServiceRequest):
             request = compute.GetHealthBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_service is not None:
@@ -947,7 +926,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``backend_service_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -999,10 +977,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertBackendServiceRequest):
             request = compute.InsertBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_service_resource is not None:
@@ -1040,7 +1016,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1072,10 +1047,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListBackendServicesRequest):
             request = compute.ListBackendServicesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -1134,7 +1107,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``backend_service_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1186,10 +1158,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchBackendServiceRequest):
             request = compute.PatchBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_service is not None:
@@ -1244,7 +1214,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``security_policy_reference_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1298,10 +1267,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetSecurityPolicyBackendServiceRequest):
             request = compute.SetSecurityPolicyBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_service is not None:
@@ -1358,7 +1325,6 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
                 This corresponds to the ``backend_service_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1410,10 +1376,8 @@ class BackendServicesClient(metaclass=BackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateBackendServiceRequest):
             request = compute.UpdateBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if backend_service is not None:
