@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import BackendServicesTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class BackendServicesRestTransport(BackendServicesTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class BackendServicesRestTransport(BackendServicesTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def add_signed_url_key(
         self,
@@ -103,8 +103,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.AddSignedUrlKeyBackendServiceRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.AddSignedUrlKey. See the
                 method description for details.
 
@@ -161,15 +160,14 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.AddSignedUrlKeyBackendServiceRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -179,7 +177,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def aggregated_list(
         self,
@@ -191,8 +189,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.AggregatedListBackendServicesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.AggregatedList. See the
                 method description for details.
 
@@ -214,30 +211,39 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListBackendServicesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.AggregatedListBackendServicesRequest.include_all_scopes in request:
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListBackendServicesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListBackendServicesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListBackendServicesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if (
+            compute.AggregatedListBackendServicesRequest.return_partial_success
+            in request
+        ):
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.BackendServiceAggregatedList.from_json(response.content)
+        return compute.BackendServiceAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def delete(
         self,
@@ -249,8 +255,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.DeleteBackendServiceRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.Delete. See the method
                 description for details.
 
@@ -300,25 +305,24 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteBackendServiceRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def delete_signed_url_key(
         self,
@@ -330,8 +334,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.DeleteSignedUrlKeyBackendServiceRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.DeleteSignedUrlKey. See
                 the method description for details.
 
@@ -381,26 +384,26 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "keyName": request.key_name,
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if request.key_name:
+            query_params["keyName"] = request.key_name
+        if compute.DeleteSignedUrlKeyBackendServiceRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url)
+        response = self._session.post(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -412,8 +415,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.GetBackendServiceRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.Get. See the method
                 description for details.
 
@@ -458,22 +460,23 @@ class BackendServicesRestTransport(BackendServicesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.BackendService.from_json(response.content)
+        return compute.BackendService.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def get_health(
         self,
@@ -485,8 +488,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.GetHealthBackendServiceRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.GetHealth. See the
                 method description for details.
 
@@ -516,12 +518,11 @@ class BackendServicesRestTransport(BackendServicesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -531,7 +532,9 @@ class BackendServicesRestTransport(BackendServicesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.BackendServiceGroupHealth.from_json(response.content)
+        return compute.BackendServiceGroupHealth.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -543,8 +546,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.InsertBackendServiceRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.Insert. See the method
                 description for details.
 
@@ -599,15 +601,14 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertBackendServiceRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -617,7 +618,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -629,8 +630,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.ListBackendServicesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.List. See the method
                 description for details.
 
@@ -652,29 +652,34 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListBackendServicesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListBackendServicesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListBackendServicesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListBackendServicesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListBackendServicesRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.BackendServiceList.from_json(response.content)
+        return compute.BackendServiceList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def patch(
         self,
@@ -686,8 +691,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.PatchBackendServiceRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.Patch. See the method
                 description for details.
 
@@ -744,15 +748,14 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.PatchBackendServiceRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -762,7 +765,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_security_policy(
         self,
@@ -774,8 +777,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.SetSecurityPolicyBackendServiceRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.SetSecurityPolicy. See
                 the method description for details.
 
@@ -832,15 +834,14 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetSecurityPolicyBackendServiceRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -850,7 +851,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def update(
         self,
@@ -862,8 +863,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         Args:
             request (~.compute.UpdateBackendServiceRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 BackendServices.Update. See the method
                 description for details.
 
@@ -920,15 +920,14 @@ class BackendServicesRestTransport(BackendServicesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.UpdateBackendServiceRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -938,7 +937,7 @@ class BackendServicesRestTransport(BackendServicesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("BackendServicesRestTransport",)
