@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.disks import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import DisksTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import DisksRestTransport
 
@@ -213,7 +210,7 @@ class DisksClient(metaclass=DisksClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, DisksTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -366,7 +363,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``disks_add_resource_policies_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -420,10 +416,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AddResourcePoliciesDiskRequest):
             request = compute.AddResourcePoliciesDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -466,7 +460,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -496,10 +489,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListDisksRequest):
             request = compute.AggregatedListDisksRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -562,7 +553,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``snapshot_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -614,10 +604,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.CreateSnapshotDiskRequest):
             request = compute.CreateSnapshotDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -677,7 +665,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``disk`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -729,10 +716,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteDiskRequest):
             request = compute.DeleteDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -787,7 +772,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``disk`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -836,10 +820,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetDiskRequest):
             request = compute.GetDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -895,7 +877,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -973,10 +954,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicyDiskRequest):
             request = compute.GetIamPolicyDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1034,7 +1013,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``disk_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1086,10 +1064,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertDiskRequest):
             request = compute.InsertDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1136,7 +1112,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``zone`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1167,10 +1142,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListDisksRequest):
             request = compute.ListDisksRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1233,7 +1206,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``disks_remove_resource_policies_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1287,10 +1259,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.RemoveResourcePoliciesDiskRequest):
             request = compute.RemoveResourcePoliciesDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1353,7 +1323,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``disks_resize_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1405,10 +1374,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ResizeDiskRequest):
             request = compute.ResizeDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1472,7 +1439,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``zone_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1552,10 +1518,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicyDiskRequest):
             request = compute.SetIamPolicyDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1620,7 +1584,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``zone_set_labels_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1674,10 +1637,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetLabelsDiskRequest):
             request = compute.SetLabelsDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1743,7 +1704,6 @@ class DisksClient(metaclass=DisksClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1772,10 +1732,8 @@ class DisksClient(metaclass=DisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsDiskRequest):
             request = compute.TestIamPermissionsDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
