@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import DisksTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class DisksRestTransport(DisksTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class DisksRestTransport(DisksTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class DisksRestTransport(DisksTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def add_resource_policies(
         self,
@@ -103,8 +103,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.AddResourcePoliciesDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Disks.AddResourcePolicies. See the
                 method description for details.
 
@@ -162,15 +161,14 @@ class DisksRestTransport(DisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.AddResourcePoliciesDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -180,7 +178,7 @@ class DisksRestTransport(DisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def aggregated_list(
         self,
@@ -192,8 +190,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.AggregatedListDisksRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Disks.AggregatedList. See the method
                 description for details.
 
@@ -213,30 +210,36 @@ class DisksRestTransport(DisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListDisksRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.AggregatedListDisksRequest.include_all_scopes in request:
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListDisksRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListDisksRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListDisksRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.AggregatedListDisksRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.DiskAggregatedList.from_json(response.content)
+        return compute.DiskAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def create_snapshot(
         self,
@@ -248,8 +251,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.CreateSnapshotDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Disks.CreateSnapshot. See the method
                 description for details.
 
@@ -307,16 +309,16 @@ class DisksRestTransport(DisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "guestFlush": request.guest_flush,
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.CreateSnapshotDiskRequest.guest_flush in request:
+            query_params["guestFlush"] = request.guest_flush
+        if compute.CreateSnapshotDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -326,7 +328,7 @@ class DisksRestTransport(DisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def delete(
         self,
@@ -338,8 +340,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.DeleteDiskRequest):
-                The request object.
-                A request message for Disks.Delete.
+                The request object. A request message for Disks.Delete.
                 See the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -389,25 +390,24 @@ class DisksRestTransport(DisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -419,8 +419,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.GetDiskRequest):
-                The request object.
-                A request message for Disks.Get. See
+                The request object. A request message for Disks.Get. See
                 the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -463,22 +462,21 @@ class DisksRestTransport(DisksTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Disk.from_json(response.content)
+        return compute.Disk.from_json(response.content, ignore_unknown_fields=True)
 
     def get_iam_policy(
         self,
@@ -490,8 +488,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.GetIamPolicyDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Disks.GetIamPolicy. See the method
                 description for details.
 
@@ -564,25 +561,26 @@ class DisksRestTransport(DisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "optionsRequestedPolicyVersion": request.options_requested_policy_version,
-        }
+        query_params = {}
+        if compute.GetIamPolicyDiskRequest.options_requested_policy_version in request:
+            query_params[
+                "optionsRequestedPolicyVersion"
+            ] = request.options_requested_policy_version
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def insert(
         self,
@@ -594,8 +592,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.InsertDiskRequest):
-                The request object.
-                A request message for Disks.Insert.
+                The request object. A request message for Disks.Insert.
                 See the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -649,16 +646,16 @@ class DisksRestTransport(DisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-            "sourceImage": request.source_image,
-        }
+        query_params = {}
+        if compute.InsertDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+        if compute.InsertDiskRequest.source_image in request:
+            query_params["sourceImage"] = request.source_image
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -668,7 +665,7 @@ class DisksRestTransport(DisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -680,8 +677,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.ListDisksRequest):
-                The request object.
-                A request message for Disks.List. See
+                The request object. A request message for Disks.List. See
                 the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -700,29 +696,32 @@ class DisksRestTransport(DisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListDisksRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListDisksRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListDisksRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListDisksRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListDisksRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.DiskList.from_json(response.content)
+        return compute.DiskList.from_json(response.content, ignore_unknown_fields=True)
 
     def remove_resource_policies(
         self,
@@ -734,8 +733,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.RemoveResourcePoliciesDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Disks.RemoveResourcePolicies. See the
                 method description for details.
 
@@ -793,15 +791,14 @@ class DisksRestTransport(DisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.RemoveResourcePoliciesDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -811,7 +808,7 @@ class DisksRestTransport(DisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def resize(
         self,
@@ -823,8 +820,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.ResizeDiskRequest):
-                The request object.
-                A request message for Disks.Resize.
+                The request object. A request message for Disks.Resize.
                 See the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -881,15 +877,14 @@ class DisksRestTransport(DisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.ResizeDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -899,7 +894,7 @@ class DisksRestTransport(DisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_iam_policy(
         self,
@@ -911,8 +906,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.SetIamPolicyDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Disks.SetIamPolicy. See the method
                 description for details.
 
@@ -993,12 +987,11 @@ class DisksRestTransport(DisksTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -1008,7 +1001,7 @@ class DisksRestTransport(DisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def set_labels(
         self,
@@ -1020,8 +1013,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.SetLabelsDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Disks.SetLabels. See the method
                 description for details.
 
@@ -1079,15 +1071,14 @@ class DisksRestTransport(DisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetLabelsDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -1097,7 +1088,7 @@ class DisksRestTransport(DisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def test_iam_permissions(
         self,
@@ -1109,8 +1100,7 @@ class DisksRestTransport(DisksTransport):
 
         Args:
             request (~.compute.TestIamPermissionsDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Disks.TestIamPermissions. See the method
                 description for details.
 
@@ -1141,12 +1131,11 @@ class DisksRestTransport(DisksTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -1156,7 +1145,9 @@ class DisksRestTransport(DisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.TestPermissionsResponse.from_json(response.content)
+        return compute.TestPermissionsResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
 
 __all__ = ("DisksRestTransport",)
