@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.firewalls import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import FirewallsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import FirewallsRestTransport
 
@@ -213,7 +210,7 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, FirewallsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -350,7 +347,6 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
                 This corresponds to the ``firewall`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -402,10 +398,8 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteFirewallRequest):
             request = compute.DeleteFirewallRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if firewall is not None:
@@ -447,7 +441,6 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
                 This corresponds to the ``firewall`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -479,10 +472,8 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetFirewallRequest):
             request = compute.GetFirewallRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if firewall is not None:
@@ -526,7 +517,6 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
                 This corresponds to the ``firewall_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -578,10 +568,8 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertFirewallRequest):
             request = compute.InsertFirewallRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if firewall_resource is not None:
@@ -618,7 +606,6 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -649,10 +636,8 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListFirewallsRequest):
             request = compute.ListFirewallsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -707,7 +692,6 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
                 This corresponds to the ``firewall_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -759,10 +743,8 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchFirewallRequest):
             request = compute.PatchFirewallRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if firewall is not None:
@@ -817,7 +799,6 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
                 This corresponds to the ``firewall_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -869,10 +850,8 @@ class FirewallsClient(metaclass=FirewallsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateFirewallRequest):
             request = compute.UpdateFirewallRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if firewall is not None:
