@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.forwarding_rules import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import ForwardingRulesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import ForwardingRulesRestTransport
 
@@ -215,7 +212,7 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ForwardingRulesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -346,7 +343,6 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -376,10 +372,8 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListForwardingRulesRequest):
             request = compute.AggregatedListForwardingRulesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -436,7 +430,6 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
                 This corresponds to the ``forwarding_rule`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -488,10 +481,8 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteForwardingRuleRequest):
             request = compute.DeleteForwardingRuleRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -546,7 +537,6 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
                 This corresponds to the ``forwarding_rule`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -595,10 +585,8 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetForwardingRuleRequest):
             request = compute.GetForwardingRuleRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -653,7 +641,6 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
                 This corresponds to the ``forwarding_rule_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -705,10 +692,8 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertForwardingRuleRequest):
             request = compute.InsertForwardingRuleRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -756,7 +741,6 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -788,10 +772,8 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListForwardingRulesRequest):
             request = compute.ListForwardingRulesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -859,7 +841,6 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
                 This corresponds to the ``forwarding_rule_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -913,10 +894,8 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchForwardingRuleRequest):
             request = compute.PatchForwardingRuleRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -980,7 +959,6 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
                 This corresponds to the ``target_reference_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1034,10 +1012,8 @@ class ForwardingRulesClient(metaclass=ForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetTargetForwardingRuleRequest):
             request = compute.SetTargetForwardingRuleRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
