@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.global_forwarding_rules import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import GlobalForwardingRulesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import GlobalForwardingRulesRestTransport
 
@@ -217,7 +214,7 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, GlobalForwardingRulesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -356,7 +353,6 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
                 This corresponds to the ``forwarding_rule`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -408,10 +404,8 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteGlobalForwardingRuleRequest):
             request = compute.DeleteGlobalForwardingRuleRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if forwarding_rule is not None:
@@ -458,7 +452,6 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
                 This corresponds to the ``forwarding_rule`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -507,10 +500,8 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetGlobalForwardingRuleRequest):
             request = compute.GetGlobalForwardingRuleRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if forwarding_rule is not None:
@@ -555,7 +546,6 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
                 This corresponds to the ``forwarding_rule_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -607,10 +597,8 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertGlobalForwardingRuleRequest):
             request = compute.InsertGlobalForwardingRuleRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if forwarding_rule_resource is not None:
@@ -648,7 +636,6 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -680,10 +667,8 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListGlobalForwardingRulesRequest):
             request = compute.ListGlobalForwardingRulesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -741,7 +726,6 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
                 This corresponds to the ``forwarding_rule_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -793,10 +777,8 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchGlobalForwardingRuleRequest):
             request = compute.PatchGlobalForwardingRuleRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if forwarding_rule is not None:
@@ -851,7 +833,6 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
                 This corresponds to the ``target_reference_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -905,10 +886,8 @@ class GlobalForwardingRulesClient(metaclass=GlobalForwardingRulesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetTargetGlobalForwardingRuleRequest):
             request = compute.SetTargetGlobalForwardingRuleRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if forwarding_rule is not None:
