@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import GlobalForwardingRulesTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def delete(
         self,
@@ -103,8 +103,7 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         Args:
             request (~.compute.DeleteGlobalForwardingRuleRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 GlobalForwardingRules.Delete. See the
                 method description for details.
 
@@ -154,25 +153,24 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteGlobalForwardingRuleRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -184,8 +182,7 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         Args:
             request (~.compute.GetGlobalForwardingRuleRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 GlobalForwardingRules.Get. See the
                 method description for details.
 
@@ -230,22 +227,23 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.ForwardingRule.from_json(response.content)
+        return compute.ForwardingRule.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -257,8 +255,7 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         Args:
             request (~.compute.InsertGlobalForwardingRuleRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 GlobalForwardingRules.Insert. See the
                 method description for details.
 
@@ -313,15 +310,14 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertGlobalForwardingRuleRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -331,7 +327,7 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -343,8 +339,7 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         Args:
             request (~.compute.ListGlobalForwardingRulesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 GlobalForwardingRules.List. See the
                 method description for details.
 
@@ -366,29 +361,34 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListGlobalForwardingRulesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListGlobalForwardingRulesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListGlobalForwardingRulesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListGlobalForwardingRulesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListGlobalForwardingRulesRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.ForwardingRuleList.from_json(response.content)
+        return compute.ForwardingRuleList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def patch(
         self,
@@ -400,8 +400,7 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         Args:
             request (~.compute.PatchGlobalForwardingRuleRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 GlobalForwardingRules.Patch. See the
                 method description for details.
 
@@ -458,15 +457,14 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.PatchGlobalForwardingRuleRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -476,7 +474,7 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_target(
         self,
@@ -488,8 +486,7 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         Args:
             request (~.compute.SetTargetGlobalForwardingRuleRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 GlobalForwardingRules.SetTarget. See the
                 method description for details.
 
@@ -546,15 +543,14 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetTargetGlobalForwardingRuleRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -564,7 +560,7 @@ class GlobalForwardingRulesRestTransport(GlobalForwardingRulesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("GlobalForwardingRulesRestTransport",)
