@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.global_network_endpoint_groups import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import GlobalNetworkEndpointGroupsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import GlobalNetworkEndpointGroupsRestTransport
 
@@ -219,7 +216,7 @@ class GlobalNetworkEndpointGroupsClient(
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, GlobalNetworkEndpointGroupsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -367,7 +364,6 @@ class GlobalNetworkEndpointGroupsClient(
                 This corresponds to the ``global_network_endpoint_groups_attach_endpoints_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -429,10 +425,8 @@ class GlobalNetworkEndpointGroupsClient(
             request = compute.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest(
                 request
             )
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if network_endpoint_group is not None:
@@ -487,7 +481,6 @@ class GlobalNetworkEndpointGroupsClient(
                 This corresponds to the ``network_endpoint_group`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -539,10 +532,8 @@ class GlobalNetworkEndpointGroupsClient(
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteGlobalNetworkEndpointGroupRequest):
             request = compute.DeleteGlobalNetworkEndpointGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if network_endpoint_group is not None:
@@ -596,7 +587,6 @@ class GlobalNetworkEndpointGroupsClient(
                 This corresponds to the ``global_network_endpoint_groups_detach_endpoints_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -658,10 +648,8 @@ class GlobalNetworkEndpointGroupsClient(
             request = compute.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest(
                 request
             )
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if network_endpoint_group is not None:
@@ -715,7 +703,6 @@ class GlobalNetworkEndpointGroupsClient(
                 This corresponds to the ``network_endpoint_group`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -756,10 +743,8 @@ class GlobalNetworkEndpointGroupsClient(
         # there are no flattened fields.
         if not isinstance(request, compute.GetGlobalNetworkEndpointGroupRequest):
             request = compute.GetGlobalNetworkEndpointGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if network_endpoint_group is not None:
@@ -804,7 +789,6 @@ class GlobalNetworkEndpointGroupsClient(
                 This corresponds to the ``network_endpoint_group_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -856,10 +840,8 @@ class GlobalNetworkEndpointGroupsClient(
         # there are no flattened fields.
         if not isinstance(request, compute.InsertGlobalNetworkEndpointGroupRequest):
             request = compute.InsertGlobalNetworkEndpointGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if network_endpoint_group_resource is not None:
@@ -899,7 +881,6 @@ class GlobalNetworkEndpointGroupsClient(
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -929,10 +910,8 @@ class GlobalNetworkEndpointGroupsClient(
         # there are no flattened fields.
         if not isinstance(request, compute.ListGlobalNetworkEndpointGroupsRequest):
             request = compute.ListGlobalNetworkEndpointGroupsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -984,7 +963,6 @@ class GlobalNetworkEndpointGroupsClient(
                 This corresponds to the ``network_endpoint_group`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1018,10 +996,8 @@ class GlobalNetworkEndpointGroupsClient(
             request = compute.ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest(
                 request
             )
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if network_endpoint_group is not None:
