@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.global_operations import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import GlobalOperationsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import GlobalOperationsRestTransport
 
@@ -215,7 +212,7 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, GlobalOperationsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -346,7 +343,6 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -376,10 +372,8 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListGlobalOperationsRequest):
             request = compute.AggregatedListGlobalOperationsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -428,7 +422,6 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
                 This corresponds to the ``operation`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -458,10 +451,8 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteGlobalOperationRequest):
             request = compute.DeleteGlobalOperationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if operation is not None:
@@ -507,7 +498,6 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
                 This corresponds to the ``operation`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -559,10 +549,8 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetGlobalOperationRequest):
             request = compute.GetGlobalOperationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if operation is not None:
@@ -600,7 +588,6 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -632,10 +619,8 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListGlobalOperationsRequest):
             request = compute.ListGlobalOperationsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -698,7 +683,6 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
                 This corresponds to the ``operation`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -750,10 +734,8 @@ class GlobalOperationsClient(metaclass=GlobalOperationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.WaitGlobalOperationRequest):
             request = compute.WaitGlobalOperationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if operation is not None:
