@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.global_organization_operations import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import GlobalOrganizationOperationsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import GlobalOrganizationOperationsRestTransport
 
@@ -219,7 +216,7 @@ class GlobalOrganizationOperationsClient(
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, GlobalOrganizationOperationsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -352,7 +349,6 @@ class GlobalOrganizationOperationsClient(
                 This corresponds to the ``operation`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -382,10 +378,8 @@ class GlobalOrganizationOperationsClient(
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteGlobalOrganizationOperationRequest):
             request = compute.DeleteGlobalOrganizationOperationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if operation is not None:
                 request.operation = operation
 
@@ -423,7 +417,6 @@ class GlobalOrganizationOperationsClient(
                 This corresponds to the ``operation`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -475,10 +468,8 @@ class GlobalOrganizationOperationsClient(
         # there are no flattened fields.
         if not isinstance(request, compute.GetGlobalOrganizationOperationRequest):
             request = compute.GetGlobalOrganizationOperationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if operation is not None:
                 request.operation = operation
 
@@ -508,7 +499,6 @@ class GlobalOrganizationOperationsClient(
                 The request object. A request message for
                 GlobalOrganizationOperations.List. See the method
                 description for details.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -525,7 +515,6 @@ class GlobalOrganizationOperationsClient(
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a compute.ListGlobalOrganizationOperationsRequest.
         # There's no risk of modifying the input as we've already verified
