@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.health_checks import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import HealthChecksTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import HealthChecksRestTransport
 
@@ -213,7 +210,7 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, HealthChecksTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -347,7 +344,6 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -377,10 +373,8 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListHealthChecksRequest):
             request = compute.AggregatedListHealthChecksRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -429,7 +423,6 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
                 This corresponds to the ``health_check`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -481,10 +474,8 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteHealthCheckRequest):
             request = compute.DeleteHealthCheckRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if health_check is not None:
@@ -531,7 +522,6 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
                 This corresponds to the ``health_check`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -586,10 +576,8 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetHealthCheckRequest):
             request = compute.GetHealthCheckRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if health_check is not None:
@@ -633,7 +621,6 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
                 This corresponds to the ``health_check_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -685,10 +672,8 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertHealthCheckRequest):
             request = compute.InsertHealthCheckRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if health_check_resource is not None:
@@ -726,7 +711,6 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -758,10 +742,8 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListHealthChecksRequest):
             request = compute.ListHealthChecksRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -819,7 +801,6 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
                 This corresponds to the ``health_check_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -871,10 +852,8 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchHealthCheckRequest):
             request = compute.PatchHealthCheckRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if health_check is not None:
@@ -928,7 +907,6 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
                 This corresponds to the ``health_check_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -980,10 +958,8 @@ class HealthChecksClient(metaclass=HealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateHealthCheckRequest):
             request = compute.UpdateHealthCheckRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if health_check is not None:
