@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.images import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import ImagesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import ImagesRestTransport
 
@@ -213,7 +210,7 @@ class ImagesClient(metaclass=ImagesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ImagesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -349,7 +346,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``image`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -401,10 +397,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteImageRequest):
             request = compute.DeleteImageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if image is not None:
@@ -455,7 +449,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``deprecation_status_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -507,10 +500,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeprecateImageRequest):
             request = compute.DeprecateImageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if image is not None:
@@ -555,7 +546,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``image`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -587,10 +577,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetImageRequest):
             request = compute.GetImageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if image is not None:
@@ -636,7 +624,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``family`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -668,10 +655,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetFromFamilyImageRequest):
             request = compute.GetFromFamilyImageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if family is not None:
@@ -717,7 +702,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -795,10 +779,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicyImageRequest):
             request = compute.GetIamPolicyImageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
@@ -841,7 +823,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``image_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -893,10 +874,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertImageRequest):
             request = compute.InsertImageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if image_resource is not None:
@@ -939,7 +918,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -970,10 +948,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListImagesRequest):
             request = compute.ListImagesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -1027,7 +1003,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``image_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1079,10 +1054,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchImageRequest):
             request = compute.PatchImageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if image is not None:
@@ -1136,7 +1109,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``global_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1216,10 +1188,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicyImageRequest):
             request = compute.SetIamPolicyImageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
@@ -1275,7 +1245,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``global_set_labels_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1329,10 +1298,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetLabelsImageRequest):
             request = compute.SetLabelsImageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
@@ -1388,7 +1355,6 @@ class ImagesClient(metaclass=ImagesClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1417,10 +1383,8 @@ class ImagesClient(metaclass=ImagesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsImageRequest):
             request = compute.TestIamPermissionsImageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
