@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.instance_groups import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import InstanceGroupsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import InstanceGroupsRestTransport
 
@@ -215,7 +212,7 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, InstanceGroupsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -371,7 +368,6 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 This corresponds to the ``instance_groups_add_instances_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -430,10 +426,8 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AddInstancesInstanceGroupRequest):
             request = compute.AddInstancesInstanceGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -477,7 +471,6 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -507,10 +500,8 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListInstanceGroupsRequest):
             request = compute.AggregatedListInstanceGroupsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -570,7 +561,6 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 This corresponds to the ``instance_group`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -622,10 +612,8 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteInstanceGroupRequest):
             request = compute.DeleteInstanceGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -682,7 +670,6 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 This corresponds to the ``instance_group`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -731,10 +718,8 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetInstanceGroupRequest):
             request = compute.GetInstanceGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -788,7 +773,6 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 This corresponds to the ``instance_group_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -840,10 +824,8 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertInstanceGroupRequest):
             request = compute.InsertInstanceGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -894,7 +876,6 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 This corresponds to the ``zone`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -925,10 +906,8 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListInstanceGroupsRequest):
             request = compute.ListInstanceGroupsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -995,7 +974,6 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 This corresponds to the ``instance_groups_list_instances_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1032,10 +1010,8 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListInstancesInstanceGroupsRequest):
             request = compute.ListInstancesInstanceGroupsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1111,7 +1087,6 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 This corresponds to the ``instance_groups_remove_instances_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1170,10 +1145,8 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.RemoveInstancesInstanceGroupRequest):
             request = compute.RemoveInstancesInstanceGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1239,7 +1212,6 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
                 This corresponds to the ``instance_groups_set_named_ports_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1298,10 +1270,8 @@ class InstanceGroupsClient(metaclass=InstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetNamedPortsInstanceGroupRequest):
             request = compute.SetNamedPortsInstanceGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
