@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import InstanceGroupsTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def add_instances(
         self,
@@ -103,8 +103,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         Args:
             request (~.compute.AddInstancesInstanceGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InstanceGroups.AddInstances. See the
                 method description for details.
 
@@ -162,15 +161,14 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.AddInstancesInstanceGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -180,7 +178,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def aggregated_list(
         self,
@@ -192,8 +190,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         Args:
             request (~.compute.AggregatedListInstanceGroupsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InstanceGroups.AggregatedList. See the
                 method description for details.
 
@@ -213,30 +210,39 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListInstanceGroupsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.AggregatedListInstanceGroupsRequest.include_all_scopes in request:
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListInstanceGroupsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListInstanceGroupsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListInstanceGroupsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if (
+            compute.AggregatedListInstanceGroupsRequest.return_partial_success
+            in request
+        ):
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.InstanceGroupAggregatedList.from_json(response.content)
+        return compute.InstanceGroupAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def delete(
         self,
@@ -248,8 +254,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         Args:
             request (~.compute.DeleteInstanceGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InstanceGroups.Delete. See the method
                 description for details.
 
@@ -300,25 +305,24 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteInstanceGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -330,8 +334,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         Args:
             request (~.compute.GetInstanceGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InstanceGroups.Get. See the method
                 description for details.
 
@@ -375,22 +378,23 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.InstanceGroup.from_json(response.content)
+        return compute.InstanceGroup.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -402,8 +406,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         Args:
             request (~.compute.InsertInstanceGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InstanceGroups.Insert. See the method
                 description for details.
 
@@ -458,15 +461,14 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertInstanceGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -476,7 +478,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -488,8 +490,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         Args:
             request (~.compute.ListInstanceGroupsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InstanceGroups.List. See the method
                 description for details.
 
@@ -509,29 +510,34 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListInstanceGroupsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListInstanceGroupsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListInstanceGroupsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListInstanceGroupsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListInstanceGroupsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.InstanceGroupList.from_json(response.content)
+        return compute.InstanceGroupList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def list_instances(
         self,
@@ -543,8 +549,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         Args:
             request (~.compute.ListInstancesInstanceGroupsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InstanceGroups.ListInstances. See the
                 method description for details.
 
@@ -574,19 +579,22 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListInstancesInstanceGroupsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListInstancesInstanceGroupsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListInstancesInstanceGroupsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListInstancesInstanceGroupsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListInstancesInstanceGroupsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -596,7 +604,9 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.InstanceGroupsListInstances.from_json(response.content)
+        return compute.InstanceGroupsListInstances.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def remove_instances(
         self,
@@ -608,8 +618,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         Args:
             request (~.compute.RemoveInstancesInstanceGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InstanceGroups.RemoveInstances. See the
                 method description for details.
 
@@ -667,15 +676,14 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.RemoveInstancesInstanceGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -685,7 +693,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_named_ports(
         self,
@@ -697,8 +705,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         Args:
             request (~.compute.SetNamedPortsInstanceGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InstanceGroups.SetNamedPorts. See the
                 method description for details.
 
@@ -756,15 +763,14 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetNamedPortsInstanceGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -774,7 +780,7 @@ class InstanceGroupsRestTransport(InstanceGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("InstanceGroupsRestTransport",)
