@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.instance_templates import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import InstanceTemplatesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import InstanceTemplatesRestTransport
 
@@ -217,7 +214,7 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, InstanceTemplatesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -359,7 +356,6 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
                 This corresponds to the ``instance_template`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -411,10 +407,8 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteInstanceTemplateRequest):
             request = compute.DeleteInstanceTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if instance_template is not None:
@@ -459,7 +453,6 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
                 This corresponds to the ``instance_template`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -492,10 +485,8 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetInstanceTemplateRequest):
             request = compute.GetInstanceTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if instance_template is not None:
@@ -541,7 +532,6 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -619,10 +609,8 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicyInstanceTemplateRequest):
             request = compute.GetIamPolicyInstanceTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
@@ -670,7 +658,6 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
                 This corresponds to the ``instance_template_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -722,10 +709,8 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertInstanceTemplateRequest):
             request = compute.InsertInstanceTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if instance_template_resource is not None:
@@ -763,7 +748,6 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -794,10 +778,8 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListInstanceTemplatesRequest):
             request = compute.ListInstanceTemplatesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -853,7 +835,6 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
                 This corresponds to the ``global_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -933,10 +914,8 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicyInstanceTemplateRequest):
             request = compute.SetIamPolicyInstanceTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
@@ -992,7 +971,6 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1021,10 +999,8 @@ class InstanceTemplatesClient(metaclass=InstanceTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsInstanceTemplateRequest):
             request = compute.TestIamPermissionsInstanceTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
