@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.interconnect_attachments import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import InterconnectAttachmentsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import InterconnectAttachmentsRestTransport
 
@@ -217,7 +214,7 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, InterconnectAttachmentsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -349,7 +346,6 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -381,10 +377,8 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
             request, compute.AggregatedListInterconnectAttachmentsRequest
         ):
             request = compute.AggregatedListInterconnectAttachmentsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -439,7 +433,6 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
                 This corresponds to the ``interconnect_attachment`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -491,10 +484,8 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteInterconnectAttachmentRequest):
             request = compute.DeleteInterconnectAttachmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -547,7 +538,6 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
                 This corresponds to the ``interconnect_attachment`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -582,10 +572,8 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # there are no flattened fields.
         if not isinstance(request, compute.GetInterconnectAttachmentRequest):
             request = compute.GetInterconnectAttachmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -637,7 +625,6 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
                 This corresponds to the ``interconnect_attachment_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -689,10 +676,8 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # there are no flattened fields.
         if not isinstance(request, compute.InsertInterconnectAttachmentRequest):
             request = compute.InsertInterconnectAttachmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -740,7 +725,6 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -772,10 +756,8 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # there are no flattened fields.
         if not isinstance(request, compute.ListInterconnectAttachmentsRequest):
             request = compute.ListInterconnectAttachmentsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -843,7 +825,6 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
                 This corresponds to the ``interconnect_attachment_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -897,10 +878,8 @@ class InterconnectAttachmentsClient(metaclass=InterconnectAttachmentsClientMeta)
         # there are no flattened fields.
         if not isinstance(request, compute.PatchInterconnectAttachmentRequest):
             request = compute.PatchInterconnectAttachmentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
