@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import InterconnectAttachmentsTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def aggregated_list(
         self,
@@ -103,8 +103,7 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         Args:
             request (~.compute.AggregatedListInterconnectAttachmentsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InterconnectAttachments.AggregatedList.
                 See the method description for details.
 
@@ -124,30 +123,42 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListInterconnectAttachmentsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if (
+            compute.AggregatedListInterconnectAttachmentsRequest.include_all_scopes
+            in request
+        ):
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListInterconnectAttachmentsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListInterconnectAttachmentsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListInterconnectAttachmentsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if (
+            compute.AggregatedListInterconnectAttachmentsRequest.return_partial_success
+            in request
+        ):
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.InterconnectAttachmentAggregatedList.from_json(response.content)
+        return compute.InterconnectAttachmentAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def delete(
         self,
@@ -159,8 +170,7 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         Args:
             request (~.compute.DeleteInterconnectAttachmentRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InterconnectAttachments.Delete. See the
                 method description for details.
 
@@ -211,25 +221,24 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteInterconnectAttachmentRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -241,8 +250,7 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         Args:
             request (~.compute.GetInterconnectAttachmentRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InterconnectAttachments.Get. See the
                 method description for details.
 
@@ -273,22 +281,23 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.InterconnectAttachment.from_json(response.content)
+        return compute.InterconnectAttachment.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -300,8 +309,7 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         Args:
             request (~.compute.InsertInterconnectAttachmentRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InterconnectAttachments.Insert. See the
                 method description for details.
 
@@ -356,16 +364,16 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-            "validateOnly": request.validate_only,
-        }
+        query_params = {}
+        if compute.InsertInterconnectAttachmentRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+        if compute.InsertInterconnectAttachmentRequest.validate_only in request:
+            query_params["validateOnly"] = request.validate_only
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -375,7 +383,7 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -387,8 +395,7 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         Args:
             request (~.compute.ListInterconnectAttachmentsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InterconnectAttachments.List. See the
                 method description for details.
 
@@ -411,29 +418,34 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListInterconnectAttachmentsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListInterconnectAttachmentsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListInterconnectAttachmentsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListInterconnectAttachmentsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListInterconnectAttachmentsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.InterconnectAttachmentList.from_json(response.content)
+        return compute.InterconnectAttachmentList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def patch(
         self,
@@ -445,8 +457,7 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         Args:
             request (~.compute.PatchInterconnectAttachmentRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 InterconnectAttachments.Patch. See the
                 method description for details.
 
@@ -504,15 +515,14 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.PatchInterconnectAttachmentRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -522,7 +532,7 @@ class InterconnectAttachmentsRestTransport(InterconnectAttachmentsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("InterconnectAttachmentsRestTransport",)
