@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.interconnect_locations import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import InterconnectLocationsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import InterconnectLocationsRestTransport
 
@@ -217,7 +214,7 @@ class InterconnectLocationsClient(metaclass=InterconnectLocationsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, InterconnectLocationsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -358,7 +355,6 @@ class InterconnectLocationsClient(metaclass=InterconnectLocationsClientMeta):
                 This corresponds to the ``interconnect_location`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -392,10 +388,8 @@ class InterconnectLocationsClient(metaclass=InterconnectLocationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetInterconnectLocationRequest):
             request = compute.GetInterconnectLocationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if interconnect_location is not None:
@@ -433,7 +427,6 @@ class InterconnectLocationsClient(metaclass=InterconnectLocationsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -465,10 +458,8 @@ class InterconnectLocationsClient(metaclass=InterconnectLocationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListInterconnectLocationsRequest):
             request = compute.ListInterconnectLocationsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
