@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.interconnects import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import InterconnectsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import InterconnectsRestTransport
 
@@ -213,7 +210,7 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, InterconnectsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -350,7 +347,6 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
                 This corresponds to the ``interconnect`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -402,10 +398,8 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteInterconnectRequest):
             request = compute.DeleteInterconnectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if interconnect is not None:
@@ -449,7 +443,6 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
                 This corresponds to the ``interconnect`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -483,10 +476,8 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetInterconnectRequest):
             request = compute.GetInterconnectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if interconnect is not None:
@@ -532,7 +523,6 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
                 This corresponds to the ``interconnect`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -561,10 +551,8 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetDiagnosticsInterconnectRequest):
             request = compute.GetDiagnosticsInterconnectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if interconnect is not None:
@@ -608,7 +596,6 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
                 This corresponds to the ``interconnect_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -660,10 +647,8 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertInterconnectRequest):
             request = compute.InsertInterconnectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if interconnect_resource is not None:
@@ -701,7 +686,6 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -733,10 +717,8 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListInterconnectsRequest):
             request = compute.ListInterconnectsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -792,7 +774,6 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
                 This corresponds to the ``interconnect_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -844,10 +825,8 @@ class InterconnectsClient(metaclass=InterconnectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchInterconnectRequest):
             request = compute.PatchInterconnectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if interconnect is not None:
