@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.licenses import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import LicensesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import LicensesRestTransport
 
@@ -213,7 +210,7 @@ class LicensesClient(metaclass=LicensesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, LicensesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -353,7 +350,6 @@ class LicensesClient(metaclass=LicensesClientMeta):
                 This corresponds to the ``license_`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -405,10 +401,8 @@ class LicensesClient(metaclass=LicensesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteLicenseRequest):
             request = compute.DeleteLicenseRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if license_ is not None:
@@ -454,7 +448,6 @@ class LicensesClient(metaclass=LicensesClientMeta):
                 This corresponds to the ``license_`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -488,10 +481,8 @@ class LicensesClient(metaclass=LicensesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetLicenseRequest):
             request = compute.GetLicenseRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if license_ is not None:
@@ -539,7 +530,6 @@ class LicensesClient(metaclass=LicensesClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -617,10 +607,8 @@ class LicensesClient(metaclass=LicensesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicyLicenseRequest):
             request = compute.GetIamPolicyLicenseRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
@@ -665,7 +653,6 @@ class LicensesClient(metaclass=LicensesClientMeta):
                 This corresponds to the ``license_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -717,10 +704,8 @@ class LicensesClient(metaclass=LicensesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertLicenseRequest):
             request = compute.InsertLicenseRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if license_resource is not None:
@@ -765,7 +750,6 @@ class LicensesClient(metaclass=LicensesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -795,10 +779,8 @@ class LicensesClient(metaclass=LicensesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListLicensesRequest):
             request = compute.ListLicensesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -856,7 +838,6 @@ class LicensesClient(metaclass=LicensesClientMeta):
                 This corresponds to the ``global_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -936,10 +917,8 @@ class LicensesClient(metaclass=LicensesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicyLicenseRequest):
             request = compute.SetIamPolicyLicenseRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
@@ -997,7 +976,6 @@ class LicensesClient(metaclass=LicensesClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1026,10 +1004,8 @@ class LicensesClient(metaclass=LicensesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsLicenseRequest):
             request = compute.TestIamPermissionsLicenseRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
