@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import LicensesTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class LicensesRestTransport(LicensesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class LicensesRestTransport(LicensesTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class LicensesRestTransport(LicensesTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def delete(
         self,
@@ -103,8 +103,7 @@ class LicensesRestTransport(LicensesTransport):
 
         Args:
             request (~.compute.DeleteLicenseRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Licenses.Delete. See the method
                 description for details.
 
@@ -152,26 +151,26 @@ class LicensesRestTransport(LicensesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "license": request.license_,
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if request.license_:
+            query_params["license"] = request.license_
+        if compute.DeleteLicenseRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -183,8 +182,7 @@ class LicensesRestTransport(LicensesTransport):
 
         Args:
             request (~.compute.GetLicenseRequest):
-                The request object.
-                A request message for Licenses.Get.
+                The request object. A request message for Licenses.Get.
                 See the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -210,25 +208,24 @@ class LicensesRestTransport(LicensesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "license": request.license_,
-        }
+        query_params = {}
+        if request.license_:
+            query_params["license"] = request.license_
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.License.from_json(response.content)
+        return compute.License.from_json(response.content, ignore_unknown_fields=True)
 
     def get_iam_policy(
         self,
@@ -240,8 +237,7 @@ class LicensesRestTransport(LicensesTransport):
 
         Args:
             request (~.compute.GetIamPolicyLicenseRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Licenses.GetIamPolicy. See the method
                 description for details.
 
@@ -311,25 +307,29 @@ class LicensesRestTransport(LicensesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "optionsRequestedPolicyVersion": request.options_requested_policy_version,
-        }
+        query_params = {}
+        if (
+            compute.GetIamPolicyLicenseRequest.options_requested_policy_version
+            in request
+        ):
+            query_params[
+                "optionsRequestedPolicyVersion"
+            ] = request.options_requested_policy_version
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def insert(
         self,
@@ -341,8 +341,7 @@ class LicensesRestTransport(LicensesTransport):
 
         Args:
             request (~.compute.InsertLicenseRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Licenses.Insert. See the method
                 description for details.
 
@@ -397,15 +396,14 @@ class LicensesRestTransport(LicensesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertLicenseRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -415,7 +413,7 @@ class LicensesRestTransport(LicensesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -427,8 +425,7 @@ class LicensesRestTransport(LicensesTransport):
 
         Args:
             request (~.compute.ListLicensesRequest):
-                The request object.
-                A request message for Licenses.List.
+                The request object. A request message for Licenses.List.
                 See the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -447,29 +444,34 @@ class LicensesRestTransport(LicensesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListLicensesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListLicensesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListLicensesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListLicensesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListLicensesRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.LicensesListResponse.from_json(response.content)
+        return compute.LicensesListResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def set_iam_policy(
         self,
@@ -481,8 +483,7 @@ class LicensesRestTransport(LicensesTransport):
 
         Args:
             request (~.compute.SetIamPolicyLicenseRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Licenses.SetIamPolicy. See the method
                 description for details.
 
@@ -560,12 +561,11 @@ class LicensesRestTransport(LicensesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -575,7 +575,7 @@ class LicensesRestTransport(LicensesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def test_iam_permissions(
         self,
@@ -587,8 +587,7 @@ class LicensesRestTransport(LicensesTransport):
 
         Args:
             request (~.compute.TestIamPermissionsLicenseRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Licenses.TestIamPermissions. See the
                 method description for details.
 
@@ -616,12 +615,11 @@ class LicensesRestTransport(LicensesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -631,7 +629,9 @@ class LicensesRestTransport(LicensesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.TestPermissionsResponse.from_json(response.content)
+        return compute.TestPermissionsResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
 
 __all__ = ("LicensesRestTransport",)
