@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import NetworkEndpointGroupsTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def aggregated_list(
         self,
@@ -103,8 +103,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         Args:
             request (~.compute.AggregatedListNetworkEndpointGroupsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NetworkEndpointGroups.AggregatedList.
                 See the method description for details.
 
@@ -124,30 +123,42 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListNetworkEndpointGroupsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if (
+            compute.AggregatedListNetworkEndpointGroupsRequest.include_all_scopes
+            in request
+        ):
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListNetworkEndpointGroupsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListNetworkEndpointGroupsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListNetworkEndpointGroupsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if (
+            compute.AggregatedListNetworkEndpointGroupsRequest.return_partial_success
+            in request
+        ):
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.NetworkEndpointGroupAggregatedList.from_json(response.content)
+        return compute.NetworkEndpointGroupAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def attach_network_endpoints(
         self,
@@ -159,8 +170,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         Args:
             request (~.compute.AttachNetworkEndpointsNetworkEndpointGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NetworkEndpointGroups.AttachNetworkEndpoints.
                 See the method description for details.
 
@@ -218,15 +228,17 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if (
+            compute.AttachNetworkEndpointsNetworkEndpointGroupRequest.request_id
+            in request
+        ):
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -236,7 +248,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def delete(
         self,
@@ -248,8 +260,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         Args:
             request (~.compute.DeleteNetworkEndpointGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NetworkEndpointGroups.Delete. See the
                 method description for details.
 
@@ -300,25 +311,24 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteNetworkEndpointGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def detach_network_endpoints(
         self,
@@ -330,8 +340,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         Args:
             request (~.compute.DetachNetworkEndpointsNetworkEndpointGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NetworkEndpointGroups.DetachNetworkEndpoints.
                 See the method description for details.
 
@@ -389,15 +398,17 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if (
+            compute.DetachNetworkEndpointsNetworkEndpointGroupRequest.request_id
+            in request
+        ):
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -407,7 +418,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -419,8 +430,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         Args:
             request (~.compute.GetNetworkEndpointGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NetworkEndpointGroups.Get. See the
                 method description for details.
 
@@ -457,22 +467,23 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.NetworkEndpointGroup.from_json(response.content)
+        return compute.NetworkEndpointGroup.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -484,8 +495,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         Args:
             request (~.compute.InsertNetworkEndpointGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NetworkEndpointGroups.Insert. See the
                 method description for details.
 
@@ -540,15 +550,14 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertNetworkEndpointGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -558,7 +567,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -570,8 +579,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         Args:
             request (~.compute.ListNetworkEndpointGroupsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NetworkEndpointGroups.List. See the
                 method description for details.
 
@@ -591,29 +599,34 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListNetworkEndpointGroupsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListNetworkEndpointGroupsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListNetworkEndpointGroupsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListNetworkEndpointGroupsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListNetworkEndpointGroupsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.NetworkEndpointGroupList.from_json(response.content)
+        return compute.NetworkEndpointGroupList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def list_network_endpoints(
         self,
@@ -625,8 +638,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         Args:
             request (~.compute.ListNetworkEndpointsNetworkEndpointGroupsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NetworkEndpointGroups.ListNetworkEndpoints.
                 See the method description for details.
 
@@ -656,19 +668,31 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListNetworkEndpointsNetworkEndpointGroupsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if (
+            compute.ListNetworkEndpointsNetworkEndpointGroupsRequest.max_results
+            in request
+        ):
+            query_params["maxResults"] = request.max_results
+        if compute.ListNetworkEndpointsNetworkEndpointGroupsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if (
+            compute.ListNetworkEndpointsNetworkEndpointGroupsRequest.page_token
+            in request
+        ):
+            query_params["pageToken"] = request.page_token
+        if (
+            compute.ListNetworkEndpointsNetworkEndpointGroupsRequest.return_partial_success
+            in request
+        ):
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -679,7 +703,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         # Return the response
         return compute.NetworkEndpointGroupsListNetworkEndpoints.from_json(
-            response.content
+            response.content, ignore_unknown_fields=True
         )
 
     def test_iam_permissions(
@@ -692,8 +716,7 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
 
         Args:
             request (~.compute.TestIamPermissionsNetworkEndpointGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NetworkEndpointGroups.TestIamPermissions.
                 See the method description for details.
 
@@ -724,12 +747,11 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -739,7 +761,9 @@ class NetworkEndpointGroupsRestTransport(NetworkEndpointGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.TestPermissionsResponse.from_json(response.content)
+        return compute.TestPermissionsResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
 
 __all__ = ("NetworkEndpointGroupsRestTransport",)
