@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import NetworksTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class NetworksRestTransport(NetworksTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class NetworksRestTransport(NetworksTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class NetworksRestTransport(NetworksTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def add_peering(
         self,
@@ -103,8 +103,7 @@ class NetworksRestTransport(NetworksTransport):
 
         Args:
             request (~.compute.AddPeeringNetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Networks.AddPeering. See the method
                 description for details.
 
@@ -159,15 +158,14 @@ class NetworksRestTransport(NetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.AddPeeringNetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -177,7 +175,7 @@ class NetworksRestTransport(NetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def delete(
         self,
@@ -189,8 +187,7 @@ class NetworksRestTransport(NetworksTransport):
 
         Args:
             request (~.compute.DeleteNetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Networks.Delete. See the method
                 description for details.
 
@@ -238,25 +235,24 @@ class NetworksRestTransport(NetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteNetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -268,8 +264,7 @@ class NetworksRestTransport(NetworksTransport):
 
         Args:
             request (~.compute.GetNetworkRequest):
-                The request object.
-                A request message for Networks.Get.
+                The request object. A request message for Networks.Get.
                 See the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -295,22 +290,21 @@ class NetworksRestTransport(NetworksTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Network.from_json(response.content)
+        return compute.Network.from_json(response.content, ignore_unknown_fields=True)
 
     def insert(
         self,
@@ -322,8 +316,7 @@ class NetworksRestTransport(NetworksTransport):
 
         Args:
             request (~.compute.InsertNetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Networks.Insert. See the method
                 description for details.
 
@@ -378,15 +371,14 @@ class NetworksRestTransport(NetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertNetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -396,7 +388,7 @@ class NetworksRestTransport(NetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -408,8 +400,7 @@ class NetworksRestTransport(NetworksTransport):
 
         Args:
             request (~.compute.ListNetworksRequest):
-                The request object.
-                A request message for Networks.List.
+                The request object. A request message for Networks.List.
                 See the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -428,29 +419,34 @@ class NetworksRestTransport(NetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListNetworksRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListNetworksRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListNetworksRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListNetworksRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListNetworksRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.NetworkList.from_json(response.content)
+        return compute.NetworkList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def list_peering_routes(
         self,
@@ -462,8 +458,7 @@ class NetworksRestTransport(NetworksTransport):
 
         Args:
             request (~.compute.ListPeeringRoutesNetworksRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Networks.ListPeeringRoutes. See the
                 method description for details.
 
@@ -483,32 +478,40 @@ class NetworksRestTransport(NetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "direction": request.direction,
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "peeringName": request.peering_name,
-            "region": request.region,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListPeeringRoutesNetworksRequest.direction in request:
+            query_params["direction"] = request.direction
+        if compute.ListPeeringRoutesNetworksRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListPeeringRoutesNetworksRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListPeeringRoutesNetworksRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListPeeringRoutesNetworksRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListPeeringRoutesNetworksRequest.peering_name in request:
+            query_params["peeringName"] = request.peering_name
+        if compute.ListPeeringRoutesNetworksRequest.region in request:
+            query_params["region"] = request.region
+        if compute.ListPeeringRoutesNetworksRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.ExchangedPeeringRoutesList.from_json(response.content)
+        return compute.ExchangedPeeringRoutesList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def patch(
         self,
@@ -520,8 +523,7 @@ class NetworksRestTransport(NetworksTransport):
 
         Args:
             request (~.compute.PatchNetworkRequest):
-                The request object.
-                A request message for Networks.Patch.
+                The request object. A request message for Networks.Patch.
                 See the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -575,15 +577,14 @@ class NetworksRestTransport(NetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.PatchNetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -593,7 +594,7 @@ class NetworksRestTransport(NetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def remove_peering(
         self,
@@ -605,8 +606,7 @@ class NetworksRestTransport(NetworksTransport):
 
         Args:
             request (~.compute.RemovePeeringNetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Networks.RemovePeering. See the method
                 description for details.
 
@@ -661,15 +661,14 @@ class NetworksRestTransport(NetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.RemovePeeringNetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -679,7 +678,7 @@ class NetworksRestTransport(NetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def switch_to_custom_mode(
         self,
@@ -691,8 +690,7 @@ class NetworksRestTransport(NetworksTransport):
 
         Args:
             request (~.compute.SwitchToCustomModeNetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Networks.SwitchToCustomMode. See the
                 method description for details.
 
@@ -740,25 +738,24 @@ class NetworksRestTransport(NetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SwitchToCustomModeNetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url)
+        response = self._session.post(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def update_peering(
         self,
@@ -770,8 +767,7 @@ class NetworksRestTransport(NetworksTransport):
 
         Args:
             request (~.compute.UpdatePeeringNetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Networks.UpdatePeering. See the method
                 description for details.
 
@@ -826,15 +822,14 @@ class NetworksRestTransport(NetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.UpdatePeeringNetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -844,7 +839,7 @@ class NetworksRestTransport(NetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("NetworksRestTransport",)
