@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.node_groups import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import NodeGroupsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import NodeGroupsRestTransport
 
@@ -213,7 +210,7 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, NodeGroupsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -364,7 +361,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``node_groups_add_nodes_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -418,10 +414,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AddNodesNodeGroupRequest):
             request = compute.AddNodesNodeGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -466,7 +460,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -496,10 +489,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListNodeGroupsRequest):
             request = compute.AggregatedListNodeGroupsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -556,7 +547,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``node_group`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -608,10 +598,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteNodeGroupRequest):
             request = compute.DeleteNodeGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -672,7 +660,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``node_groups_delete_nodes_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -726,10 +713,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteNodesNodeGroupRequest):
             request = compute.DeleteNodesNodeGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -788,7 +773,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``node_group`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -825,10 +809,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetNodeGroupRequest):
             request = compute.GetNodeGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -884,7 +866,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -962,10 +943,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicyNodeGroupRequest):
             request = compute.GetIamPolicyNodeGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1027,7 +1006,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``node_group_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1081,10 +1059,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertNodeGroupRequest):
             request = compute.InsertNodeGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1134,7 +1110,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``zone`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1165,10 +1140,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListNodeGroupsRequest):
             request = compute.ListNodeGroupsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1227,7 +1200,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``node_group`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1257,10 +1229,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListNodesNodeGroupsRequest):
             request = compute.ListNodesNodeGroupsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1327,7 +1297,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``node_group_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1379,10 +1348,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchNodeGroupRequest):
             request = compute.PatchNodeGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1446,7 +1413,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``zone_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1526,10 +1492,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicyNodeGroupRequest):
             request = compute.SetIamPolicyNodeGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1594,7 +1558,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``node_groups_set_node_template_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1648,10 +1611,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetNodeTemplateNodeGroupRequest):
             request = compute.SetNodeTemplateNodeGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1717,7 +1678,6 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1746,10 +1706,8 @@ class NodeGroupsClient(metaclass=NodeGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsNodeGroupRequest):
             request = compute.TestIamPermissionsNodeGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
