@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import NodeGroupsTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def add_nodes(
         self,
@@ -103,8 +103,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.AddNodesNodeGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.AddNodes. See the method
                 description for details.
 
@@ -162,15 +161,14 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.AddNodesNodeGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -180,7 +178,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def aggregated_list(
         self,
@@ -192,8 +190,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.AggregatedListNodeGroupsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.AggregatedList. See the
                 method description for details.
 
@@ -213,30 +210,36 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListNodeGroupsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.AggregatedListNodeGroupsRequest.include_all_scopes in request:
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListNodeGroupsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListNodeGroupsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListNodeGroupsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.AggregatedListNodeGroupsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.NodeGroupAggregatedList.from_json(response.content)
+        return compute.NodeGroupAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def delete(
         self,
@@ -248,8 +251,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.DeleteNodeGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.Delete. See the method
                 description for details.
 
@@ -300,25 +302,24 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteNodeGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def delete_nodes(
         self,
@@ -330,8 +331,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.DeleteNodesNodeGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.DeleteNodes. See the method
                 description for details.
 
@@ -389,15 +389,14 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteNodesNodeGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -407,7 +406,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -419,8 +418,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.GetNodeGroupRequest):
-                The request object.
-                A request message for NodeGroups.Get.
+                The request object. A request message for NodeGroups.Get.
                 See the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -452,22 +450,21 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.NodeGroup.from_json(response.content)
+        return compute.NodeGroup.from_json(response.content, ignore_unknown_fields=True)
 
     def get_iam_policy(
         self,
@@ -479,8 +476,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.GetIamPolicyNodeGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.GetIamPolicy. See the method
                 description for details.
 
@@ -553,25 +549,29 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "optionsRequestedPolicyVersion": request.options_requested_policy_version,
-        }
+        query_params = {}
+        if (
+            compute.GetIamPolicyNodeGroupRequest.options_requested_policy_version
+            in request
+        ):
+            query_params[
+                "optionsRequestedPolicyVersion"
+            ] = request.options_requested_policy_version
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def insert(
         self,
@@ -583,8 +583,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.InsertNodeGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.Insert. See the method
                 description for details.
 
@@ -639,16 +638,16 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "initialNodeCount": request.initial_node_count,
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if request.initial_node_count:
+            query_params["initialNodeCount"] = request.initial_node_count
+        if compute.InsertNodeGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -658,7 +657,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -670,8 +669,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.ListNodeGroupsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.List. See the method
                 description for details.
 
@@ -691,29 +689,34 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListNodeGroupsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListNodeGroupsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListNodeGroupsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListNodeGroupsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListNodeGroupsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.NodeGroupList.from_json(response.content)
+        return compute.NodeGroupList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def list_nodes(
         self,
@@ -725,8 +728,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.ListNodesNodeGroupsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.ListNodes. See the method
                 description for details.
 
@@ -749,29 +751,34 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListNodesNodeGroupsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListNodesNodeGroupsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListNodesNodeGroupsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListNodesNodeGroupsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListNodesNodeGroupsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url)
+        response = self._session.post(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.NodeGroupsListNodes.from_json(response.content)
+        return compute.NodeGroupsListNodes.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def patch(
         self,
@@ -783,8 +790,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.PatchNodeGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.Patch. See the method
                 description for details.
 
@@ -842,15 +848,14 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.PatchNodeGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -860,7 +865,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_iam_policy(
         self,
@@ -872,8 +877,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.SetIamPolicyNodeGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.SetIamPolicy. See the method
                 description for details.
 
@@ -954,12 +958,11 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -969,7 +972,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def set_node_template(
         self,
@@ -981,8 +984,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.SetNodeTemplateNodeGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.SetNodeTemplate. See the
                 method description for details.
 
@@ -1040,15 +1042,14 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetNodeTemplateNodeGroupRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -1058,7 +1059,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def test_iam_permissions(
         self,
@@ -1070,8 +1071,7 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
 
         Args:
             request (~.compute.TestIamPermissionsNodeGroupRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 NodeGroups.TestIamPermissions. See the
                 method description for details.
 
@@ -1102,12 +1102,11 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -1117,7 +1116,9 @@ class NodeGroupsRestTransport(NodeGroupsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.TestPermissionsResponse.from_json(response.content)
+        return compute.TestPermissionsResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
 
 __all__ = ("NodeGroupsRestTransport",)
