@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.node_templates import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import NodeTemplatesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import NodeTemplatesRestTransport
 
@@ -213,7 +210,7 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, NodeTemplatesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -344,7 +341,6 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -374,10 +370,8 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListNodeTemplatesRequest):
             request = compute.AggregatedListNodeTemplatesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -434,7 +428,6 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
                 This corresponds to the ``node_template`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -486,10 +479,8 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteNodeTemplateRequest):
             request = compute.DeleteNodeTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -543,7 +534,6 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
                 This corresponds to the ``node_template`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -576,10 +566,8 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetNodeTemplateRequest):
             request = compute.GetNodeTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -635,7 +623,6 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -713,10 +700,8 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicyNodeTemplateRequest):
             request = compute.GetIamPolicyNodeTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -770,7 +755,6 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
                 This corresponds to the ``node_template_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -822,10 +806,8 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertNodeTemplateRequest):
             request = compute.InsertNodeTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -873,7 +855,6 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -904,10 +885,8 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListNodeTemplatesRequest):
             request = compute.ListNodeTemplatesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -973,7 +952,6 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
                 This corresponds to the ``region_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1053,10 +1031,8 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicyNodeTemplateRequest):
             request = compute.SetIamPolicyNodeTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1122,7 +1098,6 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1151,10 +1126,8 @@ class NodeTemplatesClient(metaclass=NodeTemplatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsNodeTemplateRequest):
             request = compute.TestIamPermissionsNodeTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
