@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.packet_mirrorings import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import PacketMirroringsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import PacketMirroringsRestTransport
 
@@ -215,7 +212,7 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, PacketMirroringsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -346,7 +343,6 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -377,10 +373,8 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListPacketMirroringsRequest):
             request = compute.AggregatedListPacketMirroringsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -435,7 +429,6 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
                 This corresponds to the ``packet_mirroring`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -487,10 +480,8 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeletePacketMirroringRequest):
             request = compute.DeletePacketMirroringRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -543,7 +534,6 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
                 This corresponds to the ``packet_mirroring`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -580,10 +570,8 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetPacketMirroringRequest):
             request = compute.GetPacketMirroringRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -636,7 +624,6 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
                 This corresponds to the ``packet_mirroring_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -688,10 +675,8 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertPacketMirroringRequest):
             request = compute.InsertPacketMirroringRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -737,7 +722,6 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -769,10 +753,8 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListPacketMirroringsRequest):
             request = compute.ListPacketMirroringsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -838,7 +820,6 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
                 This corresponds to the ``packet_mirroring_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -892,10 +873,8 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchPacketMirroringRequest):
             request = compute.PatchPacketMirroringRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -959,7 +938,6 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -988,10 +966,8 @@ class PacketMirroringsClient(metaclass=PacketMirroringsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsPacketMirroringRequest):
             request = compute.TestIamPermissionsPacketMirroringRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
