@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.projects import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import ProjectsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import ProjectsRestTransport
 
@@ -213,7 +210,7 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ProjectsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -344,7 +341,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -396,10 +392,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DisableXpnHostProjectRequest):
             request = compute.DisableXpnHostProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -441,7 +435,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``projects_disable_xpn_resource_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -495,10 +488,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DisableXpnResourceProjectRequest):
             request = compute.DisableXpnResourceProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if projects_disable_xpn_resource_request_resource is not None:
@@ -537,7 +528,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -589,10 +579,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.EnableXpnHostProjectRequest):
             request = compute.EnableXpnHostProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -635,7 +623,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``projects_enable_xpn_resource_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -689,10 +676,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.EnableXpnResourceProjectRequest):
             request = compute.EnableXpnResourceProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if projects_enable_xpn_resource_request_resource is not None:
@@ -730,7 +715,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -763,10 +747,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetProjectRequest):
             request = compute.GetProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -802,7 +784,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -835,10 +816,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetXpnHostProjectRequest):
             request = compute.GetXpnHostProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -874,7 +853,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -904,10 +882,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetXpnResourcesProjectsRequest):
             request = compute.GetXpnResourcesProjectsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -955,7 +931,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``projects_list_xpn_hosts_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -985,10 +960,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListXpnHostsProjectsRequest):
             request = compute.ListXpnHostsProjectsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if projects_list_xpn_hosts_request_resource is not None:
@@ -1039,7 +1012,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``disk_move_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1091,10 +1063,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.MoveDiskProjectRequest):
             request = compute.MoveDiskProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if disk_move_request_resource is not None:
@@ -1138,7 +1108,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``instance_move_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1190,10 +1159,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.MoveInstanceProjectRequest):
             request = compute.MoveInstanceProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if instance_move_request_resource is not None:
@@ -1238,7 +1205,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``metadata_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1290,10 +1256,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetCommonInstanceMetadataProjectRequest):
             request = compute.SetCommonInstanceMetadataProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if metadata_resource is not None:
@@ -1341,7 +1305,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``projects_set_default_network_tier_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1395,10 +1358,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetDefaultNetworkTierProjectRequest):
             request = compute.SetDefaultNetworkTierProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if projects_set_default_network_tier_request_resource is not None:
@@ -1446,7 +1407,6 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
                 This corresponds to the ``usage_export_location_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1498,10 +1458,8 @@ class ProjectsClient(metaclass=ProjectsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetUsageExportBucketProjectRequest):
             request = compute.SetUsageExportBucketProjectRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if usage_export_location_resource is not None:
