@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import ProjectsTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class ProjectsRestTransport(ProjectsTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class ProjectsRestTransport(ProjectsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class ProjectsRestTransport(ProjectsTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def disable_xpn_host(
         self,
@@ -103,8 +103,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.DisableXpnHostProjectRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.DisableXpnHost. See the method
                 description for details.
 
@@ -152,25 +151,24 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DisableXpnHostProjectRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url)
+        response = self._session.post(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def disable_xpn_resource(
         self,
@@ -182,8 +180,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.DisableXpnResourceProjectRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.DisableXpnResource. See the
                 method description for details.
 
@@ -238,15 +235,14 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DisableXpnResourceProjectRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -256,7 +252,7 @@ class ProjectsRestTransport(ProjectsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def enable_xpn_host(
         self,
@@ -268,8 +264,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.EnableXpnHostProjectRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.EnableXpnHost. See the method
                 description for details.
 
@@ -317,25 +312,24 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.EnableXpnHostProjectRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url)
+        response = self._session.post(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def enable_xpn_resource(
         self,
@@ -347,8 +341,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.EnableXpnResourceProjectRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.EnableXpnResource. See the
                 method description for details.
 
@@ -403,15 +396,14 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.EnableXpnResourceProjectRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -421,7 +413,7 @@ class ProjectsRestTransport(ProjectsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -433,8 +425,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.GetProjectRequest):
-                The request object.
-                A request message for Projects.Get.
+                The request object. A request message for Projects.Get.
                 See the method description for details.
 
             metadata (Sequence[Tuple[str, str]]): Strings which should be
@@ -460,22 +451,21 @@ class ProjectsRestTransport(ProjectsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Project.from_json(response.content)
+        return compute.Project.from_json(response.content, ignore_unknown_fields=True)
 
     def get_xpn_host(
         self,
@@ -487,8 +477,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.GetXpnHostProjectRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.GetXpnHost. See the method
                 description for details.
 
@@ -515,22 +504,21 @@ class ProjectsRestTransport(ProjectsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Project.from_json(response.content)
+        return compute.Project.from_json(response.content, ignore_unknown_fields=True)
 
     def get_xpn_resources(
         self,
@@ -542,8 +530,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.GetXpnResourcesProjectsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.GetXpnResources. See the method
                 description for details.
 
@@ -563,29 +550,34 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.GetXpnResourcesProjectsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.GetXpnResourcesProjectsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.GetXpnResourcesProjectsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.GetXpnResourcesProjectsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.GetXpnResourcesProjectsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.ProjectsGetXpnResources.from_json(response.content)
+        return compute.ProjectsGetXpnResources.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def list_xpn_hosts(
         self,
@@ -597,8 +589,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.ListXpnHostsProjectsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.ListXpnHosts. See the method
                 description for details.
 
@@ -625,19 +616,22 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListXpnHostsProjectsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListXpnHostsProjectsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListXpnHostsProjectsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListXpnHostsProjectsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListXpnHostsProjectsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -647,7 +641,9 @@ class ProjectsRestTransport(ProjectsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.XpnHostList.from_json(response.content)
+        return compute.XpnHostList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def move_disk(
         self,
@@ -659,8 +655,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.MoveDiskProjectRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.MoveDisk. See the method
                 description for details.
 
@@ -715,15 +710,14 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.MoveDiskProjectRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -733,7 +727,7 @@ class ProjectsRestTransport(ProjectsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def move_instance(
         self,
@@ -745,8 +739,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.MoveInstanceProjectRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.MoveInstance. See the method
                 description for details.
 
@@ -801,15 +794,14 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.MoveInstanceProjectRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -819,7 +811,7 @@ class ProjectsRestTransport(ProjectsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_common_instance_metadata(
         self,
@@ -832,8 +824,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.SetCommonInstanceMetadataProjectRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.SetCommonInstanceMetadata. See
                 the method description for details.
 
@@ -888,15 +879,14 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetCommonInstanceMetadataProjectRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -906,7 +896,7 @@ class ProjectsRestTransport(ProjectsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_default_network_tier(
         self,
@@ -918,8 +908,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.SetDefaultNetworkTierProjectRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.SetDefaultNetworkTier. See the
                 method description for details.
 
@@ -974,15 +963,14 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetDefaultNetworkTierProjectRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -992,7 +980,7 @@ class ProjectsRestTransport(ProjectsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_usage_export_bucket(
         self,
@@ -1004,8 +992,7 @@ class ProjectsRestTransport(ProjectsTransport):
 
         Args:
             request (~.compute.SetUsageExportBucketProjectRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Projects.SetUsageExportBucket. See the
                 method description for details.
 
@@ -1060,15 +1047,14 @@ class ProjectsRestTransport(ProjectsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetUsageExportBucketProjectRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -1078,7 +1064,7 @@ class ProjectsRestTransport(ProjectsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("ProjectsRestTransport",)
