@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.region_autoscalers import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import RegionAutoscalersTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import RegionAutoscalersRestTransport
 
@@ -217,7 +214,7 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RegionAutoscalersTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -362,7 +359,6 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
                 This corresponds to the ``autoscaler`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -414,10 +410,8 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteRegionAutoscalerRequest):
             request = compute.DeleteRegionAutoscalerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -470,7 +464,6 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
                 This corresponds to the ``autoscaler`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -517,10 +510,8 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRegionAutoscalerRequest):
             request = compute.GetRegionAutoscalerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -574,7 +565,6 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
                 This corresponds to the ``autoscaler_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -626,10 +616,8 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertRegionAutoscalerRequest):
             request = compute.InsertRegionAutoscalerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -677,7 +665,6 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -708,10 +695,8 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListRegionAutoscalersRequest):
             request = compute.ListRegionAutoscalersRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -771,7 +756,6 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
                 This corresponds to the ``autoscaler_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -823,10 +807,8 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchRegionAutoscalerRequest):
             request = compute.PatchRegionAutoscalerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -880,7 +862,6 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
                 This corresponds to the ``autoscaler_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -932,10 +913,8 @@ class RegionAutoscalersClient(metaclass=RegionAutoscalersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateRegionAutoscalerRequest):
             request = compute.UpdateRegionAutoscalerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
