@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.region_backend_services import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import RegionBackendServicesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import RegionBackendServicesRestTransport
 
@@ -217,7 +214,7 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RegionBackendServicesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -365,7 +362,6 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
                 This corresponds to the ``backend_service`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -417,10 +413,8 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteRegionBackendServiceRequest):
             request = compute.DeleteRegionBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -476,7 +470,6 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
                 This corresponds to the ``backend_service`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -525,10 +518,8 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRegionBackendServiceRequest):
             request = compute.GetRegionBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -590,7 +581,6 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
                 This corresponds to the ``resource_group_reference_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -619,10 +609,8 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetHealthRegionBackendServiceRequest):
             request = compute.GetHealthRegionBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -682,7 +670,6 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
                 This corresponds to the ``backend_service_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -734,10 +721,8 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertRegionBackendServiceRequest):
             request = compute.InsertRegionBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -786,7 +771,6 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -818,10 +802,8 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListRegionBackendServicesRequest):
             request = compute.ListRegionBackendServicesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -890,7 +872,6 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
                 This corresponds to the ``backend_service_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -944,10 +925,8 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchRegionBackendServiceRequest):
             request = compute.PatchRegionBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1012,7 +991,6 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
                 This corresponds to the ``backend_service_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1066,10 +1044,8 @@ class RegionBackendServicesClient(metaclass=RegionBackendServicesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateRegionBackendServiceRequest):
             request = compute.UpdateRegionBackendServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
