@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.region_disks import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import RegionDisksTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import RegionDisksRestTransport
 
@@ -213,7 +210,7 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RegionDisksTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -366,7 +363,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``region_disks_add_resource_policies_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -420,10 +416,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AddResourcePoliciesRegionDiskRequest):
             request = compute.AddResourcePoliciesRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -486,7 +480,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``snapshot_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -538,10 +531,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.CreateSnapshotRegionDiskRequest):
             request = compute.CreateSnapshotRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -600,7 +591,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``disk`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -652,10 +642,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteRegionDiskRequest):
             request = compute.DeleteRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -707,7 +695,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``disk`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -756,10 +743,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRegionDiskRequest):
             request = compute.GetRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -815,7 +800,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -893,10 +877,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicyRegionDiskRequest):
             request = compute.GetIamPolicyRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -948,7 +930,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``disk_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1000,10 +981,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertRegionDiskRequest):
             request = compute.InsertRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1049,7 +1028,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1080,10 +1058,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListRegionDisksRequest):
             request = compute.ListRegionDisksRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1146,7 +1122,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``region_disks_remove_resource_policies_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1205,10 +1180,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.RemoveResourcePoliciesRegionDiskRequest):
             request = compute.RemoveResourcePoliciesRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1269,7 +1242,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``region_disks_resize_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1323,10 +1295,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ResizeRegionDiskRequest):
             request = compute.ResizeRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1392,7 +1362,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``region_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1472,10 +1441,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicyRegionDiskRequest):
             request = compute.SetIamPolicyRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1538,7 +1505,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``region_set_labels_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1592,10 +1558,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetLabelsRegionDiskRequest):
             request = compute.SetLabelsRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1661,7 +1625,6 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1690,10 +1653,8 @@ class RegionDisksClient(metaclass=RegionDisksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsRegionDiskRequest):
             request = compute.TestIamPermissionsRegionDiskRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
