@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import RegionDisksTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class RegionDisksRestTransport(RegionDisksTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class RegionDisksRestTransport(RegionDisksTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def add_resource_policies(
         self,
@@ -103,8 +103,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.AddResourcePoliciesRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.AddResourcePolicies. See the
                 method description for details.
 
@@ -162,15 +161,14 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.AddResourcePoliciesRegionDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -180,7 +178,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def create_snapshot(
         self,
@@ -192,8 +190,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.CreateSnapshotRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.CreateSnapshot. See the
                 method description for details.
 
@@ -251,15 +248,14 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.CreateSnapshotRegionDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -269,7 +265,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def delete(
         self,
@@ -281,8 +277,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.DeleteRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.Delete. See the method
                 description for details.
 
@@ -333,25 +328,24 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteRegionDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -363,8 +357,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.GetRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.Get. See the method
                 description for details.
 
@@ -408,22 +401,21 @@ class RegionDisksRestTransport(RegionDisksTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Disk.from_json(response.content)
+        return compute.Disk.from_json(response.content, ignore_unknown_fields=True)
 
     def get_iam_policy(
         self,
@@ -435,8 +427,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.GetIamPolicyRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.GetIamPolicy. See the method
                 description for details.
 
@@ -509,25 +500,29 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "optionsRequestedPolicyVersion": request.options_requested_policy_version,
-        }
+        query_params = {}
+        if (
+            compute.GetIamPolicyRegionDiskRequest.options_requested_policy_version
+            in request
+        ):
+            query_params[
+                "optionsRequestedPolicyVersion"
+            ] = request.options_requested_policy_version
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def insert(
         self,
@@ -539,8 +534,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.InsertRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.Insert. See the method
                 description for details.
 
@@ -595,16 +589,16 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-            "sourceImage": request.source_image,
-        }
+        query_params = {}
+        if compute.InsertRegionDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+        if compute.InsertRegionDiskRequest.source_image in request:
+            query_params["sourceImage"] = request.source_image
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -614,7 +608,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -626,8 +620,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.ListRegionDisksRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.List. See the method
                 description for details.
 
@@ -647,29 +640,32 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListRegionDisksRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListRegionDisksRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListRegionDisksRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListRegionDisksRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListRegionDisksRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.DiskList.from_json(response.content)
+        return compute.DiskList.from_json(response.content, ignore_unknown_fields=True)
 
     def remove_resource_policies(
         self,
@@ -681,8 +677,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.RemoveResourcePoliciesRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.RemoveResourcePolicies. See
                 the method description for details.
 
@@ -740,15 +735,14 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.RemoveResourcePoliciesRegionDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -758,7 +752,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def resize(
         self,
@@ -770,8 +764,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.ResizeRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.Resize. See the method
                 description for details.
 
@@ -829,15 +822,14 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.ResizeRegionDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -847,7 +839,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_iam_policy(
         self,
@@ -859,8 +851,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.SetIamPolicyRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.SetIamPolicy. See the method
                 description for details.
 
@@ -941,12 +932,11 @@ class RegionDisksRestTransport(RegionDisksTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -956,7 +946,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def set_labels(
         self,
@@ -968,8 +958,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.SetLabelsRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.SetLabels. See the method
                 description for details.
 
@@ -1027,15 +1016,14 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetLabelsRegionDiskRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -1045,7 +1033,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def test_iam_permissions(
         self,
@@ -1057,8 +1045,7 @@ class RegionDisksRestTransport(RegionDisksTransport):
 
         Args:
             request (~.compute.TestIamPermissionsRegionDiskRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionDisks.TestIamPermissions. See the
                 method description for details.
 
@@ -1089,12 +1076,11 @@ class RegionDisksRestTransport(RegionDisksTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -1104,7 +1090,9 @@ class RegionDisksRestTransport(RegionDisksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.TestPermissionsResponse.from_json(response.content)
+        return compute.TestPermissionsResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
 
 __all__ = ("RegionDisksRestTransport",)
