@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.region_health_checks import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import RegionHealthChecksTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import RegionHealthChecksRestTransport
 
@@ -217,7 +214,7 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RegionHealthChecksTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -364,7 +361,6 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
                 This corresponds to the ``health_check`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -416,10 +412,8 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteRegionHealthCheckRequest):
             request = compute.DeleteRegionHealthCheckRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -476,7 +470,6 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
                 This corresponds to the ``health_check`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -531,10 +524,8 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRegionHealthCheckRequest):
             request = compute.GetRegionHealthCheckRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -588,7 +579,6 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
                 This corresponds to the ``health_check_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -640,10 +630,8 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertRegionHealthCheckRequest):
             request = compute.InsertRegionHealthCheckRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -691,7 +679,6 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -723,10 +710,8 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListRegionHealthChecksRequest):
             request = compute.ListRegionHealthChecksRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -794,7 +779,6 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
                 This corresponds to the ``health_check_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -848,10 +832,8 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchRegionHealthCheckRequest):
             request = compute.PatchRegionHealthCheckRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -915,7 +897,6 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
                 This corresponds to the ``health_check_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -969,10 +950,8 @@ class RegionHealthChecksClient(metaclass=RegionHealthChecksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateRegionHealthCheckRequest):
             request = compute.UpdateRegionHealthCheckRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
