@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,20 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import abc
-import typing
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
+import packaging.version
 import pkg_resources
 
-from google import auth  # type: ignore
-from google.api_core import exceptions  # type: ignore
+import google.auth  # type: ignore
+import google.api_core  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 
 from google.cloud.compute_v1.types import compute
 
-
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution("google-cloud-compute",).version,
@@ -35,6 +34,17 @@ try:
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
+try:
+    # google.auth.__version__ was added in 1.26.0
+    _GOOGLE_AUTH_VERSION = google.auth.__version__
+except AttributeError:
+    try:  # try pkg_resources if it is available
+        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
+    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
+        _GOOGLE_AUTH_VERSION = None
+
+_API_CORE_VERSION = google.api_core.__version__
+
 
 class RegionInstanceGroupManagersTransport(abc.ABC):
     """Abstract transport class for RegionInstanceGroupManagers."""
@@ -44,21 +54,24 @@ class RegionInstanceGroupManagersTransport(abc.ABC):
         "https://www.googleapis.com/auth/cloud-platform",
     )
 
+    DEFAULT_HOST: str = "compute.googleapis.com"
+
     def __init__(
         self,
         *,
-        host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
-        credentials_file: typing.Optional[str] = None,
-        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
-        quota_project_id: typing.Optional[str] = None,
+        host: str = DEFAULT_HOST,
+        credentials: ga_credentials.Credentials = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -67,13 +80,13 @@ class RegionInstanceGroupManagersTransport(abc.ABC):
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
                 This argument is mutually exclusive with credentials.
-            scope (Optional[Sequence[str]]): A list of scopes.
+            scopes (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
@@ -81,28 +94,75 @@ class RegionInstanceGroupManagersTransport(abc.ABC):
             host += ":443"
         self._host = host
 
+        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
+
+        # Save the scopes.
+        self._scopes = scopes or self.AUTH_SCOPES
+
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
-            raise exceptions.DuplicateCredentialArgs(
+            raise core_exceptions.DuplicateCredentialArgs(
                 "'credentials_file' and 'credentials' are mutually exclusive"
             )
 
         if credentials_file is not None:
-            credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.load_credentials_from_file(
+                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
-            credentials, _ = auth.default(
-                scopes=scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.default(
+                **scopes_kwargs, quota_project_id=quota_project_id
             )
 
         # Save the credentials.
         self._credentials = credentials
 
-        # Lifted into its own function so it can be stubbed out during tests.
-        self._prep_wrapped_messages(client_info)
+    # TODO(busunkim): These two class methods are in the base transport
+    # to avoid duplicating code across the transport classes. These functions
+    # should be deleted once the minimum required versions of google-api-core
+    # and google-auth are increased.
+
+    # TODO: Remove this function once google-auth >= 1.25.0 is required
+    @classmethod
+    def _get_scopes_kwargs(
+        cls, host: str, scopes: Optional[Sequence[str]]
+    ) -> Dict[str, Optional[Sequence[str]]]:
+        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""
+
+        scopes_kwargs = {}
+
+        if _GOOGLE_AUTH_VERSION and (
+            packaging.version.parse(_GOOGLE_AUTH_VERSION)
+            >= packaging.version.parse("1.25.0")
+        ):
+            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
+        else:
+            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
+
+        return scopes_kwargs
+
+    # TODO: Remove this function once google-api-core >= 1.26.0 is required
+    @classmethod
+    def _get_self_signed_jwt_kwargs(
+        cls, host: str, scopes: Optional[Sequence[str]]
+    ) -> Dict[str, Union[Optional[Sequence[str]], str]]:
+        """Returns kwargs to pass to grpc_helpers.create_channel depending on the google-api-core version"""
+
+        self_signed_jwt_kwargs: Dict[str, Union[Optional[Sequence[str]], str]] = {}
+
+        if _API_CORE_VERSION and (
+            packaging.version.parse(_API_CORE_VERSION)
+            >= packaging.version.parse("1.26.0")
+        ):
+            self_signed_jwt_kwargs["default_scopes"] = cls.AUTH_SCOPES
+            self_signed_jwt_kwargs["scopes"] = scopes
+            self_signed_jwt_kwargs["default_host"] = cls.DEFAULT_HOST
+        else:
+            self_signed_jwt_kwargs["scopes"] = scopes or cls.AUTH_SCOPES
+
+        return self_signed_jwt_kwargs
 
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
@@ -183,85 +243,83 @@ class RegionInstanceGroupManagersTransport(abc.ABC):
     @property
     def abandon_instances(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.AbandonInstancesRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def apply_updates_to_instances(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def create_instances(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.CreateInstancesRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def delete(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.DeleteRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def delete_instances(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.DeleteInstancesRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def delete_per_instance_configs(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.DeletePerInstanceConfigsRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def get(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.GetRegionInstanceGroupManagerRequest],
-        typing.Union[
-            compute.InstanceGroupManager, typing.Awaitable[compute.InstanceGroupManager]
-        ],
+        Union[compute.InstanceGroupManager, Awaitable[compute.InstanceGroupManager]],
     ]:
         raise NotImplementedError()
 
     @property
     def insert(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.InsertRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def list(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.ListRegionInstanceGroupManagersRequest],
-        typing.Union[
+        Union[
             compute.RegionInstanceGroupManagerList,
-            typing.Awaitable[compute.RegionInstanceGroupManagerList],
+            Awaitable[compute.RegionInstanceGroupManagerList],
         ],
     ]:
         raise NotImplementedError()
@@ -269,11 +327,11 @@ class RegionInstanceGroupManagersTransport(abc.ABC):
     @property
     def list_errors(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.ListErrorsRegionInstanceGroupManagersRequest],
-        typing.Union[
+        Union[
             compute.RegionInstanceGroupManagersListErrorsResponse,
-            typing.Awaitable[compute.RegionInstanceGroupManagersListErrorsResponse],
+            Awaitable[compute.RegionInstanceGroupManagersListErrorsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -281,11 +339,11 @@ class RegionInstanceGroupManagersTransport(abc.ABC):
     @property
     def list_managed_instances(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.ListManagedInstancesRegionInstanceGroupManagersRequest],
-        typing.Union[
+        Union[
             compute.RegionInstanceGroupManagersListInstancesResponse,
-            typing.Awaitable[compute.RegionInstanceGroupManagersListInstancesResponse],
+            Awaitable[compute.RegionInstanceGroupManagersListInstancesResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -293,13 +351,11 @@ class RegionInstanceGroupManagersTransport(abc.ABC):
     @property
     def list_per_instance_configs(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.ListPerInstanceConfigsRegionInstanceGroupManagersRequest],
-        typing.Union[
+        Union[
             compute.RegionInstanceGroupManagersListInstanceConfigsResp,
-            typing.Awaitable[
-                compute.RegionInstanceGroupManagersListInstanceConfigsResp
-            ],
+            Awaitable[compute.RegionInstanceGroupManagersListInstanceConfigsResp],
         ],
     ]:
         raise NotImplementedError()
@@ -307,63 +363,63 @@ class RegionInstanceGroupManagersTransport(abc.ABC):
     @property
     def patch(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.PatchRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def patch_per_instance_configs(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.PatchPerInstanceConfigsRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def recreate_instances(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.RecreateInstancesRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def resize(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.ResizeRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def set_instance_template(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.SetInstanceTemplateRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def set_target_pools(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.SetTargetPoolsRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def update_per_instance_configs(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [compute.UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest],
-        typing.Union[compute.Operation, typing.Awaitable[compute.Operation]],
+        Union[compute.Operation, Awaitable[compute.Operation]],
     ]:
         raise NotImplementedError()
 
