@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.region_instance_groups import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import RegionInstanceGroupsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import RegionInstanceGroupsRestTransport
 
@@ -217,7 +214,7 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RegionInstanceGroupsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -364,7 +361,6 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
                 This corresponds to the ``instance_group`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -413,10 +409,8 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRegionInstanceGroupRequest):
             request = compute.GetRegionInstanceGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -464,7 +458,6 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -496,10 +489,8 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListRegionInstanceGroupsRequest):
             request = compute.ListRegionInstanceGroupsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -568,7 +559,6 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
                 This corresponds to the ``region_instance_groups_list_instances_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -605,10 +595,8 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListInstancesRegionInstanceGroupsRequest):
             request = compute.ListInstancesRegionInstanceGroupsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -680,7 +668,6 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
                 This corresponds to the ``region_instance_groups_set_named_ports_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -739,10 +726,8 @@ class RegionInstanceGroupsClient(metaclass=RegionInstanceGroupsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetNamedPortsRegionInstanceGroupRequest):
             request = compute.SetNamedPortsRegionInstanceGroupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
