@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.region_notification_endpoints import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import RegionNotificationEndpointsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import RegionNotificationEndpointsRestTransport
 
@@ -219,7 +216,7 @@ class RegionNotificationEndpointsClient(
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RegionNotificationEndpointsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -367,7 +364,6 @@ class RegionNotificationEndpointsClient(
                 This corresponds to the ``notification_endpoint`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -419,10 +415,8 @@ class RegionNotificationEndpointsClient(
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteRegionNotificationEndpointRequest):
             request = compute.DeleteRegionNotificationEndpointRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -478,7 +472,6 @@ class RegionNotificationEndpointsClient(
                 This corresponds to the ``notification_endpoint`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -516,10 +509,8 @@ class RegionNotificationEndpointsClient(
         # there are no flattened fields.
         if not isinstance(request, compute.GetRegionNotificationEndpointRequest):
             request = compute.GetRegionNotificationEndpointRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -574,7 +565,6 @@ class RegionNotificationEndpointsClient(
                 This corresponds to the ``notification_endpoint_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -626,10 +616,8 @@ class RegionNotificationEndpointsClient(
         # there are no flattened fields.
         if not isinstance(request, compute.InsertRegionNotificationEndpointRequest):
             request = compute.InsertRegionNotificationEndpointRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -677,7 +665,6 @@ class RegionNotificationEndpointsClient(
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -707,10 +694,8 @@ class RegionNotificationEndpointsClient(
         # there are no flattened fields.
         if not isinstance(request, compute.ListRegionNotificationEndpointsRequest):
             request = compute.ListRegionNotificationEndpointsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
