@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.region_operations import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import RegionOperationsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import RegionOperationsRestTransport
 
@@ -215,7 +212,7 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RegionOperationsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -361,7 +358,6 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
                 This corresponds to the ``operation`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -391,10 +387,8 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteRegionOperationRequest):
             request = compute.DeleteRegionOperationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -448,7 +442,6 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
                 This corresponds to the ``operation`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -500,10 +493,8 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRegionOperationRequest):
             request = compute.GetRegionOperationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -549,7 +540,6 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -581,10 +571,8 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListRegionOperationsRequest):
             request = compute.ListRegionOperationsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -655,7 +643,6 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
                 This corresponds to the ``operation`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -707,10 +694,8 @@ class RegionOperationsClient(metaclass=RegionOperationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.WaitRegionOperationRequest):
             request = compute.WaitRegionOperationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
