@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.region_url_maps import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import RegionUrlMapsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import RegionUrlMapsRestTransport
 
@@ -213,7 +210,7 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RegionUrlMapsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -360,7 +357,6 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
                 This corresponds to the ``url_map`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -412,10 +408,8 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteRegionUrlMapRequest):
             request = compute.DeleteRegionUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -471,7 +465,6 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
                 This corresponds to the ``url_map`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -531,10 +524,8 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRegionUrlMapRequest):
             request = compute.GetRegionUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -588,7 +579,6 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
                 This corresponds to the ``url_map_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -640,10 +630,8 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertRegionUrlMapRequest):
             request = compute.InsertRegionUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -691,7 +679,6 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -722,10 +709,8 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListRegionUrlMapsRequest):
             request = compute.ListRegionUrlMapsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -791,7 +776,6 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
                 This corresponds to the ``url_map_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -843,10 +827,8 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchRegionUrlMapRequest):
             request = compute.PatchRegionUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -910,7 +892,6 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
                 This corresponds to the ``url_map_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -962,10 +943,8 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateRegionUrlMapRequest):
             request = compute.UpdateRegionUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1030,7 +1009,6 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
                 This corresponds to the ``region_url_maps_validate_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1059,10 +1037,8 @@ class RegionUrlMapsClient(metaclass=RegionUrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ValidateRegionUrlMapRequest):
             request = compute.ValidateRegionUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
