@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import RegionUrlMapsTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def delete(
         self,
@@ -103,8 +103,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         Args:
             request (~.compute.DeleteRegionUrlMapRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionUrlMaps.Delete. See the method
                 description for details.
 
@@ -155,25 +154,24 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteRegionUrlMapRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -185,8 +183,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         Args:
             request (~.compute.GetRegionUrlMapRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionUrlMaps.Get. See the method
                 description for details.
 
@@ -242,22 +239,21 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.UrlMap.from_json(response.content)
+        return compute.UrlMap.from_json(response.content, ignore_unknown_fields=True)
 
     def insert(
         self,
@@ -269,8 +265,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         Args:
             request (~.compute.InsertRegionUrlMapRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionUrlMaps.Insert. See the method
                 description for details.
 
@@ -325,15 +320,14 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertRegionUrlMapRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -343,7 +337,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -355,8 +349,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         Args:
             request (~.compute.ListRegionUrlMapsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionUrlMaps.List. See the method
                 description for details.
 
@@ -376,29 +369,34 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListRegionUrlMapsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListRegionUrlMapsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListRegionUrlMapsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListRegionUrlMapsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListRegionUrlMapsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.UrlMapList.from_json(response.content)
+        return compute.UrlMapList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def patch(
         self,
@@ -410,8 +408,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         Args:
             request (~.compute.PatchRegionUrlMapRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionUrlMaps.Patch. See the method
                 description for details.
 
@@ -469,15 +466,14 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.PatchRegionUrlMapRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -487,7 +483,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def update(
         self,
@@ -499,8 +495,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         Args:
             request (~.compute.UpdateRegionUrlMapRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionUrlMaps.Update. See the method
                 description for details.
 
@@ -558,15 +553,14 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.UpdateRegionUrlMapRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -576,7 +570,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def validate(
         self,
@@ -588,8 +582,7 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
 
         Args:
             request (~.compute.ValidateRegionUrlMapRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 RegionUrlMaps.Validate. See the method
                 description for details.
 
@@ -620,12 +613,11 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -635,7 +627,9 @@ class RegionUrlMapsRestTransport(RegionUrlMapsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.UrlMapsValidateResponse.from_json(response.content)
+        return compute.UrlMapsValidateResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
 
 __all__ = ("RegionUrlMapsRestTransport",)
