@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.reservations import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import ReservationsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import ReservationsRestTransport
 
@@ -213,7 +210,7 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ReservationsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -344,7 +341,6 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -375,10 +371,8 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListReservationsRequest):
             request = compute.AggregatedListReservationsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -431,7 +425,6 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
                 This corresponds to the ``reservation`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -483,10 +476,8 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteReservationRequest):
             request = compute.DeleteReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -538,7 +529,6 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
                 This corresponds to the ``reservation`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -570,10 +560,8 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetReservationRequest):
             request = compute.GetReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -629,7 +617,6 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -707,10 +694,8 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicyReservationRequest):
             request = compute.GetIamPolicyReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -762,7 +747,6 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
                 This corresponds to the ``reservation_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -814,10 +798,8 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertReservationRequest):
             request = compute.InsertReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -863,7 +845,6 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
                 This corresponds to the ``zone`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -893,10 +874,8 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListReservationsRequest):
             request = compute.ListReservationsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -959,7 +938,6 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
                 This corresponds to the ``reservations_resize_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1013,10 +991,8 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ResizeReservationRequest):
             request = compute.ResizeReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1082,7 +1058,6 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
                 This corresponds to the ``zone_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1162,10 +1137,8 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicyReservationRequest):
             request = compute.SetIamPolicyReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -1231,7 +1204,6 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1260,10 +1232,8 @@ class ReservationsClient(metaclass=ReservationsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsReservationRequest):
             request = compute.TestIamPermissionsReservationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
