@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import ReservationsTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class ReservationsRestTransport(ReservationsTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class ReservationsRestTransport(ReservationsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class ReservationsRestTransport(ReservationsTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def aggregated_list(
         self,
@@ -103,8 +103,7 @@ class ReservationsRestTransport(ReservationsTransport):
 
         Args:
             request (~.compute.AggregatedListReservationsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Reservations.AggregatedList. See the
                 method description for details.
 
@@ -124,30 +123,36 @@ class ReservationsRestTransport(ReservationsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListReservationsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.AggregatedListReservationsRequest.include_all_scopes in request:
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListReservationsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListReservationsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListReservationsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.AggregatedListReservationsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.ReservationAggregatedList.from_json(response.content)
+        return compute.ReservationAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def delete(
         self,
@@ -159,8 +164,7 @@ class ReservationsRestTransport(ReservationsTransport):
 
         Args:
             request (~.compute.DeleteReservationRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Reservations.Delete. See the method
                 description for details.
 
@@ -211,25 +215,24 @@ class ReservationsRestTransport(ReservationsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteReservationRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -241,8 +244,7 @@ class ReservationsRestTransport(ReservationsTransport):
 
         Args:
             request (~.compute.GetReservationRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Reservations.Get. See the method
                 description for details.
 
@@ -271,22 +273,23 @@ class ReservationsRestTransport(ReservationsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Reservation.from_json(response.content)
+        return compute.Reservation.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def get_iam_policy(
         self,
@@ -298,8 +301,7 @@ class ReservationsRestTransport(ReservationsTransport):
 
         Args:
             request (~.compute.GetIamPolicyReservationRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Reservations.GetIamPolicy. See the
                 method description for details.
 
@@ -372,25 +374,29 @@ class ReservationsRestTransport(ReservationsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "optionsRequestedPolicyVersion": request.options_requested_policy_version,
-        }
+        query_params = {}
+        if (
+            compute.GetIamPolicyReservationRequest.options_requested_policy_version
+            in request
+        ):
+            query_params[
+                "optionsRequestedPolicyVersion"
+            ] = request.options_requested_policy_version
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def insert(
         self,
@@ -402,8 +408,7 @@ class ReservationsRestTransport(ReservationsTransport):
 
         Args:
             request (~.compute.InsertReservationRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Reservations.Insert. See the method
                 description for details.
 
@@ -458,15 +463,14 @@ class ReservationsRestTransport(ReservationsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertReservationRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -476,7 +480,7 @@ class ReservationsRestTransport(ReservationsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -488,8 +492,7 @@ class ReservationsRestTransport(ReservationsTransport):
 
         Args:
             request (~.compute.ListReservationsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Reservations.List. See the method
                 description for details.
 
@@ -509,29 +512,34 @@ class ReservationsRestTransport(ReservationsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListReservationsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListReservationsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListReservationsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListReservationsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListReservationsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.ReservationList.from_json(response.content)
+        return compute.ReservationList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def resize(
         self,
@@ -543,8 +551,7 @@ class ReservationsRestTransport(ReservationsTransport):
 
         Args:
             request (~.compute.ResizeReservationRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Reservations.Resize. See the method
                 description for details.
 
@@ -602,15 +609,14 @@ class ReservationsRestTransport(ReservationsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.ResizeReservationRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -620,7 +626,7 @@ class ReservationsRestTransport(ReservationsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_iam_policy(
         self,
@@ -632,8 +638,7 @@ class ReservationsRestTransport(ReservationsTransport):
 
         Args:
             request (~.compute.SetIamPolicyReservationRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Reservations.SetIamPolicy. See the
                 method description for details.
 
@@ -714,12 +719,11 @@ class ReservationsRestTransport(ReservationsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -729,7 +733,7 @@ class ReservationsRestTransport(ReservationsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def test_iam_permissions(
         self,
@@ -741,8 +745,7 @@ class ReservationsRestTransport(ReservationsTransport):
 
         Args:
             request (~.compute.TestIamPermissionsReservationRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Reservations.TestIamPermissions. See the
                 method description for details.
 
@@ -773,12 +776,11 @@ class ReservationsRestTransport(ReservationsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -788,7 +790,9 @@ class ReservationsRestTransport(ReservationsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.TestPermissionsResponse.from_json(response.content)
+        return compute.TestPermissionsResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
 
 __all__ = ("ReservationsRestTransport",)
