@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.resource_policies import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import ResourcePoliciesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import ResourcePoliciesRestTransport
 
@@ -215,7 +212,7 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ResourcePoliciesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -346,7 +343,6 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -377,10 +373,8 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListResourcePoliciesRequest):
             request = compute.AggregatedListResourcePoliciesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -435,7 +429,6 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
                 This corresponds to the ``resource_policy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -487,10 +480,8 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteResourcePolicyRequest):
             request = compute.DeleteResourcePolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -544,7 +535,6 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
                 This corresponds to the ``resource_policy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -577,10 +567,8 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetResourcePolicyRequest):
             request = compute.GetResourcePolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -636,7 +624,6 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -714,10 +701,8 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicyResourcePolicyRequest):
             request = compute.GetIamPolicyResourcePolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -768,7 +753,6 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
                 This corresponds to the ``resource_policy_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -820,10 +804,8 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertResourcePolicyRequest):
             request = compute.InsertResourcePolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -870,7 +852,6 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -900,10 +881,8 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListResourcePoliciesRequest):
             request = compute.ListResourcePoliciesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -969,7 +948,6 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
                 This corresponds to the ``region_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1049,10 +1027,8 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicyResourcePolicyRequest):
             request = compute.SetIamPolicyResourcePolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1118,7 +1094,6 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1147,10 +1122,8 @@ class ResourcePoliciesClient(metaclass=ResourcePoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsResourcePolicyRequest):
             request = compute.TestIamPermissionsResourcePolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
