@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.routers import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import RoutersTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import RoutersRestTransport
 
@@ -213,7 +210,7 @@ class RoutersClient(metaclass=RoutersClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RoutersTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -344,7 +341,6 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -375,10 +371,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListRoutersRequest):
             request = compute.AggregatedListRoutersRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -432,7 +426,6 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 This corresponds to the ``router`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -484,10 +477,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteRouterRequest):
             request = compute.DeleteRouterRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -540,7 +531,6 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 This corresponds to the ``router`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -570,10 +560,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRouterRequest):
             request = compute.GetRouterRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -628,7 +616,6 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 This corresponds to the ``router`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -660,10 +647,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetNatMappingInfoRoutersRequest):
             request = compute.GetNatMappingInfoRoutersRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -721,7 +706,6 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 This corresponds to the ``router`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -748,10 +732,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRouterStatusRouterRequest):
             request = compute.GetRouterStatusRouterRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -802,7 +784,6 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 This corresponds to the ``router_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -854,10 +835,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertRouterRequest):
             request = compute.InsertRouterRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -902,7 +881,6 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -933,10 +911,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListRoutersRequest):
             request = compute.ListRoutersRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -999,7 +975,6 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 This corresponds to the ``router_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1051,10 +1026,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchRouterRequest):
             request = compute.PatchRouterRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1114,7 +1087,6 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 This corresponds to the ``router_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1141,10 +1113,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PreviewRouterRequest):
             request = compute.PreviewRouterRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1209,7 +1179,6 @@ class RoutersClient(metaclass=RoutersClientMeta):
                 This corresponds to the ``router_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1261,10 +1230,8 @@ class RoutersClient(metaclass=RoutersClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateRouterRequest):
             request = compute.UpdateRouterRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
