@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.routes import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import RoutesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import RoutesRestTransport
 
@@ -213,7 +210,7 @@ class RoutesClient(metaclass=RoutesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RoutesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -349,7 +346,6 @@ class RoutesClient(metaclass=RoutesClientMeta):
                 This corresponds to the ``route`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -401,10 +397,8 @@ class RoutesClient(metaclass=RoutesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteRouteRequest):
             request = compute.DeleteRouteRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if route is not None:
@@ -447,7 +441,6 @@ class RoutesClient(metaclass=RoutesClientMeta):
                 This corresponds to the ``route`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -481,10 +474,8 @@ class RoutesClient(metaclass=RoutesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRouteRequest):
             request = compute.GetRouteRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if route is not None:
@@ -527,7 +518,6 @@ class RoutesClient(metaclass=RoutesClientMeta):
                 This corresponds to the ``route_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -579,10 +569,8 @@ class RoutesClient(metaclass=RoutesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertRouteRequest):
             request = compute.InsertRouteRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if route_resource is not None:
@@ -619,7 +607,6 @@ class RoutesClient(metaclass=RoutesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -650,10 +637,8 @@ class RoutesClient(metaclass=RoutesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListRoutesRequest):
             request = compute.ListRoutesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
