@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.security_policies import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import SecurityPoliciesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import SecurityPoliciesRestTransport
 
@@ -215,7 +212,7 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, SecurityPoliciesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -360,7 +357,6 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 This corresponds to the ``security_policy_rule_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -414,10 +410,8 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AddRuleSecurityPolicyRequest):
             request = compute.AddRuleSecurityPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if security_policy is not None:
@@ -464,7 +458,6 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 This corresponds to the ``security_policy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -516,10 +509,8 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteSecurityPolicyRequest):
             request = compute.DeleteSecurityPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if security_policy is not None:
@@ -563,7 +554,6 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 This corresponds to the ``security_policy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -598,10 +588,8 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetSecurityPolicyRequest):
             request = compute.GetSecurityPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if security_policy is not None:
@@ -646,7 +634,6 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 This corresponds to the ``security_policy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -677,10 +664,8 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetRuleSecurityPolicyRequest):
             request = compute.GetRuleSecurityPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if security_policy is not None:
@@ -724,7 +709,6 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 This corresponds to the ``security_policy_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -776,10 +760,8 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertSecurityPolicyRequest):
             request = compute.InsertSecurityPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if security_policy_resource is not None:
@@ -817,7 +799,6 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -847,10 +828,8 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListSecurityPoliciesRequest):
             request = compute.ListSecurityPoliciesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -892,7 +871,6 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -923,10 +901,8 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
             request = compute.ListPreconfiguredExpressionSetsSecurityPoliciesRequest(
                 request
             )
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -980,7 +956,6 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 This corresponds to the ``security_policy_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1032,10 +1007,8 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchSecurityPolicyRequest):
             request = compute.PatchSecurityPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if security_policy is not None:
@@ -1088,7 +1061,6 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 This corresponds to the ``security_policy_rule_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1142,10 +1114,8 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchRuleSecurityPolicyRequest):
             request = compute.PatchRuleSecurityPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if security_policy is not None:
@@ -1192,7 +1162,6 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
                 This corresponds to the ``security_policy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1244,10 +1213,8 @@ class SecurityPoliciesClient(metaclass=SecurityPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.RemoveRuleSecurityPolicyRequest):
             request = compute.RemoveRuleSecurityPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if security_policy is not None:
