@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import SecurityPoliciesTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def add_rule(
         self,
@@ -103,8 +103,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         Args:
             request (~.compute.AddRuleSecurityPolicyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 SecurityPolicies.AddRule. See the method
                 description for details.
 
@@ -162,12 +161,11 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -177,7 +175,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def delete(
         self,
@@ -189,8 +187,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         Args:
             request (~.compute.DeleteSecurityPolicyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 SecurityPolicies.Delete. See the method
                 description for details.
 
@@ -240,25 +237,24 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteSecurityPolicyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -270,8 +266,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         Args:
             request (~.compute.GetSecurityPolicyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 SecurityPolicies.Get. See the method
                 description for details.
 
@@ -301,22 +296,23 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.SecurityPolicy.from_json(response.content)
+        return compute.SecurityPolicy.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def get_rule(
         self,
@@ -328,8 +324,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         Args:
             request (~.compute.GetRuleSecurityPolicyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 SecurityPolicies.GetRule. See the method
                 description for details.
 
@@ -355,25 +350,26 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "priority": request.priority,
-        }
+        query_params = {}
+        if compute.GetRuleSecurityPolicyRequest.priority in request:
+            query_params["priority"] = request.priority
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.SecurityPolicyRule.from_json(response.content)
+        return compute.SecurityPolicyRule.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -385,8 +381,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         Args:
             request (~.compute.InsertSecurityPolicyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 SecurityPolicies.Insert. See the method
                 description for details.
 
@@ -441,15 +436,14 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertSecurityPolicyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -459,7 +453,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -471,8 +465,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         Args:
             request (~.compute.ListSecurityPoliciesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 SecurityPolicies.List. See the method
                 description for details.
 
@@ -492,29 +485,34 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListSecurityPoliciesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListSecurityPoliciesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListSecurityPoliciesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListSecurityPoliciesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListSecurityPoliciesRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.SecurityPolicyList.from_json(response.content)
+        return compute.SecurityPolicyList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def list_preconfigured_expression_sets(
         self,
@@ -527,8 +525,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         Args:
             request (~.compute.ListPreconfiguredExpressionSetsSecurityPoliciesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 SecurityPolicies.ListPreconfiguredExpressionSets.
                 See the method description for details.
 
@@ -548,30 +545,48 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if (
+            compute.ListPreconfiguredExpressionSetsSecurityPoliciesRequest.filter
+            in request
+        ):
+            query_params["filter"] = request.filter
+        if (
+            compute.ListPreconfiguredExpressionSetsSecurityPoliciesRequest.max_results
+            in request
+        ):
+            query_params["maxResults"] = request.max_results
+        if (
+            compute.ListPreconfiguredExpressionSetsSecurityPoliciesRequest.order_by
+            in request
+        ):
+            query_params["orderBy"] = request.order_by
+        if (
+            compute.ListPreconfiguredExpressionSetsSecurityPoliciesRequest.page_token
+            in request
+        ):
+            query_params["pageToken"] = request.page_token
+        if (
+            compute.ListPreconfiguredExpressionSetsSecurityPoliciesRequest.return_partial_success
+            in request
+        ):
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
         return compute.SecurityPoliciesListPreconfiguredExpressionSetsResponse.from_json(
-            response.content
+            response.content, ignore_unknown_fields=True
         )
 
     def patch(
@@ -584,8 +599,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         Args:
             request (~.compute.PatchSecurityPolicyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 SecurityPolicies.Patch. See the method
                 description for details.
 
@@ -642,15 +656,14 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.PatchSecurityPolicyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -660,7 +673,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def patch_rule(
         self,
@@ -672,8 +685,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         Args:
             request (~.compute.PatchRuleSecurityPolicyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 SecurityPolicies.PatchRule. See the
                 method description for details.
 
@@ -730,15 +742,14 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "priority": request.priority,
-        }
+        query_params = {}
+        if compute.PatchRuleSecurityPolicyRequest.priority in request:
+            query_params["priority"] = request.priority
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -748,7 +759,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def remove_rule(
         self,
@@ -760,8 +771,7 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         Args:
             request (~.compute.RemoveRuleSecurityPolicyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 SecurityPolicies.RemoveRule. See the
                 method description for details.
 
@@ -811,25 +821,24 @@ class SecurityPoliciesRestTransport(SecurityPoliciesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "priority": request.priority,
-        }
+        query_params = {}
+        if compute.RemoveRuleSecurityPolicyRequest.priority in request:
+            query_params["priority"] = request.priority
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url)
+        response = self._session.post(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("SecurityPoliciesRestTransport",)
