@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.snapshots import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import SnapshotsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import SnapshotsRestTransport
 
@@ -213,7 +210,7 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, SnapshotsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -358,7 +355,6 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
                 This corresponds to the ``snapshot`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -410,10 +406,8 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteSnapshotRequest):
             request = compute.DeleteSnapshotRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if snapshot is not None:
@@ -458,7 +452,6 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
                 This corresponds to the ``snapshot`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -491,10 +484,8 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetSnapshotRequest):
             request = compute.GetSnapshotRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if snapshot is not None:
@@ -540,7 +531,6 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -618,10 +608,8 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicySnapshotRequest):
             request = compute.GetIamPolicySnapshotRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
@@ -658,7 +646,6 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -690,10 +677,8 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListSnapshotsRequest):
             request = compute.ListSnapshotsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -749,7 +734,6 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
                 This corresponds to the ``global_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -829,10 +813,8 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicySnapshotRequest):
             request = compute.SetIamPolicySnapshotRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
@@ -888,7 +870,6 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
                 This corresponds to the ``global_set_labels_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -942,10 +923,8 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetLabelsSnapshotRequest):
             request = compute.SetLabelsSnapshotRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
@@ -1001,7 +980,6 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1030,10 +1008,8 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsSnapshotRequest):
             request = compute.TestIamPermissionsSnapshotRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if resource is not None:
