@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.ssl_certificates import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import SslCertificatesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import SslCertificatesRestTransport
 
@@ -215,7 +212,7 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, SslCertificatesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -349,7 +346,6 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -379,10 +375,8 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListSslCertificatesRequest):
             request = compute.AggregatedListSslCertificatesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -431,7 +425,6 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
                 This corresponds to the ``ssl_certificate`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -483,10 +476,8 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteSslCertificateRequest):
             request = compute.DeleteSslCertificateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if ssl_certificate is not None:
@@ -533,7 +524,6 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
                 This corresponds to the ``ssl_certificate`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -585,10 +575,8 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetSslCertificateRequest):
             request = compute.GetSslCertificateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if ssl_certificate is not None:
@@ -632,7 +620,6 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
                 This corresponds to the ``ssl_certificate_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -684,10 +671,8 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertSslCertificateRequest):
             request = compute.InsertSslCertificateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if ssl_certificate_resource is not None:
@@ -725,7 +710,6 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -757,10 +741,8 @@ class SslCertificatesClient(metaclass=SslCertificatesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListSslCertificatesRequest):
             request = compute.ListSslCertificatesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
