@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.ssl_policies import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import SslPoliciesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import SslPoliciesRestTransport
 
@@ -213,7 +210,7 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, SslPoliciesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -355,7 +352,6 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
                 This corresponds to the ``ssl_policy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -407,10 +403,8 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteSslPolicyRequest):
             request = compute.DeleteSslPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if ssl_policy is not None:
@@ -456,7 +450,6 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
                 This corresponds to the ``ssl_policy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -490,10 +483,8 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetSslPolicyRequest):
             request = compute.GetSslPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if ssl_policy is not None:
@@ -538,7 +529,6 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
                 This corresponds to the ``ssl_policy_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -590,10 +580,8 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertSslPolicyRequest):
             request = compute.InsertSslPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if ssl_policy_resource is not None:
@@ -631,7 +619,6 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -661,10 +648,8 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListSslPoliciesRequest):
             request = compute.ListSslPoliciesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -706,7 +691,6 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -733,10 +717,8 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListAvailableFeaturesSslPoliciesRequest):
             request = compute.ListAvailableFeaturesSslPoliciesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -787,7 +769,6 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
                 This corresponds to the ``ssl_policy_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -839,10 +820,8 @@ class SslPoliciesClient(metaclass=SslPoliciesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchSslPolicyRequest):
             request = compute.PatchSslPolicyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if ssl_policy is not None:
