@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.subnetworks import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import SubnetworksTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import SubnetworksRestTransport
 
@@ -213,7 +210,7 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, SubnetworksTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -344,7 +341,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -374,10 +370,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListSubnetworksRequest):
             request = compute.AggregatedListSubnetworksRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -434,7 +428,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``subnetwork`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -486,10 +479,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteSubnetworkRequest):
             request = compute.DeleteSubnetworkRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -551,7 +542,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``subnetworks_expand_ip_cidr_range_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -610,10 +600,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ExpandIpCidrRangeSubnetworkRequest):
             request = compute.ExpandIpCidrRangeSubnetworkRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -672,7 +660,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``subnetwork`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -707,10 +694,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetSubnetworkRequest):
             request = compute.GetSubnetworkRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -766,7 +751,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -844,10 +828,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetIamPolicySubnetworkRequest):
             request = compute.GetIamPolicySubnetworkRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -901,7 +883,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``subnetwork_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -953,10 +934,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertSubnetworkRequest):
             request = compute.InsertSubnetworkRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1004,7 +983,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1036,10 +1014,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListSubnetworksRequest):
             request = compute.ListSubnetworksRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1083,7 +1059,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1113,10 +1088,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListUsableSubnetworksRequest):
             request = compute.ListUsableSubnetworksRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -1183,7 +1156,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``subnetwork_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1235,10 +1207,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchSubnetworkRequest):
             request = compute.PatchSubnetworkRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1302,7 +1272,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``region_set_policy_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1382,10 +1351,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetIamPolicySubnetworkRequest):
             request = compute.SetIamPolicySubnetworkRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1450,7 +1417,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``subnetworks_set_private_ip_google_access_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1509,10 +1475,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetPrivateIpGoogleAccessSubnetworkRequest):
             request = compute.SetPrivateIpGoogleAccessSubnetworkRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1580,7 +1544,6 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1609,10 +1572,8 @@ class SubnetworksClient(metaclass=SubnetworksClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsSubnetworkRequest):
             request = compute.TestIamPermissionsSubnetworkRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
