@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import SubnetworksTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class SubnetworksRestTransport(SubnetworksTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class SubnetworksRestTransport(SubnetworksTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def aggregated_list(
         self,
@@ -103,8 +103,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.AggregatedListSubnetworksRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.AggregatedList. See the
                 method description for details.
 
@@ -124,30 +123,36 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListSubnetworksRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.AggregatedListSubnetworksRequest.include_all_scopes in request:
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListSubnetworksRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListSubnetworksRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListSubnetworksRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.AggregatedListSubnetworksRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.SubnetworkAggregatedList.from_json(response.content)
+        return compute.SubnetworkAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def delete(
         self,
@@ -159,8 +164,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.DeleteSubnetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.Delete. See the method
                 description for details.
 
@@ -211,25 +215,24 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteSubnetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def expand_ip_cidr_range(
         self,
@@ -241,8 +244,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.ExpandIpCidrRangeSubnetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.ExpandIpCidrRange. See the
                 method description for details.
 
@@ -300,15 +302,14 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.ExpandIpCidrRangeSubnetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -318,7 +319,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -330,8 +331,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.GetSubnetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.Get. See the method
                 description for details.
 
@@ -362,22 +362,23 @@ class SubnetworksRestTransport(SubnetworksTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Subnetwork.from_json(response.content)
+        return compute.Subnetwork.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def get_iam_policy(
         self,
@@ -389,8 +390,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.GetIamPolicySubnetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.GetIamPolicy. See the method
                 description for details.
 
@@ -463,25 +463,29 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "optionsRequestedPolicyVersion": request.options_requested_policy_version,
-        }
+        query_params = {}
+        if (
+            compute.GetIamPolicySubnetworkRequest.options_requested_policy_version
+            in request
+        ):
+            query_params[
+                "optionsRequestedPolicyVersion"
+            ] = request.options_requested_policy_version
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def insert(
         self,
@@ -493,8 +497,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.InsertSubnetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.Insert. See the method
                 description for details.
 
@@ -549,15 +552,14 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertSubnetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -567,7 +569,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -579,8 +581,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.ListSubnetworksRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.List. See the method
                 description for details.
 
@@ -602,29 +603,34 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListSubnetworksRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListSubnetworksRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListSubnetworksRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListSubnetworksRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListSubnetworksRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.SubnetworkList.from_json(response.content)
+        return compute.SubnetworkList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def list_usable(
         self,
@@ -636,8 +642,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.ListUsableSubnetworksRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.ListUsable. See the method
                 description for details.
 
@@ -657,29 +662,34 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListUsableSubnetworksRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListUsableSubnetworksRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListUsableSubnetworksRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListUsableSubnetworksRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListUsableSubnetworksRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.UsableSubnetworksAggregatedList.from_json(response.content)
+        return compute.UsableSubnetworksAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def patch(
         self,
@@ -691,8 +701,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.PatchSubnetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.Patch. See the method
                 description for details.
 
@@ -750,16 +759,16 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "drainTimeoutSeconds": request.drain_timeout_seconds,
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.PatchSubnetworkRequest.drain_timeout_seconds in request:
+            query_params["drainTimeoutSeconds"] = request.drain_timeout_seconds
+        if compute.PatchSubnetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -769,7 +778,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_iam_policy(
         self,
@@ -781,8 +790,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.SetIamPolicySubnetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.SetIamPolicy. See the method
                 description for details.
 
@@ -863,12 +871,11 @@ class SubnetworksRestTransport(SubnetworksTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -878,7 +885,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Policy.from_json(response.content)
+        return compute.Policy.from_json(response.content, ignore_unknown_fields=True)
 
     def set_private_ip_google_access(
         self,
@@ -891,8 +898,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.SetPrivateIpGoogleAccessSubnetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.SetPrivateIpGoogleAccess.
                 See the method description for details.
 
@@ -950,15 +956,14 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetPrivateIpGoogleAccessSubnetworkRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -968,7 +973,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def test_iam_permissions(
         self,
@@ -980,8 +985,7 @@ class SubnetworksRestTransport(SubnetworksTransport):
 
         Args:
             request (~.compute.TestIamPermissionsSubnetworkRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 Subnetworks.TestIamPermissions. See the
                 method description for details.
 
@@ -1012,12 +1016,11 @@ class SubnetworksRestTransport(SubnetworksTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -1027,7 +1030,9 @@ class SubnetworksRestTransport(SubnetworksTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.TestPermissionsResponse.from_json(response.content)
+        return compute.TestPermissionsResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
 
 __all__ = ("SubnetworksRestTransport",)
