@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.target_grpc_proxies import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import TargetGrpcProxiesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import TargetGrpcProxiesRestTransport
 
@@ -217,7 +214,7 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, TargetGrpcProxiesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -357,7 +354,6 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
                 This corresponds to the ``target_grpc_proxy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -409,10 +405,8 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteTargetGrpcProxyRequest):
             request = compute.DeleteTargetGrpcProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_grpc_proxy is not None:
@@ -458,7 +452,6 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
                 This corresponds to the ``target_grpc_proxy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -494,10 +487,8 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetTargetGrpcProxyRequest):
             request = compute.GetTargetGrpcProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_grpc_proxy is not None:
@@ -542,7 +533,6 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
                 This corresponds to the ``target_grpc_proxy_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -594,10 +584,8 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertTargetGrpcProxyRequest):
             request = compute.InsertTargetGrpcProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_grpc_proxy_resource is not None:
@@ -635,7 +623,6 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -665,10 +652,8 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListTargetGrpcProxiesRequest):
             request = compute.ListTargetGrpcProxiesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -726,7 +711,6 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
                 This corresponds to the ``target_grpc_proxy_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -780,10 +764,8 @@ class TargetGrpcProxiesClient(metaclass=TargetGrpcProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchTargetGrpcProxyRequest):
             request = compute.PatchTargetGrpcProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_grpc_proxy is not None:
