@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import TargetHttpProxiesTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def aggregated_list(
         self,
@@ -103,8 +103,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         Args:
             request (~.compute.AggregatedListTargetHttpProxiesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpProxies.AggregatedList. See
                 the method description for details.
 
@@ -124,30 +123,39 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListTargetHttpProxiesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.AggregatedListTargetHttpProxiesRequest.include_all_scopes in request:
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListTargetHttpProxiesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListTargetHttpProxiesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListTargetHttpProxiesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if (
+            compute.AggregatedListTargetHttpProxiesRequest.return_partial_success
+            in request
+        ):
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetHttpProxyAggregatedList.from_json(response.content)
+        return compute.TargetHttpProxyAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def delete(
         self,
@@ -159,8 +167,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         Args:
             request (~.compute.DeleteTargetHttpProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpProxies.Delete. See the method
                 description for details.
 
@@ -210,25 +217,24 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteTargetHttpProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -240,8 +246,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         Args:
             request (~.compute.GetTargetHttpProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpProxies.Get. See the method
                 description for details.
 
@@ -287,22 +292,23 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetHttpProxy.from_json(response.content)
+        return compute.TargetHttpProxy.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -314,8 +320,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         Args:
             request (~.compute.InsertTargetHttpProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpProxies.Insert. See the method
                 description for details.
 
@@ -370,15 +375,14 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertTargetHttpProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -388,7 +392,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -400,8 +404,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         Args:
             request (~.compute.ListTargetHttpProxiesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpProxies.List. See the method
                 description for details.
 
@@ -421,29 +424,34 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListTargetHttpProxiesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListTargetHttpProxiesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListTargetHttpProxiesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListTargetHttpProxiesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListTargetHttpProxiesRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetHttpProxyList.from_json(response.content)
+        return compute.TargetHttpProxyList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def patch(
         self,
@@ -455,8 +463,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         Args:
             request (~.compute.PatchTargetHttpProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpProxies.Patch. See the method
                 description for details.
 
@@ -513,15 +520,14 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.PatchTargetHttpProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -531,7 +537,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_url_map(
         self,
@@ -543,8 +549,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         Args:
             request (~.compute.SetUrlMapTargetHttpProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpProxies.SetUrlMap. See the
                 method description for details.
 
@@ -601,15 +606,14 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetUrlMapTargetHttpProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -619,7 +623,7 @@ class TargetHttpProxiesRestTransport(TargetHttpProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("TargetHttpProxiesRestTransport",)
