@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.target_https_proxies import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import TargetHttpsProxiesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import TargetHttpsProxiesRestTransport
 
@@ -217,7 +214,7 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, TargetHttpsProxiesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -351,7 +348,6 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -381,10 +377,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListTargetHttpsProxiesRequest):
             request = compute.AggregatedListTargetHttpsProxiesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -433,7 +427,6 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 This corresponds to the ``target_https_proxy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -485,10 +478,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteTargetHttpsProxyRequest):
             request = compute.DeleteTargetHttpsProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_https_proxy is not None:
@@ -535,7 +526,6 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 This corresponds to the ``target_https_proxy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -585,10 +575,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetTargetHttpsProxyRequest):
             request = compute.GetTargetHttpsProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_https_proxy is not None:
@@ -632,7 +620,6 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 This corresponds to the ``target_https_proxy_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -684,10 +671,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertTargetHttpsProxyRequest):
             request = compute.InsertTargetHttpsProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_https_proxy_resource is not None:
@@ -725,7 +710,6 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -757,10 +741,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListTargetHttpsProxiesRequest):
             request = compute.ListTargetHttpsProxiesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -816,7 +798,6 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 This corresponds to the ``target_https_proxies_set_quic_override_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -874,10 +855,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetQuicOverrideTargetHttpsProxyRequest):
             request = compute.SetQuicOverrideTargetHttpsProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_https_proxy is not None:
@@ -932,7 +911,6 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 This corresponds to the ``target_https_proxies_set_ssl_certificates_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -990,10 +968,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetSslCertificatesTargetHttpsProxyRequest):
             request = compute.SetSslCertificatesTargetHttpsProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_https_proxy is not None:
@@ -1054,7 +1030,6 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 This corresponds to the ``ssl_policy_reference_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1108,10 +1083,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetSslPolicyTargetHttpsProxyRequest):
             request = compute.SetSslPolicyTargetHttpsProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_https_proxy is not None:
@@ -1164,7 +1137,6 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 This corresponds to the ``url_map_reference_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1218,10 +1190,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetUrlMapTargetHttpsProxyRequest):
             request = compute.SetUrlMapTargetHttpsProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_https_proxy is not None:
