@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import TargetHttpsProxiesTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def aggregated_list(
         self,
@@ -103,8 +103,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         Args:
             request (~.compute.AggregatedListTargetHttpsProxiesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpsProxies.AggregatedList. See
                 the method description for details.
 
@@ -124,30 +123,42 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListTargetHttpsProxiesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if (
+            compute.AggregatedListTargetHttpsProxiesRequest.include_all_scopes
+            in request
+        ):
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListTargetHttpsProxiesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListTargetHttpsProxiesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListTargetHttpsProxiesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if (
+            compute.AggregatedListTargetHttpsProxiesRequest.return_partial_success
+            in request
+        ):
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetHttpsProxyAggregatedList.from_json(response.content)
+        return compute.TargetHttpsProxyAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def delete(
         self,
@@ -159,8 +170,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         Args:
             request (~.compute.DeleteTargetHttpsProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpsProxies.Delete. See the
                 method description for details.
 
@@ -210,25 +220,24 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteTargetHttpsProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -240,8 +249,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         Args:
             request (~.compute.GetTargetHttpsProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpsProxies.Get. See the method
                 description for details.
 
@@ -286,22 +294,23 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetHttpsProxy.from_json(response.content)
+        return compute.TargetHttpsProxy.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -313,8 +322,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         Args:
             request (~.compute.InsertTargetHttpsProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpsProxies.Insert. See the
                 method description for details.
 
@@ -369,15 +377,14 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertTargetHttpsProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -387,7 +394,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -399,8 +406,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         Args:
             request (~.compute.ListTargetHttpsProxiesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpsProxies.List. See the method
                 description for details.
 
@@ -422,29 +428,34 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListTargetHttpsProxiesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListTargetHttpsProxiesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListTargetHttpsProxiesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListTargetHttpsProxiesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListTargetHttpsProxiesRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetHttpsProxyList.from_json(response.content)
+        return compute.TargetHttpsProxyList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def set_quic_override(
         self,
@@ -456,8 +467,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         Args:
             request (~.compute.SetQuicOverrideTargetHttpsProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpsProxies.SetQuicOverride. See
                 the method description for details.
 
@@ -514,15 +524,14 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetQuicOverrideTargetHttpsProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -532,7 +541,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_ssl_certificates(
         self,
@@ -544,8 +553,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         Args:
             request (~.compute.SetSslCertificatesTargetHttpsProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpsProxies.SetSslCertificates.
                 See the method description for details.
 
@@ -602,15 +610,14 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetSslCertificatesTargetHttpsProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -620,7 +627,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_ssl_policy(
         self,
@@ -632,8 +639,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         Args:
             request (~.compute.SetSslPolicyTargetHttpsProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpsProxies.SetSslPolicy. See the
                 method description for details.
 
@@ -690,15 +696,14 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetSslPolicyTargetHttpsProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -708,7 +713,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_url_map(
         self,
@@ -720,8 +725,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         Args:
             request (~.compute.SetUrlMapTargetHttpsProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetHttpsProxies.SetUrlMap. See the
                 method description for details.
 
@@ -778,15 +782,14 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetUrlMapTargetHttpsProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -796,7 +799,7 @@ class TargetHttpsProxiesRestTransport(TargetHttpsProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("TargetHttpsProxiesRestTransport",)
