@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.target_instances import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import TargetInstancesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import TargetInstancesRestTransport
 
@@ -215,7 +212,7 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, TargetInstancesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -346,7 +343,6 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -376,10 +372,8 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListTargetInstancesRequest):
             request = compute.AggregatedListTargetInstancesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -436,7 +430,6 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
                 This corresponds to the ``target_instance`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -488,10 +481,8 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteTargetInstanceRequest):
             request = compute.DeleteTargetInstanceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -548,7 +539,6 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
                 This corresponds to the ``target_instance`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -583,10 +573,8 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetTargetInstanceRequest):
             request = compute.GetTargetInstanceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -640,7 +628,6 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
                 This corresponds to the ``target_instance_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -692,10 +679,8 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertTargetInstanceRequest):
             request = compute.InsertTargetInstanceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
@@ -743,7 +728,6 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
                 This corresponds to the ``zone`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -775,10 +759,8 @@ class TargetInstancesClient(metaclass=TargetInstancesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListTargetInstancesRequest):
             request = compute.ListTargetInstancesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if zone is not None:
