@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import TargetPoolsTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def add_health_check(
         self,
@@ -103,8 +103,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.AddHealthCheckTargetPoolRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.AddHealthCheck. See the
                 method description for details.
 
@@ -162,15 +161,14 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.AddHealthCheckTargetPoolRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -180,7 +178,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def add_instance(
         self,
@@ -192,8 +190,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.AddInstanceTargetPoolRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.AddInstance. See the method
                 description for details.
 
@@ -251,15 +248,14 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.AddInstanceTargetPoolRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -269,7 +265,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def aggregated_list(
         self,
@@ -281,8 +277,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.AggregatedListTargetPoolsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.AggregatedList. See the
                 method description for details.
 
@@ -302,30 +297,36 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListTargetPoolsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.AggregatedListTargetPoolsRequest.include_all_scopes in request:
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListTargetPoolsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListTargetPoolsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListTargetPoolsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.AggregatedListTargetPoolsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetPoolAggregatedList.from_json(response.content)
+        return compute.TargetPoolAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def delete(
         self,
@@ -337,8 +338,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.DeleteTargetPoolRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.Delete. See the method
                 description for details.
 
@@ -389,25 +389,24 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteTargetPoolRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -419,8 +418,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.GetTargetPoolRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.Get. See the method
                 description for details.
 
@@ -452,22 +450,23 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetPool.from_json(response.content)
+        return compute.TargetPool.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def get_health(
         self,
@@ -479,8 +478,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.GetHealthTargetPoolRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.GetHealth. See the method
                 description for details.
 
@@ -511,12 +509,11 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -526,7 +523,9 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetPoolInstanceHealth.from_json(response.content)
+        return compute.TargetPoolInstanceHealth.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -538,8 +537,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.InsertTargetPoolRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.Insert. See the method
                 description for details.
 
@@ -594,15 +592,14 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertTargetPoolRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -612,7 +609,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -624,8 +621,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.ListTargetPoolsRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.List. See the method
                 description for details.
 
@@ -647,29 +643,34 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListTargetPoolsRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListTargetPoolsRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListTargetPoolsRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListTargetPoolsRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListTargetPoolsRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetPoolList.from_json(response.content)
+        return compute.TargetPoolList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def remove_health_check(
         self,
@@ -681,8 +682,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.RemoveHealthCheckTargetPoolRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.RemoveHealthCheck. See the
                 method description for details.
 
@@ -740,15 +740,14 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.RemoveHealthCheckTargetPoolRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -758,7 +757,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def remove_instance(
         self,
@@ -770,8 +769,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.RemoveInstanceTargetPoolRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.RemoveInstance. See the
                 method description for details.
 
@@ -829,15 +827,14 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.RemoveInstanceTargetPoolRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -847,7 +844,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_backup(
         self,
@@ -859,8 +856,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         Args:
             request (~.compute.SetBackupTargetPoolRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetPools.SetBackup. See the method
                 description for details.
 
@@ -918,16 +914,16 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "failoverRatio": request.failover_ratio,
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetBackupTargetPoolRequest.failover_ratio in request:
+            query_params["failoverRatio"] = request.failover_ratio
+        if compute.SetBackupTargetPoolRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -937,7 +933,7 @@ class TargetPoolsRestTransport(TargetPoolsTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("TargetPoolsRestTransport",)
