@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.target_ssl_proxies import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import TargetSslProxiesTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import TargetSslProxiesRestTransport
 
@@ -215,7 +212,7 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, TargetSslProxiesTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -354,7 +351,6 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
                 This corresponds to the ``target_ssl_proxy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -406,10 +402,8 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteTargetSslProxyRequest):
             request = compute.DeleteTargetSslProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_ssl_proxy is not None:
@@ -456,7 +450,6 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
                 This corresponds to the ``target_ssl_proxy`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -491,10 +484,8 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetTargetSslProxyRequest):
             request = compute.GetTargetSslProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_ssl_proxy is not None:
@@ -538,7 +529,6 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
                 This corresponds to the ``target_ssl_proxy_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -590,10 +580,8 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertTargetSslProxyRequest):
             request = compute.InsertTargetSslProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_ssl_proxy_resource is not None:
@@ -631,7 +619,6 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -663,10 +650,8 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListTargetSslProxiesRequest):
             request = compute.ListTargetSslProxiesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -722,7 +707,6 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
                 This corresponds to the ``target_ssl_proxies_set_backend_service_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -780,10 +764,8 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetBackendServiceTargetSslProxyRequest):
             request = compute.SetBackendServiceTargetSslProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_ssl_proxy is not None:
@@ -838,7 +820,6 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
                 This corresponds to the ``target_ssl_proxies_set_proxy_header_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -896,10 +877,8 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetProxyHeaderTargetSslProxyRequest):
             request = compute.SetProxyHeaderTargetSslProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_ssl_proxy is not None:
@@ -955,7 +934,6 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
                 This corresponds to the ``target_ssl_proxies_set_ssl_certificates_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1013,10 +991,8 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetSslCertificatesTargetSslProxyRequest):
             request = compute.SetSslCertificatesTargetSslProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_ssl_proxy is not None:
@@ -1077,7 +1053,6 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
                 This corresponds to the ``ssl_policy_reference_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1131,10 +1106,8 @@ class TargetSslProxiesClient(metaclass=TargetSslProxiesClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetSslPolicyTargetSslProxyRequest):
             request = compute.SetSslPolicyTargetSslProxyRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if target_ssl_proxy is not None:
