@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import TargetSslProxiesTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def delete(
         self,
@@ -103,8 +103,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         Args:
             request (~.compute.DeleteTargetSslProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetSslProxies.Delete. See the method
                 description for details.
 
@@ -154,25 +153,24 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteTargetSslProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -184,8 +182,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         Args:
             request (~.compute.GetTargetSslProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetSslProxies.Get. See the method
                 description for details.
 
@@ -216,22 +213,23 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetSslProxy.from_json(response.content)
+        return compute.TargetSslProxy.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -243,8 +241,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         Args:
             request (~.compute.InsertTargetSslProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetSslProxies.Insert. See the method
                 description for details.
 
@@ -299,15 +296,14 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertTargetSslProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -317,7 +313,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -329,8 +325,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         Args:
             request (~.compute.ListTargetSslProxiesRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetSslProxies.List. See the method
                 description for details.
 
@@ -352,29 +347,34 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListTargetSslProxiesRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListTargetSslProxiesRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListTargetSslProxiesRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListTargetSslProxiesRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListTargetSslProxiesRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.TargetSslProxyList.from_json(response.content)
+        return compute.TargetSslProxyList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def set_backend_service(
         self,
@@ -386,8 +386,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         Args:
             request (~.compute.SetBackendServiceTargetSslProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetSslProxies.SetBackendService. See
                 the method description for details.
 
@@ -444,15 +443,14 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetBackendServiceTargetSslProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -462,7 +460,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_proxy_header(
         self,
@@ -474,8 +472,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         Args:
             request (~.compute.SetProxyHeaderTargetSslProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetSslProxies.SetProxyHeader. See the
                 method description for details.
 
@@ -532,15 +529,14 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetProxyHeaderTargetSslProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -550,7 +546,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_ssl_certificates(
         self,
@@ -562,8 +558,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         Args:
             request (~.compute.SetSslCertificatesTargetSslProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetSslProxies.SetSslCertificates. See
                 the method description for details.
 
@@ -620,15 +615,14 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetSslCertificatesTargetSslProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -638,7 +632,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def set_ssl_policy(
         self,
@@ -650,8 +644,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         Args:
             request (~.compute.SetSslPolicyTargetSslProxyRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 TargetSslProxies.SetSslPolicy. See the
                 method description for details.
 
@@ -708,15 +701,14 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetSslPolicyTargetSslProxyRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -726,7 +718,7 @@ class TargetSslProxiesRestTransport(TargetSslProxiesTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
 
 __all__ = ("TargetSslProxiesRestTransport",)
