@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.url_maps import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import UrlMapsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import UrlMapsRestTransport
 
@@ -213,7 +210,7 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, UrlMapsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -347,7 +344,6 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -377,10 +373,8 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListUrlMapsRequest):
             request = compute.AggregatedListUrlMapsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -428,7 +422,6 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
                 This corresponds to the ``url_map`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -480,10 +473,8 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteUrlMapRequest):
             request = compute.DeleteUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if url_map is not None:
@@ -528,7 +519,6 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
                 This corresponds to the ``url_map`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -588,10 +578,8 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetUrlMapRequest):
             request = compute.GetUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if url_map is not None:
@@ -634,7 +622,6 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
                 This corresponds to the ``url_map_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -686,10 +673,8 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertUrlMapRequest):
             request = compute.InsertUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if url_map_resource is not None:
@@ -744,7 +729,6 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
                 This corresponds to the ``cache_invalidation_rule_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -796,10 +780,8 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InvalidateCacheUrlMapRequest):
             request = compute.InvalidateCacheUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if url_map is not None:
@@ -840,7 +822,6 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -871,10 +852,8 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListUrlMapsRequest):
             request = compute.ListUrlMapsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -929,7 +908,6 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
                 This corresponds to the ``url_map_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -981,10 +959,8 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.PatchUrlMapRequest):
             request = compute.PatchUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if url_map is not None:
@@ -1037,7 +1013,6 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
                 This corresponds to the ``url_map_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1089,10 +1064,8 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.UpdateUrlMapRequest):
             request = compute.UpdateUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if url_map is not None:
@@ -1147,7 +1120,6 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
                 This corresponds to the ``url_maps_validate_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1176,10 +1148,8 @@ class UrlMapsClient(metaclass=UrlMapsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ValidateUrlMapRequest):
             request = compute.ValidateUrlMapRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if url_map is not None:
