@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.vpn_gateways import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import VpnGatewaysTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import VpnGatewaysRestTransport
 
@@ -213,7 +210,7 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, VpnGatewaysTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -344,7 +341,6 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -374,10 +370,8 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListVpnGatewaysRequest):
             request = compute.AggregatedListVpnGatewaysRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -430,7 +424,6 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
                 This corresponds to the ``vpn_gateway`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -482,10 +475,8 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteVpnGatewayRequest):
             request = compute.DeleteVpnGatewayRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -536,7 +527,6 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
                 This corresponds to the ``vpn_gateway`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -572,10 +562,8 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetVpnGatewayRequest):
             request = compute.GetVpnGatewayRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -626,7 +614,6 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
                 This corresponds to the ``vpn_gateway`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -653,10 +640,8 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetStatusVpnGatewayRequest):
             request = compute.GetStatusVpnGatewayRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -708,7 +693,6 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
                 This corresponds to the ``vpn_gateway_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -760,10 +744,8 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertVpnGatewayRequest):
             request = compute.InsertVpnGatewayRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -809,7 +791,6 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -841,10 +822,8 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListVpnGatewaysRequest):
             request = compute.ListVpnGatewaysRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -908,7 +887,6 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
                 This corresponds to the ``region_set_labels_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -962,10 +940,8 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.SetLabelsVpnGatewayRequest):
             request = compute.SetLabelsVpnGatewayRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -1031,7 +1007,6 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
                 This corresponds to the ``test_permissions_request_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1060,10 +1035,8 @@ class VpnGatewaysClient(metaclass=VpnGatewaysClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.TestIamPermissionsVpnGatewayRequest):
             request = compute.TestIamPermissionsVpnGatewayRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
