@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
-
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession
 
-
 from google.cloud.compute_v1.types import compute
 
-
 from .base import VpnGatewaysTransport, DEFAULT_CLIENT_INFO
 
 
@@ -51,7 +45,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         self,
         *,
         host: str = "compute.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
@@ -61,7 +55,8 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -78,20 +73,25 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
                 if ``channel`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
+        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
+        # credentials object
         super().__init__(
             host=host, credentials=credentials, client_info=client_info,
         )
-        self._session = AuthorizedSession(self._credentials)
+        self._session = AuthorizedSession(
+            self._credentials, default_host=self.DEFAULT_HOST
+        )
         if client_cert_source_for_mtls:
             self._session.configure_mtls_channel(client_cert_source_for_mtls)
+        self._prep_wrapped_messages(client_info)
 
     def aggregated_list(
         self,
@@ -103,8 +103,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         Args:
             request (~.compute.AggregatedListVpnGatewaysRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 VpnGateways.AggregatedList. See the
                 method description for details.
 
@@ -124,30 +123,36 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "includeAllScopes": request.include_all_scopes,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.AggregatedListVpnGatewaysRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.AggregatedListVpnGatewaysRequest.include_all_scopes in request:
+            query_params["includeAllScopes"] = request.include_all_scopes
+        if compute.AggregatedListVpnGatewaysRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.AggregatedListVpnGatewaysRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.AggregatedListVpnGatewaysRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.AggregatedListVpnGatewaysRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.VpnGatewayAggregatedList.from_json(response.content)
+        return compute.VpnGatewayAggregatedList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def delete(
         self,
@@ -159,8 +164,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         Args:
             request (~.compute.DeleteVpnGatewayRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 VpnGateways.Delete. See the method
                 description for details.
 
@@ -211,25 +215,24 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.DeleteVpnGatewayRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url)
+        response = self._session.delete(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def get(
         self,
@@ -241,8 +244,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         Args:
             request (~.compute.GetVpnGatewayRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 VpnGateways.Get. See the method
                 description for details.
 
@@ -275,22 +277,23 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.VpnGateway.from_json(response.content)
+        return compute.VpnGateway.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def get_status(
         self,
@@ -302,8 +305,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         Args:
             request (~.compute.GetStatusVpnGatewayRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 VpnGateways.GetStatus. See the method
                 description for details.
 
@@ -327,22 +329,23 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.VpnGatewaysGetStatusResponse.from_json(response.content)
+        return compute.VpnGatewaysGetStatusResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def insert(
         self,
@@ -354,8 +357,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         Args:
             request (~.compute.InsertVpnGatewayRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 VpnGateways.Insert. See the method
                 description for details.
 
@@ -410,15 +412,14 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.InsertVpnGatewayRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -428,7 +429,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def list(
         self,
@@ -440,8 +441,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         Args:
             request (~.compute.ListVpnGatewaysRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 VpnGateways.List. See the method
                 description for details.
 
@@ -463,29 +463,34 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "filter": request.filter,
-            "maxResults": request.max_results,
-            "orderBy": request.order_by,
-            "pageToken": request.page_token,
-            "returnPartialSuccess": request.return_partial_success,
-        }
+        query_params = {}
+        if compute.ListVpnGatewaysRequest.filter in request:
+            query_params["filter"] = request.filter
+        if compute.ListVpnGatewaysRequest.max_results in request:
+            query_params["maxResults"] = request.max_results
+        if compute.ListVpnGatewaysRequest.order_by in request:
+            query_params["orderBy"] = request.order_by
+        if compute.ListVpnGatewaysRequest.page_token in request:
+            query_params["pageToken"] = request.page_token
+        if compute.ListVpnGatewaysRequest.return_partial_success in request:
+            query_params["returnPartialSuccess"] = request.return_partial_success
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url)
+        response = self._session.get(url,)
 
         # Raise requests.exceptions.HTTPError if the status code is >= 400
         response.raise_for_status()
 
         # Return the response
-        return compute.VpnGatewayList.from_json(response.content)
+        return compute.VpnGatewayList.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
     def set_labels(
         self,
@@ -497,8 +502,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         Args:
             request (~.compute.SetLabelsVpnGatewayRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 VpnGateways.SetLabels. See the method
                 description for details.
 
@@ -556,15 +560,14 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
-        query_params = {
-            "requestId": request.request_id,
-        }
+        query_params = {}
+        if compute.SetLabelsVpnGatewayRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -574,7 +577,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.Operation.from_json(response.content)
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
 
     def test_iam_permissions(
         self,
@@ -586,8 +589,7 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
 
         Args:
             request (~.compute.TestIamPermissionsVpnGatewayRequest):
-                The request object.
-                A request message for
+                The request object. A request message for
                 VpnGateways.TestIamPermissions. See the
                 method description for details.
 
@@ -618,12 +620,11 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
         #               not required for GCE
         query_params = {}
+
         # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
         #               discards default values
         # TODO(yon-mg): add test for proper url encoded strings
-        query_params = [
-            "{k}={v}".format(k=k, v=v) for k, v in query_params.items() if v
-        ]
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
@@ -633,7 +634,9 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         response.raise_for_status()
 
         # Return the response
-        return compute.TestPermissionsResponse.from_json(response.content)
+        return compute.TestPermissionsResponse.from_json(
+            response.content, ignore_unknown_fields=True
+        )
 
 
 __all__ = ("VpnGatewaysRestTransport",)
