@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,7 +32,6 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.compute_v1.services.vpn_tunnels import pagers
 from google.cloud.compute_v1.types import compute
-
 from .transports.base import VpnTunnelsTransport, DEFAULT_CLIENT_INFO
 from .transports.rest import VpnTunnelsRestTransport
 
@@ -213,7 +210,7 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, VpnTunnelsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
@@ -344,7 +341,6 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
                 This corresponds to the ``project`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -374,10 +370,8 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.AggregatedListVpnTunnelsRequest):
             request = compute.AggregatedListVpnTunnelsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
 
@@ -432,7 +426,6 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
                 This corresponds to the ``vpn_tunnel`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -484,10 +477,8 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.DeleteVpnTunnelRequest):
             request = compute.DeleteVpnTunnelRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -540,7 +531,6 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
                 This corresponds to the ``vpn_tunnel`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -572,10 +562,8 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.GetVpnTunnelRequest):
             request = compute.GetVpnTunnelRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -627,7 +615,6 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
                 This corresponds to the ``vpn_tunnel_resource`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -679,10 +666,8 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.InsertVpnTunnelRequest):
             request = compute.InsertVpnTunnelRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
@@ -727,7 +712,6 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
                 This corresponds to the ``region`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -759,10 +743,8 @@ class VpnTunnelsClient(metaclass=VpnTunnelsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, compute.ListVpnTunnelsRequest):
             request = compute.ListVpnTunnelsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project is not None:
                 request.project = project
             if region is not None:
