@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,61 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.autoscalers import AutoscalersClient
 from google.cloud.compute_v1.services.autoscalers import pagers
 from google.cloud.compute_v1.services.autoscalers import transports
+from google.cloud.compute_v1.services.autoscalers.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.autoscalers.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -82,31 +111,35 @@ def test__get_default_mtls_endpoint():
     assert AutoscalersClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-def test_autoscalers_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [AutoscalersClient,])
+def test_autoscalers_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = AutoscalersClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [AutoscalersClient,])
 def test_autoscalers_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -134,7 +167,7 @@ def test_autoscalers_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(AutoscalersClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -370,7 +403,7 @@ def test_aggregated_list_rest(
     transport: str = "rest", request_type=compute.AggregatedListAutoscalersRequest
 ):
     client = AutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -399,17 +432,16 @@ def test_aggregated_list_rest(
             unreachables=["unreachables_value"],
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.AutoscalerAggregatedList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.aggregated_list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.AggregatedListPager)
     assert response.id == "id_value"
     assert response.items == {
@@ -435,7 +467,7 @@ def test_aggregated_list_rest_from_dict():
 
 
 def test_aggregated_list_rest_flattened():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -458,12 +490,11 @@ def test_aggregated_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_aggregated_list_rest_flattened_error():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -474,12 +505,11 @@ def test_aggregated_list_rest_flattened_error():
 
 
 def test_aggregated_list_pager():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.AutoscalerAggregatedList(
                 items={
@@ -500,7 +530,6 @@ def test_aggregated_list_pager():
                 },
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -522,7 +551,6 @@ def test_aggregated_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, tuple) for i in results)
         for result in results:
             assert isinstance(result, tuple)
@@ -543,7 +571,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeleteAutoscalerRequest
 ):
     client = AutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -578,17 +606,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -622,7 +649,7 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -647,16 +674,13 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "zone_value" in http_call[1] + str(body)
-
         assert "autoscaler_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -671,7 +695,7 @@ def test_delete_rest_flattened_error():
 
 def test_get_rest(transport: str = "rest", request_type=compute.GetAutoscalerRequest):
     client = AutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -696,17 +720,16 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetAutoscalerReq
             target="target_value",
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Autoscaler.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Autoscaler)
     assert response.autoscaling_policy == compute.AutoscalingPolicy(
         cool_down_period_sec=2112
@@ -732,7 +755,7 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -757,16 +780,13 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "zone_value" in http_call[1] + str(body)
-
         assert "autoscaler_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -783,7 +803,7 @@ def test_insert_rest(
     transport: str = "rest", request_type=compute.InsertAutoscalerRequest
 ):
     client = AutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -818,17 +838,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -862,7 +881,7 @@ def test_insert_rest_from_dict():
 
 
 def test_insert_rest_flattened():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -881,7 +900,6 @@ def test_insert_rest_flattened():
         autoscaler_resource = compute.Autoscaler(
             autoscaling_policy=compute.AutoscalingPolicy(cool_down_period_sec=2112)
         )
-
         client.insert(
             project="project_value",
             zone="zone_value",
@@ -893,11 +911,8 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "zone_value" in http_call[1] + str(body)
-
         assert compute.Autoscaler.to_json(
             autoscaler_resource,
             including_default_value_fields=False,
@@ -906,7 +921,7 @@ def test_insert_rest_flattened():
 
 
 def test_insert_rest_flattened_error():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -925,7 +940,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListAutoscalersRequest
 ):
     client = AutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -949,17 +964,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.AutoscalerList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [
@@ -978,7 +992,7 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1003,14 +1017,12 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "zone_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1023,12 +1035,11 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.AutoscalerList(
                 items=[
@@ -1046,7 +1057,6 @@ def test_list_pager():
                 items=[compute.Autoscaler(), compute.Autoscaler(),],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -1065,7 +1075,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.Autoscaler) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -1077,7 +1086,7 @@ def test_patch_rest(
     transport: str = "rest", request_type=compute.PatchAutoscalerRequest
 ):
     client = AutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1112,17 +1121,16 @@ def test_patch_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.patch(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1156,7 +1164,7 @@ def test_patch_rest_from_dict():
 
 
 def test_patch_rest_flattened():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1175,7 +1183,6 @@ def test_patch_rest_flattened():
         autoscaler_resource = compute.Autoscaler(
             autoscaling_policy=compute.AutoscalingPolicy(cool_down_period_sec=2112)
         )
-
         client.patch(
             project="project_value",
             zone="zone_value",
@@ -1187,11 +1194,8 @@ def test_patch_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "zone_value" in http_call[1] + str(body)
-
         assert compute.Autoscaler.to_json(
             autoscaler_resource,
             including_default_value_fields=False,
@@ -1200,7 +1204,7 @@ def test_patch_rest_flattened():
 
 
 def test_patch_rest_flattened_error():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1219,7 +1223,7 @@ def test_update_rest(
     transport: str = "rest", request_type=compute.UpdateAutoscalerRequest
 ):
     client = AutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1254,17 +1258,16 @@ def test_update_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.update(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1298,7 +1301,7 @@ def test_update_rest_from_dict():
 
 
 def test_update_rest_flattened():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1317,7 +1320,6 @@ def test_update_rest_flattened():
         autoscaler_resource = compute.Autoscaler(
             autoscaling_policy=compute.AutoscalingPolicy(cool_down_period_sec=2112)
         )
-
         client.update(
             project="project_value",
             zone="zone_value",
@@ -1329,11 +1331,8 @@ def test_update_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "zone_value" in http_call[1] + str(body)
-
         assert compute.Autoscaler.to_json(
             autoscaler_resource,
             including_default_value_fields=False,
@@ -1342,7 +1341,7 @@ def test_update_rest_flattened():
 
 
 def test_update_rest_flattened_error():
-    client = AutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = AutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1360,16 +1359,16 @@ def test_update_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.AutoscalersRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = AutoscalersClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.AutoscalersRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = AutoscalersClient(
@@ -1379,7 +1378,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.AutoscalersRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = AutoscalersClient(
@@ -1390,7 +1389,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.AutoscalersRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = AutoscalersClient(transport=transport)
     assert client.transport is transport
@@ -1399,17 +1398,17 @@ def test_transport_instance():
 @pytest.mark.parametrize("transport_class", [transports.AutoscalersRestTransport,])
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_autoscalers_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.AutoscalersTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1421,7 +1420,7 @@ def test_autoscalers_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.AutoscalersTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1440,15 +1439,40 @@ def test_autoscalers_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_autoscalers_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.autoscalers.transports.AutoscalersTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.AutoscalersTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_autoscalers_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.autoscalers.transports.AutoscalersTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.AutoscalersTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1464,19 +1488,36 @@ def test_autoscalers_base_transport_with_credentials_file():
 
 def test_autoscalers_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.autoscalers.transports.AutoscalersTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.AutoscalersTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_autoscalers_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        AutoscalersClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_autoscalers_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         AutoscalersClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1488,7 +1529,7 @@ def test_autoscalers_auth_adc():
 
 
 def test_autoscalers_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1500,7 +1541,7 @@ def test_autoscalers_http_transport_client_cert_source_for_mtls():
 
 def test_autoscalers_host_no_port():
     client = AutoscalersClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1510,7 +1551,7 @@ def test_autoscalers_host_no_port():
 
 def test_autoscalers_host_with_port():
     client = AutoscalersClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1520,7 +1561,6 @@ def test_autoscalers_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1541,7 +1581,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = AutoscalersClient.common_folder_path(folder)
     assert expected == actual
@@ -1560,7 +1599,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = AutoscalersClient.common_organization_path(organization)
     assert expected == actual
@@ -1579,7 +1617,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = AutoscalersClient.common_project_path(project)
     assert expected == actual
@@ -1599,7 +1636,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1626,7 +1662,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.AutoscalersTransport, "_prep_wrapped_messages"
     ) as prep:
         client = AutoscalersClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1635,6 +1671,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = AutoscalersClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
