@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,61 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.backend_buckets import BackendBucketsClient
 from google.cloud.compute_v1.services.backend_buckets import pagers
 from google.cloud.compute_v1.services.backend_buckets import transports
+from google.cloud.compute_v1.services.backend_buckets.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.backend_buckets.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -85,31 +114,35 @@ def test__get_default_mtls_endpoint():
     )
 
 
-def test_backend_buckets_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [BackendBucketsClient,])
+def test_backend_buckets_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = BackendBucketsClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [BackendBucketsClient,])
 def test_backend_buckets_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -139,7 +172,7 @@ def test_backend_buckets_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(BackendBucketsClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -377,7 +410,7 @@ def test_add_signed_url_key_rest(
     transport: str = "rest", request_type=compute.AddSignedUrlKeyBackendBucketRequest
 ):
     client = BackendBucketsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -412,17 +445,16 @@ def test_add_signed_url_key_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.add_signed_url_key(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -456,7 +488,7 @@ def test_add_signed_url_key_rest_from_dict():
 
 
 def test_add_signed_url_key_rest_flattened():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -473,7 +505,6 @@ def test_add_signed_url_key_rest_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         signed_url_key_resource = compute.SignedUrlKey(key_name="key_name_value")
-
         client.add_signed_url_key(
             project="project_value",
             backend_bucket="backend_bucket_value",
@@ -485,11 +516,8 @@ def test_add_signed_url_key_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "backend_bucket_value" in http_call[1] + str(body)
-
         assert compute.SignedUrlKey.to_json(
             signed_url_key_resource,
             including_default_value_fields=False,
@@ -498,7 +526,7 @@ def test_add_signed_url_key_rest_flattened():
 
 
 def test_add_signed_url_key_rest_flattened_error():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -515,7 +543,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeleteBackendBucketRequest
 ):
     client = BackendBucketsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -550,17 +578,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -594,7 +621,7 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -619,14 +646,12 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "backend_bucket_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -642,7 +667,7 @@ def test_delete_signed_url_key_rest(
     transport: str = "rest", request_type=compute.DeleteSignedUrlKeyBackendBucketRequest
 ):
     client = BackendBucketsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -677,17 +702,16 @@ def test_delete_signed_url_key_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete_signed_url_key(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -721,7 +745,7 @@ def test_delete_signed_url_key_rest_from_dict():
 
 
 def test_delete_signed_url_key_rest_flattened():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -748,16 +772,13 @@ def test_delete_signed_url_key_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "backend_bucket_value" in http_call[1] + str(body)
-
         assert "key_name_value" in http_call[1] + str(body)
 
 
 def test_delete_signed_url_key_rest_flattened_error():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -774,7 +795,7 @@ def test_get_rest(
     transport: str = "rest", request_type=compute.GetBackendBucketRequest
 ):
     client = BackendBucketsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -798,17 +819,16 @@ def test_get_rest(
             name="name_value",
             self_link="self_link_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.BackendBucket.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.BackendBucket)
     assert response.bucket_name == "bucket_name_value"
     assert response.cdn_policy == compute.BackendBucketCdnPolicy(
@@ -817,7 +837,6 @@ def test_get_rest(
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.custom_response_headers == ["custom_response_headers_value"]
     assert response.description == "description_value"
-
     assert response.enable_cdn is True
     assert response.id == "id_value"
     assert response.kind == "kind_value"
@@ -830,7 +849,7 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -855,14 +874,12 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "backend_bucket_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -878,7 +895,7 @@ def test_insert_rest(
     transport: str = "rest", request_type=compute.InsertBackendBucketRequest
 ):
     client = BackendBucketsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -913,17 +930,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -957,7 +973,7 @@ def test_insert_rest_from_dict():
 
 
 def test_insert_rest_flattened():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -974,7 +990,6 @@ def test_insert_rest_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         backend_bucket_resource = compute.BackendBucket(bucket_name="bucket_name_value")
-
         client.insert(
             project="project_value", backend_bucket_resource=backend_bucket_resource,
         )
@@ -984,9 +999,7 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert compute.BackendBucket.to_json(
             backend_bucket_resource,
             including_default_value_fields=False,
@@ -995,7 +1008,7 @@ def test_insert_rest_flattened():
 
 
 def test_insert_rest_flattened_error():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1013,7 +1026,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListBackendBucketsRequest
 ):
     client = BackendBucketsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1031,17 +1044,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.BackendBucketList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [compute.BackendBucket(bucket_name="bucket_name_value")]
@@ -1056,7 +1068,7 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1079,12 +1091,11 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1095,12 +1106,11 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.BackendBucketList(
                 items=[
@@ -1118,7 +1128,6 @@ def test_list_pager():
                 items=[compute.BackendBucket(), compute.BackendBucket(),],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -1137,7 +1146,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.BackendBucket) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -1149,7 +1157,7 @@ def test_patch_rest(
     transport: str = "rest", request_type=compute.PatchBackendBucketRequest
 ):
     client = BackendBucketsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1184,17 +1192,16 @@ def test_patch_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.patch(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1228,7 +1235,7 @@ def test_patch_rest_from_dict():
 
 
 def test_patch_rest_flattened():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1245,7 +1252,6 @@ def test_patch_rest_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         backend_bucket_resource = compute.BackendBucket(bucket_name="bucket_name_value")
-
         client.patch(
             project="project_value",
             backend_bucket="backend_bucket_value",
@@ -1257,11 +1263,8 @@ def test_patch_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "backend_bucket_value" in http_call[1] + str(body)
-
         assert compute.BackendBucket.to_json(
             backend_bucket_resource,
             including_default_value_fields=False,
@@ -1270,7 +1273,7 @@ def test_patch_rest_flattened():
 
 
 def test_patch_rest_flattened_error():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1289,7 +1292,7 @@ def test_update_rest(
     transport: str = "rest", request_type=compute.UpdateBackendBucketRequest
 ):
     client = BackendBucketsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1324,17 +1327,16 @@ def test_update_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.update(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1368,7 +1370,7 @@ def test_update_rest_from_dict():
 
 
 def test_update_rest_flattened():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1385,7 +1387,6 @@ def test_update_rest_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         backend_bucket_resource = compute.BackendBucket(bucket_name="bucket_name_value")
-
         client.update(
             project="project_value",
             backend_bucket="backend_bucket_value",
@@ -1397,11 +1398,8 @@ def test_update_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "backend_bucket_value" in http_call[1] + str(body)
-
         assert compute.BackendBucket.to_json(
             backend_bucket_resource,
             including_default_value_fields=False,
@@ -1410,7 +1408,7 @@ def test_update_rest_flattened():
 
 
 def test_update_rest_flattened_error():
-    client = BackendBucketsClient(credentials=credentials.AnonymousCredentials(),)
+    client = BackendBucketsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1428,16 +1426,16 @@ def test_update_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.BackendBucketsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = BackendBucketsClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.BackendBucketsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = BackendBucketsClient(
@@ -1447,7 +1445,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.BackendBucketsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = BackendBucketsClient(
@@ -1458,7 +1456,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.BackendBucketsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = BackendBucketsClient(transport=transport)
     assert client.transport is transport
@@ -1467,17 +1465,17 @@ def test_transport_instance():
 @pytest.mark.parametrize("transport_class", [transports.BackendBucketsRestTransport,])
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_backend_buckets_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.BackendBucketsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1489,7 +1487,7 @@ def test_backend_buckets_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.BackendBucketsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1509,15 +1507,40 @@ def test_backend_buckets_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_backend_buckets_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.backend_buckets.transports.BackendBucketsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.BackendBucketsTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_backend_buckets_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.backend_buckets.transports.BackendBucketsTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.BackendBucketsTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1533,19 +1556,36 @@ def test_backend_buckets_base_transport_with_credentials_file():
 
 def test_backend_buckets_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.backend_buckets.transports.BackendBucketsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.BackendBucketsTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_backend_buckets_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        BackendBucketsClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_backend_buckets_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         BackendBucketsClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1557,7 +1597,7 @@ def test_backend_buckets_auth_adc():
 
 
 def test_backend_buckets_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1569,7 +1609,7 @@ def test_backend_buckets_http_transport_client_cert_source_for_mtls():
 
 def test_backend_buckets_host_no_port():
     client = BackendBucketsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1579,7 +1619,7 @@ def test_backend_buckets_host_no_port():
 
 def test_backend_buckets_host_with_port():
     client = BackendBucketsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1589,7 +1629,6 @@ def test_backend_buckets_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1610,7 +1649,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = BackendBucketsClient.common_folder_path(folder)
     assert expected == actual
@@ -1629,7 +1667,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = BackendBucketsClient.common_organization_path(organization)
     assert expected == actual
@@ -1648,7 +1685,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = BackendBucketsClient.common_project_path(project)
     assert expected == actual
@@ -1668,7 +1704,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1695,7 +1730,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.BackendBucketsTransport, "_prep_wrapped_messages"
     ) as prep:
         client = BackendBucketsClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1704,6 +1739,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = BackendBucketsClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
