@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,33 +13,63 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.external_vpn_gateways import (
     ExternalVpnGatewaysClient,
 )
 from google.cloud.compute_v1.services.external_vpn_gateways import pagers
 from google.cloud.compute_v1.services.external_vpn_gateways import transports
+from google.cloud.compute_v1.services.external_vpn_gateways.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.external_vpn_gateways.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -88,31 +117,35 @@ def test__get_default_mtls_endpoint():
     )
 
 
-def test_external_vpn_gateways_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [ExternalVpnGatewaysClient,])
+def test_external_vpn_gateways_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = ExternalVpnGatewaysClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [ExternalVpnGatewaysClient,])
 def test_external_vpn_gateways_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -142,7 +175,7 @@ def test_external_vpn_gateways_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(ExternalVpnGatewaysClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -390,7 +423,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeleteExternalVpnGatewayRequest
 ):
     client = ExternalVpnGatewaysClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -425,17 +458,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -469,7 +501,9 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -494,14 +528,14 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "external_vpn_gateway_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -517,7 +551,7 @@ def test_get_rest(
     transport: str = "rest", request_type=compute.GetExternalVpnGatewayRequest
 ):
     client = ExternalVpnGatewaysClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -539,17 +573,16 @@ def test_get_rest(
             redundancy_type=compute.ExternalVpnGateway.RedundancyType.FOUR_IPS_REDUNDANCY,
             self_link="self_link_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.ExternalVpnGateway.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.ExternalVpnGateway)
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
@@ -571,7 +604,9 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -596,14 +631,14 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "external_vpn_gateway_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -619,7 +654,7 @@ def test_insert_rest(
     transport: str = "rest", request_type=compute.InsertExternalVpnGatewayRequest
 ):
     client = ExternalVpnGatewaysClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -654,17 +689,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -698,7 +732,9 @@ def test_insert_rest_from_dict():
 
 
 def test_insert_rest_flattened():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -717,7 +753,6 @@ def test_insert_rest_flattened():
         external_vpn_gateway_resource = compute.ExternalVpnGateway(
             creation_timestamp="creation_timestamp_value"
         )
-
         client.insert(
             project="project_value",
             external_vpn_gateway_resource=external_vpn_gateway_resource,
@@ -728,9 +763,7 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert compute.ExternalVpnGateway.to_json(
             external_vpn_gateway_resource,
             including_default_value_fields=False,
@@ -739,7 +772,9 @@ def test_insert_rest_flattened():
 
 
 def test_insert_rest_flattened_error():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -757,7 +792,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListExternalVpnGatewaysRequest
 ):
     client = ExternalVpnGatewaysClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -780,17 +815,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.ExternalVpnGatewayList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.etag == "etag_value"
     assert response.id == "id_value"
@@ -808,7 +842,9 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -831,12 +867,13 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -847,12 +884,13 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.ExternalVpnGatewayList(
                 items=[
@@ -870,7 +908,6 @@ def test_list_pager():
                 items=[compute.ExternalVpnGateway(), compute.ExternalVpnGateway(),],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -889,7 +926,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.ExternalVpnGateway) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -901,7 +937,7 @@ def test_set_labels_rest(
     transport: str = "rest", request_type=compute.SetLabelsExternalVpnGatewayRequest
 ):
     client = ExternalVpnGatewaysClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -936,17 +972,16 @@ def test_set_labels_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.set_labels(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -980,7 +1015,9 @@ def test_set_labels_rest_from_dict():
 
 
 def test_set_labels_rest_flattened():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -999,7 +1036,6 @@ def test_set_labels_rest_flattened():
         global_set_labels_request_resource = compute.GlobalSetLabelsRequest(
             label_fingerprint="label_fingerprint_value"
         )
-
         client.set_labels(
             project="project_value",
             resource="resource_value",
@@ -1011,11 +1047,8 @@ def test_set_labels_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "resource_value" in http_call[1] + str(body)
-
         assert compute.GlobalSetLabelsRequest.to_json(
             global_set_labels_request_resource,
             including_default_value_fields=False,
@@ -1024,7 +1057,9 @@ def test_set_labels_rest_flattened():
 
 
 def test_set_labels_rest_flattened_error():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1044,7 +1079,7 @@ def test_test_iam_permissions_rest(
     request_type=compute.TestIamPermissionsExternalVpnGatewayRequest,
 ):
     client = ExternalVpnGatewaysClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1057,17 +1092,16 @@ def test_test_iam_permissions_rest(
         return_value = compute.TestPermissionsResponse(
             permissions=["permissions_value"],
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.TestPermissionsResponse.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.test_iam_permissions(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.TestPermissionsResponse)
     assert response.permissions == ["permissions_value"]
 
@@ -1077,7 +1111,9 @@ def test_test_iam_permissions_rest_from_dict():
 
 
 def test_test_iam_permissions_rest_flattened():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1096,7 +1132,6 @@ def test_test_iam_permissions_rest_flattened():
         test_permissions_request_resource = compute.TestPermissionsRequest(
             permissions=["permissions_value"]
         )
-
         client.test_iam_permissions(
             project="project_value",
             resource="resource_value",
@@ -1108,11 +1143,8 @@ def test_test_iam_permissions_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "resource_value" in http_call[1] + str(body)
-
         assert compute.TestPermissionsRequest.to_json(
             test_permissions_request_resource,
             including_default_value_fields=False,
@@ -1121,7 +1153,9 @@ def test_test_iam_permissions_rest_flattened():
 
 
 def test_test_iam_permissions_rest_flattened_error():
-    client = ExternalVpnGatewaysClient(credentials=credentials.AnonymousCredentials(),)
+    client = ExternalVpnGatewaysClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1139,16 +1173,16 @@ def test_test_iam_permissions_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.ExternalVpnGatewaysRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = ExternalVpnGatewaysClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.ExternalVpnGatewaysRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = ExternalVpnGatewaysClient(
@@ -1158,7 +1192,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.ExternalVpnGatewaysRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = ExternalVpnGatewaysClient(
@@ -1169,7 +1203,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.ExternalVpnGatewaysRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = ExternalVpnGatewaysClient(transport=transport)
     assert client.transport is transport
@@ -1180,17 +1214,17 @@ def test_transport_instance():
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_external_vpn_gateways_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.ExternalVpnGatewaysTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1202,7 +1236,7 @@ def test_external_vpn_gateways_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.ExternalVpnGatewaysTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1220,15 +1254,40 @@ def test_external_vpn_gateways_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_external_vpn_gateways_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.external_vpn_gateways.transports.ExternalVpnGatewaysTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.ExternalVpnGatewaysTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_external_vpn_gateways_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.external_vpn_gateways.transports.ExternalVpnGatewaysTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.ExternalVpnGatewaysTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1244,19 +1303,36 @@ def test_external_vpn_gateways_base_transport_with_credentials_file():
 
 def test_external_vpn_gateways_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.external_vpn_gateways.transports.ExternalVpnGatewaysTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.ExternalVpnGatewaysTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_external_vpn_gateways_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        ExternalVpnGatewaysClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_external_vpn_gateways_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         ExternalVpnGatewaysClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1268,7 +1344,7 @@ def test_external_vpn_gateways_auth_adc():
 
 
 def test_external_vpn_gateways_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1280,7 +1356,7 @@ def test_external_vpn_gateways_http_transport_client_cert_source_for_mtls():
 
 def test_external_vpn_gateways_host_no_port():
     client = ExternalVpnGatewaysClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1290,7 +1366,7 @@ def test_external_vpn_gateways_host_no_port():
 
 def test_external_vpn_gateways_host_with_port():
     client = ExternalVpnGatewaysClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1300,7 +1376,6 @@ def test_external_vpn_gateways_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1321,7 +1396,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = ExternalVpnGatewaysClient.common_folder_path(folder)
     assert expected == actual
@@ -1340,7 +1414,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = ExternalVpnGatewaysClient.common_organization_path(organization)
     assert expected == actual
@@ -1359,7 +1432,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = ExternalVpnGatewaysClient.common_project_path(project)
     assert expected == actual
@@ -1379,7 +1451,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1406,7 +1477,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.ExternalVpnGatewaysTransport, "_prep_wrapped_messages"
     ) as prep:
         client = ExternalVpnGatewaysClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1415,6 +1486,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = ExternalVpnGatewaysClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
