@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,33 +13,63 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.global_network_endpoint_groups import (
     GlobalNetworkEndpointGroupsClient,
 )
 from google.cloud.compute_v1.services.global_network_endpoint_groups import pagers
 from google.cloud.compute_v1.services.global_network_endpoint_groups import transports
+from google.cloud.compute_v1.services.global_network_endpoint_groups.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.global_network_endpoint_groups.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -90,31 +119,35 @@ def test__get_default_mtls_endpoint():
     )
 
 
-def test_global_network_endpoint_groups_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [GlobalNetworkEndpointGroupsClient,])
+def test_global_network_endpoint_groups_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = GlobalNetworkEndpointGroupsClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [GlobalNetworkEndpointGroupsClient,])
 def test_global_network_endpoint_groups_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -152,7 +185,7 @@ def test_global_network_endpoint_groups_client_client_options(
     with mock.patch.object(
         GlobalNetworkEndpointGroupsClient, "get_transport_class"
     ) as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -415,7 +448,7 @@ def test_attach_network_endpoints_rest(
     request_type=compute.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest,
 ):
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -450,17 +483,16 @@ def test_attach_network_endpoints_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.attach_network_endpoints(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -495,7 +527,7 @@ def test_attach_network_endpoints_rest_from_dict():
 
 def test_attach_network_endpoints_rest_flattened():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the http request call within the method and fake a response.
@@ -517,7 +549,6 @@ def test_attach_network_endpoints_rest_flattened():
                 compute.NetworkEndpoint(annotations={"key_value": "value_value"})
             ]
         )
-
         client.attach_network_endpoints(
             project="project_value",
             network_endpoint_group="network_endpoint_group_value",
@@ -529,11 +560,8 @@ def test_attach_network_endpoints_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "network_endpoint_group_value" in http_call[1] + str(body)
-
         assert compute.GlobalNetworkEndpointGroupsAttachEndpointsRequest.to_json(
             global_network_endpoint_groups_attach_endpoints_request_resource,
             including_default_value_fields=False,
@@ -543,7 +571,7 @@ def test_attach_network_endpoints_rest_flattened():
 
 def test_attach_network_endpoints_rest_flattened_error():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -566,7 +594,7 @@ def test_delete_rest(
     request_type=compute.DeleteGlobalNetworkEndpointGroupRequest,
 ):
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -601,17 +629,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -646,7 +673,7 @@ def test_delete_rest_from_dict():
 
 def test_delete_rest_flattened():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the http request call within the method and fake a response.
@@ -673,15 +700,13 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "network_endpoint_group_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -699,7 +724,7 @@ def test_detach_network_endpoints_rest(
     request_type=compute.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest,
 ):
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -734,17 +759,16 @@ def test_detach_network_endpoints_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.detach_network_endpoints(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -779,7 +803,7 @@ def test_detach_network_endpoints_rest_from_dict():
 
 def test_detach_network_endpoints_rest_flattened():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the http request call within the method and fake a response.
@@ -801,7 +825,6 @@ def test_detach_network_endpoints_rest_flattened():
                 compute.NetworkEndpoint(annotations={"key_value": "value_value"})
             ]
         )
-
         client.detach_network_endpoints(
             project="project_value",
             network_endpoint_group="network_endpoint_group_value",
@@ -813,11 +836,8 @@ def test_detach_network_endpoints_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "network_endpoint_group_value" in http_call[1] + str(body)
-
         assert compute.GlobalNetworkEndpointGroupsDetachEndpointsRequest.to_json(
             global_network_endpoint_groups_detach_endpoints_request_resource,
             including_default_value_fields=False,
@@ -827,7 +847,7 @@ def test_detach_network_endpoints_rest_flattened():
 
 def test_detach_network_endpoints_rest_flattened_error():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -849,7 +869,7 @@ def test_get_rest(
     transport: str = "rest", request_type=compute.GetGlobalNetworkEndpointGroupRequest
 ):
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -880,17 +900,16 @@ def test_get_rest(
             subnetwork="subnetwork_value",
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.NetworkEndpointGroup.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.NetworkEndpointGroup)
     assert response.annotations == {"key_value": "value_value"}
     assert response.app_engine == compute.NetworkEndpointGroupAppEngine(
@@ -926,7 +945,7 @@ def test_get_rest_from_dict():
 
 def test_get_rest_flattened():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the http request call within the method and fake a response.
@@ -953,15 +972,13 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "network_endpoint_group_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -979,7 +996,7 @@ def test_insert_rest(
     request_type=compute.InsertGlobalNetworkEndpointGroupRequest,
 ):
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1014,17 +1031,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1059,7 +1075,7 @@ def test_insert_rest_from_dict():
 
 def test_insert_rest_flattened():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the http request call within the method and fake a response.
@@ -1079,7 +1095,6 @@ def test_insert_rest_flattened():
         network_endpoint_group_resource = compute.NetworkEndpointGroup(
             annotations={"key_value": "value_value"}
         )
-
         client.insert(
             project="project_value",
             network_endpoint_group_resource=network_endpoint_group_resource,
@@ -1090,9 +1105,7 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert compute.NetworkEndpointGroup.to_json(
             network_endpoint_group_resource,
             including_default_value_fields=False,
@@ -1102,7 +1115,7 @@ def test_insert_rest_flattened():
 
 def test_insert_rest_flattened_error():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -1121,7 +1134,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListGlobalNetworkEndpointGroupsRequest
 ):
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1141,17 +1154,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.NetworkEndpointGroupList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [
@@ -1169,7 +1181,7 @@ def test_list_rest_from_dict():
 
 def test_list_rest_flattened():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the http request call within the method and fake a response.
@@ -1193,13 +1205,12 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -1212,13 +1223,12 @@ def test_list_rest_flattened_error():
 
 def test_list_pager():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.NetworkEndpointGroupList(
                 items=[
@@ -1236,7 +1246,6 @@ def test_list_pager():
                 items=[compute.NetworkEndpointGroup(), compute.NetworkEndpointGroup(),],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -1255,7 +1264,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.NetworkEndpointGroup) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -1268,7 +1276,7 @@ def test_list_network_endpoints_rest(
     request_type=compute.ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest,
 ):
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1295,6 +1303,7 @@ def test_list_network_endpoints_rest(
             next_page_token="next_page_token_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.NetworkEndpointGroupsListNetworkEndpoints.to_json(
             return_value
@@ -1303,11 +1312,9 @@ def test_list_network_endpoints_rest(
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list_network_endpoints(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListNetworkEndpointsPager)
     assert response.id == "id_value"
     assert response.items == [
@@ -1332,7 +1339,7 @@ def test_list_network_endpoints_rest_from_dict():
 
 def test_list_network_endpoints_rest_flattened():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the http request call within the method and fake a response.
@@ -1361,15 +1368,13 @@ def test_list_network_endpoints_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "network_endpoint_group_value" in http_call[1] + str(body)
 
 
 def test_list_network_endpoints_rest_flattened_error():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -1384,13 +1389,12 @@ def test_list_network_endpoints_rest_flattened_error():
 
 def test_list_network_endpoints_pager():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.NetworkEndpointGroupsListNetworkEndpoints(
                 items=[
@@ -1414,7 +1418,6 @@ def test_list_network_endpoints_pager():
                 ],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -1436,7 +1439,6 @@ def test_list_network_endpoints_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(
             isinstance(i, compute.NetworkEndpointWithHealthStatus) for i in results
         )
@@ -1449,16 +1451,16 @@ def test_list_network_endpoints_pager():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.GlobalNetworkEndpointGroupsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = GlobalNetworkEndpointGroupsClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.GlobalNetworkEndpointGroupsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = GlobalNetworkEndpointGroupsClient(
@@ -1468,7 +1470,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.GlobalNetworkEndpointGroupsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = GlobalNetworkEndpointGroupsClient(
@@ -1479,7 +1481,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.GlobalNetworkEndpointGroupsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = GlobalNetworkEndpointGroupsClient(transport=transport)
     assert client.transport is transport
@@ -1490,17 +1492,17 @@ def test_transport_instance():
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_global_network_endpoint_groups_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.GlobalNetworkEndpointGroupsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1512,7 +1514,7 @@ def test_global_network_endpoint_groups_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.GlobalNetworkEndpointGroupsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1531,15 +1533,40 @@ def test_global_network_endpoint_groups_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_global_network_endpoint_groups_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.global_network_endpoint_groups.transports.GlobalNetworkEndpointGroupsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.GlobalNetworkEndpointGroupsTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_global_network_endpoint_groups_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.global_network_endpoint_groups.transports.GlobalNetworkEndpointGroupsTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.GlobalNetworkEndpointGroupsTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1555,19 +1582,36 @@ def test_global_network_endpoint_groups_base_transport_with_credentials_file():
 
 def test_global_network_endpoint_groups_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.global_network_endpoint_groups.transports.GlobalNetworkEndpointGroupsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.GlobalNetworkEndpointGroupsTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_global_network_endpoint_groups_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        GlobalNetworkEndpointGroupsClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_global_network_endpoint_groups_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         GlobalNetworkEndpointGroupsClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1579,7 +1623,7 @@ def test_global_network_endpoint_groups_auth_adc():
 
 
 def test_global_network_endpoint_groups_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1591,7 +1635,7 @@ def test_global_network_endpoint_groups_http_transport_client_cert_source_for_mt
 
 def test_global_network_endpoint_groups_host_no_port():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1601,7 +1645,7 @@ def test_global_network_endpoint_groups_host_no_port():
 
 def test_global_network_endpoint_groups_host_with_port():
     client = GlobalNetworkEndpointGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1611,7 +1655,6 @@ def test_global_network_endpoint_groups_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1634,7 +1677,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = GlobalNetworkEndpointGroupsClient.common_folder_path(folder)
     assert expected == actual
@@ -1653,7 +1695,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = GlobalNetworkEndpointGroupsClient.common_organization_path(organization)
     assert expected == actual
@@ -1672,7 +1713,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = GlobalNetworkEndpointGroupsClient.common_project_path(project)
     assert expected == actual
@@ -1692,7 +1732,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1719,7 +1758,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.GlobalNetworkEndpointGroupsTransport, "_prep_wrapped_messages"
     ) as prep:
         client = GlobalNetworkEndpointGroupsClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1728,6 +1767,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = GlobalNetworkEndpointGroupsClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
