@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,59 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.licenses import LicensesClient
 from google.cloud.compute_v1.services.licenses import pagers
 from google.cloud.compute_v1.services.licenses import transports
+from google.cloud.compute_v1.services.licenses.transports.base import _API_CORE_VERSION
+from google.cloud.compute_v1.services.licenses.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -80,31 +107,35 @@ def test__get_default_mtls_endpoint():
     assert LicensesClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-def test_licenses_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [LicensesClient,])
+def test_licenses_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = LicensesClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [LicensesClient,])
 def test_licenses_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -130,7 +161,7 @@ def test_licenses_client_get_transport_class():
 def test_licenses_client_client_options(client_class, transport_class, transport_name):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(LicensesClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -366,7 +397,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeleteLicenseRequest
 ):
     client = LicensesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -401,17 +432,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -445,7 +475,7 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -470,14 +500,12 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "license__value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -491,7 +519,7 @@ def test_delete_rest_flattened_error():
 
 def test_get_rest(transport: str = "rest", request_type=compute.GetLicenseRequest):
     client = LicensesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -515,19 +543,17 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetLicenseReques
             self_link="self_link_value",
             transferable=True,
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.License.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.License)
-
     assert response.charges_use_fee is True
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
@@ -539,7 +565,6 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetLicenseReques
         min_guest_cpu_count=2042
     )
     assert response.self_link == "self_link_value"
-
     assert response.transferable is True
 
 
@@ -548,7 +573,7 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -573,14 +598,12 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "license__value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -596,7 +619,7 @@ def test_get_iam_policy_rest(
     transport: str = "rest", request_type=compute.GetIamPolicyLicenseRequest
 ):
     client = LicensesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -622,17 +645,16 @@ def test_get_iam_policy_rest(
             rules=[compute.Rule(action=compute.Rule.Action.ALLOW)],
             version=774,
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Policy.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get_iam_policy(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Policy)
     assert response.audit_configs == [
         compute.AuditConfig(
@@ -643,7 +665,6 @@ def test_get_iam_policy_rest(
     ]
     assert response.bindings == [compute.Binding(binding_id="binding_id_value")]
     assert response.etag == "etag_value"
-
     assert response.iam_owned is True
     assert response.rules == [compute.Rule(action=compute.Rule.Action.ALLOW)]
     assert response.version == 774
@@ -654,7 +675,7 @@ def test_get_iam_policy_rest_from_dict():
 
 
 def test_get_iam_policy_rest_flattened():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -679,14 +700,12 @@ def test_get_iam_policy_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "resource_value" in http_call[1] + str(body)
 
 
 def test_get_iam_policy_rest_flattened_error():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -702,7 +721,7 @@ def test_insert_rest(
     transport: str = "rest", request_type=compute.InsertLicenseRequest
 ):
     client = LicensesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -737,17 +756,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -781,7 +799,7 @@ def test_insert_rest_from_dict():
 
 
 def test_insert_rest_flattened():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -798,7 +816,6 @@ def test_insert_rest_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         license_resource = compute.License(charges_use_fee=True)
-
         client.insert(
             project="project_value", license_resource=license_resource,
         )
@@ -808,9 +825,7 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert compute.License.to_json(
             license_resource,
             including_default_value_fields=False,
@@ -819,7 +834,7 @@ def test_insert_rest_flattened():
 
 
 def test_insert_rest_flattened_error():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -833,7 +848,7 @@ def test_insert_rest_flattened_error():
 
 def test_list_rest(transport: str = "rest", request_type=compute.ListLicensesRequest):
     client = LicensesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -850,17 +865,16 @@ def test_list_rest(transport: str = "rest", request_type=compute.ListLicensesReq
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.LicensesListResponse.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [compute.License(charges_use_fee=True)]
@@ -874,7 +888,7 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -897,12 +911,11 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -913,12 +926,11 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.LicensesListResponse(
                 items=[compute.License(), compute.License(), compute.License(),],
@@ -932,7 +944,6 @@ def test_list_pager():
                 items=[compute.License(), compute.License(),],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -951,7 +962,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.License) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -963,7 +973,7 @@ def test_set_iam_policy_rest(
     transport: str = "rest", request_type=compute.SetIamPolicyLicenseRequest
 ):
     client = LicensesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -989,17 +999,16 @@ def test_set_iam_policy_rest(
             rules=[compute.Rule(action=compute.Rule.Action.ALLOW)],
             version=774,
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Policy.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.set_iam_policy(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Policy)
     assert response.audit_configs == [
         compute.AuditConfig(
@@ -1010,7 +1019,6 @@ def test_set_iam_policy_rest(
     ]
     assert response.bindings == [compute.Binding(binding_id="binding_id_value")]
     assert response.etag == "etag_value"
-
     assert response.iam_owned is True
     assert response.rules == [compute.Rule(action=compute.Rule.Action.ALLOW)]
     assert response.version == 774
@@ -1021,7 +1029,7 @@ def test_set_iam_policy_rest_from_dict():
 
 
 def test_set_iam_policy_rest_flattened():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1040,7 +1048,6 @@ def test_set_iam_policy_rest_flattened():
         global_set_policy_request_resource = compute.GlobalSetPolicyRequest(
             bindings=[compute.Binding(binding_id="binding_id_value")]
         )
-
         client.set_iam_policy(
             project="project_value",
             resource="resource_value",
@@ -1052,11 +1059,8 @@ def test_set_iam_policy_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "resource_value" in http_call[1] + str(body)
-
         assert compute.GlobalSetPolicyRequest.to_json(
             global_set_policy_request_resource,
             including_default_value_fields=False,
@@ -1065,7 +1069,7 @@ def test_set_iam_policy_rest_flattened():
 
 
 def test_set_iam_policy_rest_flattened_error():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1084,7 +1088,7 @@ def test_test_iam_permissions_rest(
     transport: str = "rest", request_type=compute.TestIamPermissionsLicenseRequest
 ):
     client = LicensesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1097,17 +1101,16 @@ def test_test_iam_permissions_rest(
         return_value = compute.TestPermissionsResponse(
             permissions=["permissions_value"],
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.TestPermissionsResponse.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.test_iam_permissions(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.TestPermissionsResponse)
     assert response.permissions == ["permissions_value"]
 
@@ -1117,7 +1120,7 @@ def test_test_iam_permissions_rest_from_dict():
 
 
 def test_test_iam_permissions_rest_flattened():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1136,7 +1139,6 @@ def test_test_iam_permissions_rest_flattened():
         test_permissions_request_resource = compute.TestPermissionsRequest(
             permissions=["permissions_value"]
         )
-
         client.test_iam_permissions(
             project="project_value",
             resource="resource_value",
@@ -1148,11 +1150,8 @@ def test_test_iam_permissions_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "resource_value" in http_call[1] + str(body)
-
         assert compute.TestPermissionsRequest.to_json(
             test_permissions_request_resource,
             including_default_value_fields=False,
@@ -1161,7 +1160,7 @@ def test_test_iam_permissions_rest_flattened():
 
 
 def test_test_iam_permissions_rest_flattened_error():
-    client = LicensesClient(credentials=credentials.AnonymousCredentials(),)
+    client = LicensesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1179,16 +1178,16 @@ def test_test_iam_permissions_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.LicensesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = LicensesClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.LicensesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = LicensesClient(
@@ -1198,7 +1197,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.LicensesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = LicensesClient(
@@ -1209,7 +1208,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.LicensesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = LicensesClient(transport=transport)
     assert client.transport is transport
@@ -1218,17 +1217,17 @@ def test_transport_instance():
 @pytest.mark.parametrize("transport_class", [transports.LicensesRestTransport,])
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_licenses_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.LicensesTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1240,7 +1239,7 @@ def test_licenses_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.LicensesTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1259,15 +1258,40 @@ def test_licenses_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_licenses_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.licenses.transports.LicensesTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.LicensesTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_licenses_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.licenses.transports.LicensesTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.LicensesTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1283,19 +1307,36 @@ def test_licenses_base_transport_with_credentials_file():
 
 def test_licenses_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.licenses.transports.LicensesTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.LicensesTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_licenses_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        LicensesClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_licenses_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         LicensesClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1307,7 +1348,7 @@ def test_licenses_auth_adc():
 
 
 def test_licenses_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1319,7 +1360,7 @@ def test_licenses_http_transport_client_cert_source_for_mtls():
 
 def test_licenses_host_no_port():
     client = LicensesClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1329,7 +1370,7 @@ def test_licenses_host_no_port():
 
 def test_licenses_host_with_port():
     client = LicensesClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1339,7 +1380,6 @@ def test_licenses_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1360,7 +1400,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = LicensesClient.common_folder_path(folder)
     assert expected == actual
@@ -1379,7 +1418,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = LicensesClient.common_organization_path(organization)
     assert expected == actual
@@ -1398,7 +1436,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = LicensesClient.common_project_path(project)
     assert expected == actual
@@ -1418,7 +1455,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1445,7 +1481,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.LicensesTransport, "_prep_wrapped_messages"
     ) as prep:
         client = LicensesClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1454,6 +1490,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = LicensesClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
