@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,61 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.packet_mirrorings import PacketMirroringsClient
 from google.cloud.compute_v1.services.packet_mirrorings import pagers
 from google.cloud.compute_v1.services.packet_mirrorings import transports
+from google.cloud.compute_v1.services.packet_mirrorings.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.packet_mirrorings.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -86,31 +115,35 @@ def test__get_default_mtls_endpoint():
     )
 
 
-def test_packet_mirrorings_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [PacketMirroringsClient,])
+def test_packet_mirrorings_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = PacketMirroringsClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [PacketMirroringsClient,])
 def test_packet_mirrorings_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -140,7 +173,7 @@ def test_packet_mirrorings_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(PacketMirroringsClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -388,7 +421,7 @@ def test_aggregated_list_rest(
     transport: str = "rest", request_type=compute.AggregatedListPacketMirroringsRequest
 ):
     client = PacketMirroringsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -417,17 +450,16 @@ def test_aggregated_list_rest(
             unreachables=["unreachables_value"],
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.PacketMirroringAggregatedList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.aggregated_list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.AggregatedListPager)
     assert response.id == "id_value"
     assert response.items == {
@@ -453,7 +485,7 @@ def test_aggregated_list_rest_from_dict():
 
 
 def test_aggregated_list_rest_flattened():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -476,12 +508,11 @@ def test_aggregated_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_aggregated_list_rest_flattened_error():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -492,12 +523,11 @@ def test_aggregated_list_rest_flattened_error():
 
 
 def test_aggregated_list_pager():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.PacketMirroringAggregatedList(
                 items={
@@ -519,7 +549,6 @@ def test_aggregated_list_pager():
                 },
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -543,7 +572,6 @@ def test_aggregated_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, tuple) for i in results)
         for result in results:
             assert isinstance(result, tuple)
@@ -564,7 +592,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeletePacketMirroringRequest
 ):
     client = PacketMirroringsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -599,17 +627,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -643,7 +670,7 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -670,16 +697,13 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "packet_mirroring_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -696,7 +720,7 @@ def test_get_rest(
     transport: str = "rest", request_type=compute.GetPacketMirroringRequest
 ):
     client = PacketMirroringsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -731,17 +755,16 @@ def test_get_rest(
             region="region_value",
             self_link="self_link_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.PacketMirroring.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.PacketMirroring)
     assert response.collector_ilb == compute.PacketMirroringForwardingRuleInfo(
         canonical_url="canonical_url_value"
@@ -775,7 +798,7 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -802,16 +825,13 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "packet_mirroring_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -828,7 +848,7 @@ def test_insert_rest(
     transport: str = "rest", request_type=compute.InsertPacketMirroringRequest
 ):
     client = PacketMirroringsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -863,17 +883,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -907,7 +926,7 @@ def test_insert_rest_from_dict():
 
 
 def test_insert_rest_flattened():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -928,7 +947,6 @@ def test_insert_rest_flattened():
                 canonical_url="canonical_url_value"
             )
         )
-
         client.insert(
             project="project_value",
             region="region_value",
@@ -940,11 +958,8 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert compute.PacketMirroring.to_json(
             packet_mirroring_resource,
             including_default_value_fields=False,
@@ -953,7 +968,7 @@ def test_insert_rest_flattened():
 
 
 def test_insert_rest_flattened_error():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -974,7 +989,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListPacketMirroringsRequest
 ):
     client = PacketMirroringsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -998,17 +1013,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.PacketMirroringList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [
@@ -1029,7 +1043,7 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1054,14 +1068,12 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1074,12 +1086,11 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.PacketMirroringList(
                 items=[
@@ -1097,7 +1108,6 @@ def test_list_pager():
                 items=[compute.PacketMirroring(), compute.PacketMirroring(),],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -1116,7 +1126,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.PacketMirroring) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -1128,7 +1137,7 @@ def test_patch_rest(
     transport: str = "rest", request_type=compute.PatchPacketMirroringRequest
 ):
     client = PacketMirroringsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1163,17 +1172,16 @@ def test_patch_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.patch(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1207,7 +1215,7 @@ def test_patch_rest_from_dict():
 
 
 def test_patch_rest_flattened():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1228,7 +1236,6 @@ def test_patch_rest_flattened():
                 canonical_url="canonical_url_value"
             )
         )
-
         client.patch(
             project="project_value",
             region="region_value",
@@ -1241,13 +1248,9 @@ def test_patch_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "packet_mirroring_value" in http_call[1] + str(body)
-
         assert compute.PacketMirroring.to_json(
             packet_mirroring_resource,
             including_default_value_fields=False,
@@ -1256,7 +1259,7 @@ def test_patch_rest_flattened():
 
 
 def test_patch_rest_flattened_error():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1279,7 +1282,7 @@ def test_test_iam_permissions_rest(
     request_type=compute.TestIamPermissionsPacketMirroringRequest,
 ):
     client = PacketMirroringsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1292,17 +1295,16 @@ def test_test_iam_permissions_rest(
         return_value = compute.TestPermissionsResponse(
             permissions=["permissions_value"],
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.TestPermissionsResponse.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.test_iam_permissions(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.TestPermissionsResponse)
     assert response.permissions == ["permissions_value"]
 
@@ -1312,7 +1314,7 @@ def test_test_iam_permissions_rest_from_dict():
 
 
 def test_test_iam_permissions_rest_flattened():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1331,7 +1333,6 @@ def test_test_iam_permissions_rest_flattened():
         test_permissions_request_resource = compute.TestPermissionsRequest(
             permissions=["permissions_value"]
         )
-
         client.test_iam_permissions(
             project="project_value",
             region="region_value",
@@ -1344,13 +1345,9 @@ def test_test_iam_permissions_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "resource_value" in http_call[1] + str(body)
-
         assert compute.TestPermissionsRequest.to_json(
             test_permissions_request_resource,
             including_default_value_fields=False,
@@ -1359,7 +1356,7 @@ def test_test_iam_permissions_rest_flattened():
 
 
 def test_test_iam_permissions_rest_flattened_error():
-    client = PacketMirroringsClient(credentials=credentials.AnonymousCredentials(),)
+    client = PacketMirroringsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1378,16 +1375,16 @@ def test_test_iam_permissions_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.PacketMirroringsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = PacketMirroringsClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.PacketMirroringsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = PacketMirroringsClient(
@@ -1397,7 +1394,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.PacketMirroringsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = PacketMirroringsClient(
@@ -1408,7 +1405,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.PacketMirroringsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = PacketMirroringsClient(transport=transport)
     assert client.transport is transport
@@ -1417,17 +1414,17 @@ def test_transport_instance():
 @pytest.mark.parametrize("transport_class", [transports.PacketMirroringsRestTransport,])
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_packet_mirrorings_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.PacketMirroringsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1439,7 +1436,7 @@ def test_packet_mirrorings_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.PacketMirroringsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1458,15 +1455,40 @@ def test_packet_mirrorings_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_packet_mirrorings_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.packet_mirrorings.transports.PacketMirroringsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.PacketMirroringsTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_packet_mirrorings_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.packet_mirrorings.transports.PacketMirroringsTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.PacketMirroringsTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1482,19 +1504,36 @@ def test_packet_mirrorings_base_transport_with_credentials_file():
 
 def test_packet_mirrorings_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.packet_mirrorings.transports.PacketMirroringsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.PacketMirroringsTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_packet_mirrorings_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        PacketMirroringsClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_packet_mirrorings_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         PacketMirroringsClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1506,7 +1545,7 @@ def test_packet_mirrorings_auth_adc():
 
 
 def test_packet_mirrorings_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1518,7 +1557,7 @@ def test_packet_mirrorings_http_transport_client_cert_source_for_mtls():
 
 def test_packet_mirrorings_host_no_port():
     client = PacketMirroringsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1528,7 +1567,7 @@ def test_packet_mirrorings_host_no_port():
 
 def test_packet_mirrorings_host_with_port():
     client = PacketMirroringsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1538,7 +1577,6 @@ def test_packet_mirrorings_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1559,7 +1597,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = PacketMirroringsClient.common_folder_path(folder)
     assert expected == actual
@@ -1578,7 +1615,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = PacketMirroringsClient.common_organization_path(organization)
     assert expected == actual
@@ -1597,7 +1633,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = PacketMirroringsClient.common_project_path(project)
     assert expected == actual
@@ -1617,7 +1652,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1644,7 +1678,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.PacketMirroringsTransport, "_prep_wrapped_messages"
     ) as prep:
         client = PacketMirroringsClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1653,6 +1687,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = PacketMirroringsClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
