@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,61 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.region_autoscalers import RegionAutoscalersClient
 from google.cloud.compute_v1.services.region_autoscalers import pagers
 from google.cloud.compute_v1.services.region_autoscalers import transports
+from google.cloud.compute_v1.services.region_autoscalers.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.region_autoscalers.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -86,31 +115,35 @@ def test__get_default_mtls_endpoint():
     )
 
 
-def test_region_autoscalers_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [RegionAutoscalersClient,])
+def test_region_autoscalers_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = RegionAutoscalersClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [RegionAutoscalersClient,])
 def test_region_autoscalers_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -140,7 +173,7 @@ def test_region_autoscalers_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(RegionAutoscalersClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -388,7 +421,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeleteRegionAutoscalerRequest
 ):
     client = RegionAutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -423,17 +456,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -467,7 +499,7 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -494,16 +526,13 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "autoscaler_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -520,7 +549,7 @@ def test_get_rest(
     transport: str = "rest", request_type=compute.GetRegionAutoscalerRequest
 ):
     client = RegionAutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -545,17 +574,16 @@ def test_get_rest(
             target="target_value",
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Autoscaler.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Autoscaler)
     assert response.autoscaling_policy == compute.AutoscalingPolicy(
         cool_down_period_sec=2112
@@ -581,7 +609,7 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -608,16 +636,13 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "autoscaler_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -634,7 +659,7 @@ def test_insert_rest(
     transport: str = "rest", request_type=compute.InsertRegionAutoscalerRequest
 ):
     client = RegionAutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -669,17 +694,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -713,7 +737,7 @@ def test_insert_rest_from_dict():
 
 
 def test_insert_rest_flattened():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -732,7 +756,6 @@ def test_insert_rest_flattened():
         autoscaler_resource = compute.Autoscaler(
             autoscaling_policy=compute.AutoscalingPolicy(cool_down_period_sec=2112)
         )
-
         client.insert(
             project="project_value",
             region="region_value",
@@ -744,11 +767,8 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert compute.Autoscaler.to_json(
             autoscaler_resource,
             including_default_value_fields=False,
@@ -757,7 +777,7 @@ def test_insert_rest_flattened():
 
 
 def test_insert_rest_flattened_error():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -776,7 +796,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListRegionAutoscalersRequest
 ):
     client = RegionAutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -800,17 +820,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.RegionAutoscalerList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [
@@ -829,7 +848,7 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -854,14 +873,12 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -874,12 +891,11 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.RegionAutoscalerList(
                 items=[
@@ -897,7 +913,6 @@ def test_list_pager():
                 items=[compute.Autoscaler(), compute.Autoscaler(),],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -916,7 +931,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.Autoscaler) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -928,7 +942,7 @@ def test_patch_rest(
     transport: str = "rest", request_type=compute.PatchRegionAutoscalerRequest
 ):
     client = RegionAutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -963,17 +977,16 @@ def test_patch_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.patch(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1007,7 +1020,7 @@ def test_patch_rest_from_dict():
 
 
 def test_patch_rest_flattened():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1026,7 +1039,6 @@ def test_patch_rest_flattened():
         autoscaler_resource = compute.Autoscaler(
             autoscaling_policy=compute.AutoscalingPolicy(cool_down_period_sec=2112)
         )
-
         client.patch(
             project="project_value",
             region="region_value",
@@ -1038,11 +1050,8 @@ def test_patch_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert compute.Autoscaler.to_json(
             autoscaler_resource,
             including_default_value_fields=False,
@@ -1051,7 +1060,7 @@ def test_patch_rest_flattened():
 
 
 def test_patch_rest_flattened_error():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1070,7 +1079,7 @@ def test_update_rest(
     transport: str = "rest", request_type=compute.UpdateRegionAutoscalerRequest
 ):
     client = RegionAutoscalersClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1105,17 +1114,16 @@ def test_update_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.update(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1149,7 +1157,7 @@ def test_update_rest_from_dict():
 
 
 def test_update_rest_flattened():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1168,7 +1176,6 @@ def test_update_rest_flattened():
         autoscaler_resource = compute.Autoscaler(
             autoscaling_policy=compute.AutoscalingPolicy(cool_down_period_sec=2112)
         )
-
         client.update(
             project="project_value",
             region="region_value",
@@ -1180,11 +1187,8 @@ def test_update_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert compute.Autoscaler.to_json(
             autoscaler_resource,
             including_default_value_fields=False,
@@ -1193,7 +1197,7 @@ def test_update_rest_flattened():
 
 
 def test_update_rest_flattened_error():
-    client = RegionAutoscalersClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionAutoscalersClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1211,16 +1215,16 @@ def test_update_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.RegionAutoscalersRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = RegionAutoscalersClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.RegionAutoscalersRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = RegionAutoscalersClient(
@@ -1230,7 +1234,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.RegionAutoscalersRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = RegionAutoscalersClient(
@@ -1241,7 +1245,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.RegionAutoscalersRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = RegionAutoscalersClient(transport=transport)
     assert client.transport is transport
@@ -1252,17 +1256,17 @@ def test_transport_instance():
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_region_autoscalers_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.RegionAutoscalersTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1274,7 +1278,7 @@ def test_region_autoscalers_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.RegionAutoscalersTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1292,15 +1296,40 @@ def test_region_autoscalers_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_region_autoscalers_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.region_autoscalers.transports.RegionAutoscalersTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.RegionAutoscalersTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_region_autoscalers_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.region_autoscalers.transports.RegionAutoscalersTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.RegionAutoscalersTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1316,19 +1345,36 @@ def test_region_autoscalers_base_transport_with_credentials_file():
 
 def test_region_autoscalers_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.region_autoscalers.transports.RegionAutoscalersTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.RegionAutoscalersTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_region_autoscalers_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        RegionAutoscalersClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_region_autoscalers_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         RegionAutoscalersClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1340,7 +1386,7 @@ def test_region_autoscalers_auth_adc():
 
 
 def test_region_autoscalers_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1352,7 +1398,7 @@ def test_region_autoscalers_http_transport_client_cert_source_for_mtls():
 
 def test_region_autoscalers_host_no_port():
     client = RegionAutoscalersClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1362,7 +1408,7 @@ def test_region_autoscalers_host_no_port():
 
 def test_region_autoscalers_host_with_port():
     client = RegionAutoscalersClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1372,7 +1418,6 @@ def test_region_autoscalers_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1393,7 +1438,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = RegionAutoscalersClient.common_folder_path(folder)
     assert expected == actual
@@ -1412,7 +1456,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = RegionAutoscalersClient.common_organization_path(organization)
     assert expected == actual
@@ -1431,7 +1474,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = RegionAutoscalersClient.common_project_path(project)
     assert expected == actual
@@ -1451,7 +1493,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1478,7 +1519,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.RegionAutoscalersTransport, "_prep_wrapped_messages"
     ) as prep:
         client = RegionAutoscalersClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1487,6 +1528,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = RegionAutoscalersClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
