@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,33 +13,63 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.region_instance_groups import (
     RegionInstanceGroupsClient,
 )
 from google.cloud.compute_v1.services.region_instance_groups import pagers
 from google.cloud.compute_v1.services.region_instance_groups import transports
+from google.cloud.compute_v1.services.region_instance_groups.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.region_instance_groups.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -88,31 +117,35 @@ def test__get_default_mtls_endpoint():
     )
 
 
-def test_region_instance_groups_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [RegionInstanceGroupsClient,])
+def test_region_instance_groups_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = RegionInstanceGroupsClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [RegionInstanceGroupsClient,])
 def test_region_instance_groups_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -148,7 +181,7 @@ def test_region_instance_groups_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(RegionInstanceGroupsClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -408,7 +441,7 @@ def test_get_rest(
     transport: str = "rest", request_type=compute.GetRegionInstanceGroupRequest
 ):
     client = RegionInstanceGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -433,17 +466,16 @@ def test_get_rest(
             subnetwork="subnetwork_value",
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.InstanceGroup.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.InstanceGroup)
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
@@ -465,7 +497,9 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = RegionInstanceGroupsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionInstanceGroupsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -492,16 +526,15 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "instance_group_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = RegionInstanceGroupsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionInstanceGroupsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -518,7 +551,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListRegionInstanceGroupsRequest
 ):
     client = RegionInstanceGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -538,17 +571,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.RegionInstanceGroupList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [
@@ -565,7 +597,9 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = RegionInstanceGroupsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionInstanceGroupsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -590,14 +624,14 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = RegionInstanceGroupsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionInstanceGroupsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -610,12 +644,13 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = RegionInstanceGroupsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionInstanceGroupsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.RegionInstanceGroupList(
                 items=[
@@ -633,7 +668,6 @@ def test_list_pager():
                 items=[compute.InstanceGroup(), compute.InstanceGroup(),],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -652,7 +686,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.InstanceGroup) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -665,7 +698,7 @@ def test_list_instances_rest(
     request_type=compute.ListInstancesRegionInstanceGroupsRequest,
 ):
     client = RegionInstanceGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -683,6 +716,7 @@ def test_list_instances_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.RegionInstanceGroupsListInstances.to_json(
             return_value
@@ -691,11 +725,9 @@ def test_list_instances_rest(
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list_instances(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListInstancesPager)
     assert response.id == "id_value"
     assert response.items == [compute.InstanceWithNamedPorts(instance="instance_value")]
@@ -710,7 +742,9 @@ def test_list_instances_rest_from_dict():
 
 
 def test_list_instances_rest_flattened():
-    client = RegionInstanceGroupsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionInstanceGroupsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -731,7 +765,6 @@ def test_list_instances_rest_flattened():
         region_instance_groups_list_instances_request_resource = compute.RegionInstanceGroupsListInstancesRequest(
             instance_state=compute.RegionInstanceGroupsListInstancesRequest.InstanceState.ALL
         )
-
         client.list_instances(
             project="project_value",
             region="region_value",
@@ -744,13 +777,9 @@ def test_list_instances_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "instance_group_value" in http_call[1] + str(body)
-
         assert compute.RegionInstanceGroupsListInstancesRequest.to_json(
             region_instance_groups_list_instances_request_resource,
             including_default_value_fields=False,
@@ -759,7 +788,9 @@ def test_list_instances_rest_flattened():
 
 
 def test_list_instances_rest_flattened_error():
-    client = RegionInstanceGroupsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionInstanceGroupsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -776,12 +807,13 @@ def test_list_instances_rest_flattened_error():
 
 
 def test_list_instances_pager():
-    client = RegionInstanceGroupsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionInstanceGroupsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.RegionInstanceGroupsListInstances(
                 items=[
@@ -802,7 +834,6 @@ def test_list_instances_pager():
                 ],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -823,7 +854,6 @@ def test_list_instances_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.InstanceWithNamedPorts) for i in results)
 
         pages = list(client.list_instances(request={}).pages)
@@ -836,7 +866,7 @@ def test_set_named_ports_rest(
     request_type=compute.SetNamedPortsRegionInstanceGroupRequest,
 ):
     client = RegionInstanceGroupsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -871,17 +901,16 @@ def test_set_named_ports_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.set_named_ports(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -915,7 +944,9 @@ def test_set_named_ports_rest_from_dict():
 
 
 def test_set_named_ports_rest_flattened():
-    client = RegionInstanceGroupsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionInstanceGroupsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -934,7 +965,6 @@ def test_set_named_ports_rest_flattened():
         region_instance_groups_set_named_ports_request_resource = compute.RegionInstanceGroupsSetNamedPortsRequest(
             fingerprint="fingerprint_value"
         )
-
         client.set_named_ports(
             project="project_value",
             region="region_value",
@@ -947,13 +977,9 @@ def test_set_named_ports_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "instance_group_value" in http_call[1] + str(body)
-
         assert compute.RegionInstanceGroupsSetNamedPortsRequest.to_json(
             region_instance_groups_set_named_ports_request_resource,
             including_default_value_fields=False,
@@ -962,7 +988,9 @@ def test_set_named_ports_rest_flattened():
 
 
 def test_set_named_ports_rest_flattened_error():
-    client = RegionInstanceGroupsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionInstanceGroupsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -981,16 +1009,16 @@ def test_set_named_ports_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.RegionInstanceGroupsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = RegionInstanceGroupsClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.RegionInstanceGroupsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = RegionInstanceGroupsClient(
@@ -1000,7 +1028,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.RegionInstanceGroupsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = RegionInstanceGroupsClient(
@@ -1011,7 +1039,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.RegionInstanceGroupsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = RegionInstanceGroupsClient(transport=transport)
     assert client.transport is transport
@@ -1022,17 +1050,17 @@ def test_transport_instance():
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_region_instance_groups_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.RegionInstanceGroupsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1044,7 +1072,7 @@ def test_region_instance_groups_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.RegionInstanceGroupsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1060,15 +1088,40 @@ def test_region_instance_groups_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_region_instance_groups_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.region_instance_groups.transports.RegionInstanceGroupsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.RegionInstanceGroupsTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_region_instance_groups_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.region_instance_groups.transports.RegionInstanceGroupsTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.RegionInstanceGroupsTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1084,19 +1137,36 @@ def test_region_instance_groups_base_transport_with_credentials_file():
 
 def test_region_instance_groups_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.region_instance_groups.transports.RegionInstanceGroupsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.RegionInstanceGroupsTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_region_instance_groups_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        RegionInstanceGroupsClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_region_instance_groups_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         RegionInstanceGroupsClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1108,7 +1178,7 @@ def test_region_instance_groups_auth_adc():
 
 
 def test_region_instance_groups_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1120,7 +1190,7 @@ def test_region_instance_groups_http_transport_client_cert_source_for_mtls():
 
 def test_region_instance_groups_host_no_port():
     client = RegionInstanceGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1130,7 +1200,7 @@ def test_region_instance_groups_host_no_port():
 
 def test_region_instance_groups_host_with_port():
     client = RegionInstanceGroupsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1140,7 +1210,6 @@ def test_region_instance_groups_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1161,7 +1230,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = RegionInstanceGroupsClient.common_folder_path(folder)
     assert expected == actual
@@ -1180,7 +1248,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = RegionInstanceGroupsClient.common_organization_path(organization)
     assert expected == actual
@@ -1199,7 +1266,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = RegionInstanceGroupsClient.common_project_path(project)
     assert expected == actual
@@ -1219,7 +1285,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1246,7 +1311,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.RegionInstanceGroupsTransport, "_prep_wrapped_messages"
     ) as prep:
         client = RegionInstanceGroupsClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1255,6 +1320,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = RegionInstanceGroupsClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
