@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,61 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.region_url_maps import RegionUrlMapsClient
 from google.cloud.compute_v1.services.region_url_maps import pagers
 from google.cloud.compute_v1.services.region_url_maps import transports
+from google.cloud.compute_v1.services.region_url_maps.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.region_url_maps.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -85,31 +114,35 @@ def test__get_default_mtls_endpoint():
     )
 
 
-def test_region_url_maps_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [RegionUrlMapsClient,])
+def test_region_url_maps_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = RegionUrlMapsClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [RegionUrlMapsClient,])
 def test_region_url_maps_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -139,7 +172,7 @@ def test_region_url_maps_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(RegionUrlMapsClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -377,7 +410,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeleteRegionUrlMapRequest
 ):
     client = RegionUrlMapsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -412,17 +445,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -456,7 +488,7 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -481,16 +513,13 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "url_map_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -505,7 +534,7 @@ def test_delete_rest_flattened_error():
 
 def test_get_rest(transport: str = "rest", request_type=compute.GetRegionUrlMapRequest):
     client = RegionUrlMapsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -546,17 +575,16 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRegionUrlMapR
             self_link="self_link_value",
             tests=[compute.UrlMapTest(description="description_value")],
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.UrlMap.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.UrlMap)
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.default_route_action == compute.HttpRouteAction(
@@ -594,7 +622,7 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -619,16 +647,13 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "url_map_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -645,7 +670,7 @@ def test_insert_rest(
     transport: str = "rest", request_type=compute.InsertRegionUrlMapRequest
 ):
     client = RegionUrlMapsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -680,17 +705,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -724,7 +748,7 @@ def test_insert_rest_from_dict():
 
 
 def test_insert_rest_flattened():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -741,7 +765,6 @@ def test_insert_rest_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         url_map_resource = compute.UrlMap(creation_timestamp="creation_timestamp_value")
-
         client.insert(
             project="project_value",
             region="region_value",
@@ -753,11 +776,8 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert compute.UrlMap.to_json(
             url_map_resource,
             including_default_value_fields=False,
@@ -766,7 +786,7 @@ def test_insert_rest_flattened():
 
 
 def test_insert_rest_flattened_error():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -785,7 +805,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListRegionUrlMapsRequest
 ):
     client = RegionUrlMapsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -803,17 +823,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.UrlMapList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [
@@ -830,7 +849,7 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -855,14 +874,12 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -875,12 +892,11 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.UrlMapList(
                 items=[compute.UrlMap(), compute.UrlMap(), compute.UrlMap(),],
@@ -890,7 +906,6 @@ def test_list_pager():
             compute.UrlMapList(items=[compute.UrlMap(),], next_page_token="ghi",),
             compute.UrlMapList(items=[compute.UrlMap(), compute.UrlMap(),],),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -909,7 +924,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.UrlMap) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -921,7 +935,7 @@ def test_patch_rest(
     transport: str = "rest", request_type=compute.PatchRegionUrlMapRequest
 ):
     client = RegionUrlMapsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -956,17 +970,16 @@ def test_patch_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.patch(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1000,7 +1013,7 @@ def test_patch_rest_from_dict():
 
 
 def test_patch_rest_flattened():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1017,7 +1030,6 @@ def test_patch_rest_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         url_map_resource = compute.UrlMap(creation_timestamp="creation_timestamp_value")
-
         client.patch(
             project="project_value",
             region="region_value",
@@ -1030,13 +1042,9 @@ def test_patch_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "url_map_value" in http_call[1] + str(body)
-
         assert compute.UrlMap.to_json(
             url_map_resource,
             including_default_value_fields=False,
@@ -1045,7 +1053,7 @@ def test_patch_rest_flattened():
 
 
 def test_patch_rest_flattened_error():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1065,7 +1073,7 @@ def test_update_rest(
     transport: str = "rest", request_type=compute.UpdateRegionUrlMapRequest
 ):
     client = RegionUrlMapsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1100,17 +1108,16 @@ def test_update_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.update(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1144,7 +1151,7 @@ def test_update_rest_from_dict():
 
 
 def test_update_rest_flattened():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1161,7 +1168,6 @@ def test_update_rest_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         url_map_resource = compute.UrlMap(creation_timestamp="creation_timestamp_value")
-
         client.update(
             project="project_value",
             region="region_value",
@@ -1174,13 +1180,9 @@ def test_update_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "url_map_value" in http_call[1] + str(body)
-
         assert compute.UrlMap.to_json(
             url_map_resource,
             including_default_value_fields=False,
@@ -1189,7 +1191,7 @@ def test_update_rest_flattened():
 
 
 def test_update_rest_flattened_error():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1209,7 +1211,7 @@ def test_validate_rest(
     transport: str = "rest", request_type=compute.ValidateRegionUrlMapRequest
 ):
     client = RegionUrlMapsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1222,17 +1224,16 @@ def test_validate_rest(
         return_value = compute.UrlMapsValidateResponse(
             result=compute.UrlMapValidationResult(load_errors=["load_errors_value"]),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.UrlMapsValidateResponse.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.validate(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.UrlMapsValidateResponse)
     assert response.result == compute.UrlMapValidationResult(
         load_errors=["load_errors_value"]
@@ -1244,7 +1245,7 @@ def test_validate_rest_from_dict():
 
 
 def test_validate_rest_flattened():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1263,7 +1264,6 @@ def test_validate_rest_flattened():
         region_url_maps_validate_request_resource = compute.RegionUrlMapsValidateRequest(
             resource=compute.UrlMap(creation_timestamp="creation_timestamp_value")
         )
-
         client.validate(
             project="project_value",
             region="region_value",
@@ -1276,13 +1276,9 @@ def test_validate_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "region_value" in http_call[1] + str(body)
-
         assert "url_map_value" in http_call[1] + str(body)
-
         assert compute.RegionUrlMapsValidateRequest.to_json(
             region_url_maps_validate_request_resource,
             including_default_value_fields=False,
@@ -1291,7 +1287,7 @@ def test_validate_rest_flattened():
 
 
 def test_validate_rest_flattened_error():
-    client = RegionUrlMapsClient(credentials=credentials.AnonymousCredentials(),)
+    client = RegionUrlMapsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1310,16 +1306,16 @@ def test_validate_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.RegionUrlMapsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = RegionUrlMapsClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.RegionUrlMapsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = RegionUrlMapsClient(
@@ -1329,7 +1325,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.RegionUrlMapsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = RegionUrlMapsClient(
@@ -1340,7 +1336,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.RegionUrlMapsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = RegionUrlMapsClient(transport=transport)
     assert client.transport is transport
@@ -1349,17 +1345,17 @@ def test_transport_instance():
 @pytest.mark.parametrize("transport_class", [transports.RegionUrlMapsRestTransport,])
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_region_url_maps_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.RegionUrlMapsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1371,7 +1367,7 @@ def test_region_url_maps_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.RegionUrlMapsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1390,15 +1386,40 @@ def test_region_url_maps_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_region_url_maps_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.region_url_maps.transports.RegionUrlMapsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.RegionUrlMapsTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_region_url_maps_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.region_url_maps.transports.RegionUrlMapsTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.RegionUrlMapsTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1414,19 +1435,36 @@ def test_region_url_maps_base_transport_with_credentials_file():
 
 def test_region_url_maps_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.region_url_maps.transports.RegionUrlMapsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.RegionUrlMapsTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_region_url_maps_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        RegionUrlMapsClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_region_url_maps_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         RegionUrlMapsClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1438,7 +1476,7 @@ def test_region_url_maps_auth_adc():
 
 
 def test_region_url_maps_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1450,7 +1488,7 @@ def test_region_url_maps_http_transport_client_cert_source_for_mtls():
 
 def test_region_url_maps_host_no_port():
     client = RegionUrlMapsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1460,7 +1498,7 @@ def test_region_url_maps_host_no_port():
 
 def test_region_url_maps_host_with_port():
     client = RegionUrlMapsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1470,7 +1508,6 @@ def test_region_url_maps_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1491,7 +1528,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = RegionUrlMapsClient.common_folder_path(folder)
     assert expected == actual
@@ -1510,7 +1546,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = RegionUrlMapsClient.common_organization_path(organization)
     assert expected == actual
@@ -1529,7 +1564,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = RegionUrlMapsClient.common_project_path(project)
     assert expected == actual
@@ -1549,7 +1583,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1576,7 +1609,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.RegionUrlMapsTransport, "_prep_wrapped_messages"
     ) as prep:
         client = RegionUrlMapsClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1585,6 +1618,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = RegionUrlMapsClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
