@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,59 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.snapshots import SnapshotsClient
 from google.cloud.compute_v1.services.snapshots import pagers
 from google.cloud.compute_v1.services.snapshots import transports
+from google.cloud.compute_v1.services.snapshots.transports.base import _API_CORE_VERSION
+from google.cloud.compute_v1.services.snapshots.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -80,31 +107,35 @@ def test__get_default_mtls_endpoint():
     assert SnapshotsClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-def test_snapshots_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [SnapshotsClient,])
+def test_snapshots_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = SnapshotsClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [SnapshotsClient,])
 def test_snapshots_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -130,7 +161,7 @@ def test_snapshots_client_get_transport_class():
 def test_snapshots_client_client_options(client_class, transport_class, transport_name):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(SnapshotsClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -366,7 +397,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeleteSnapshotRequest
 ):
     client = SnapshotsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -401,17 +432,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -445,7 +475,7 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -470,14 +500,12 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "snapshot_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -491,7 +519,7 @@ def test_delete_rest_flattened_error():
 
 def test_get_rest(transport: str = "rest", request_type=compute.GetSnapshotRequest):
     client = SnapshotsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -529,19 +557,17 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetSnapshotReque
             storage_bytes_status=compute.Snapshot.StorageBytesStatus.UPDATING,
             storage_locations=["storage_locations_value"],
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Snapshot.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Snapshot)
-
     assert response.auto_created is True
     assert response.chain_name == "chain_name_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -575,7 +601,7 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -600,14 +626,12 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "snapshot_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -623,7 +647,7 @@ def test_get_iam_policy_rest(
     transport: str = "rest", request_type=compute.GetIamPolicySnapshotRequest
 ):
     client = SnapshotsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -649,17 +673,16 @@ def test_get_iam_policy_rest(
             rules=[compute.Rule(action=compute.Rule.Action.ALLOW)],
             version=774,
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Policy.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get_iam_policy(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Policy)
     assert response.audit_configs == [
         compute.AuditConfig(
@@ -670,7 +693,6 @@ def test_get_iam_policy_rest(
     ]
     assert response.bindings == [compute.Binding(binding_id="binding_id_value")]
     assert response.etag == "etag_value"
-
     assert response.iam_owned is True
     assert response.rules == [compute.Rule(action=compute.Rule.Action.ALLOW)]
     assert response.version == 774
@@ -681,7 +703,7 @@ def test_get_iam_policy_rest_from_dict():
 
 
 def test_get_iam_policy_rest_flattened():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -706,14 +728,12 @@ def test_get_iam_policy_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "resource_value" in http_call[1] + str(body)
 
 
 def test_get_iam_policy_rest_flattened_error():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -727,7 +747,7 @@ def test_get_iam_policy_rest_flattened_error():
 
 def test_list_rest(transport: str = "rest", request_type=compute.ListSnapshotsRequest):
     client = SnapshotsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -745,17 +765,16 @@ def test_list_rest(transport: str = "rest", request_type=compute.ListSnapshotsRe
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.SnapshotList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [compute.Snapshot(auto_created=True)]
@@ -770,7 +789,7 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -793,12 +812,11 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -809,12 +827,11 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.SnapshotList(
                 items=[compute.Snapshot(), compute.Snapshot(), compute.Snapshot(),],
@@ -824,7 +841,6 @@ def test_list_pager():
             compute.SnapshotList(items=[compute.Snapshot(),], next_page_token="ghi",),
             compute.SnapshotList(items=[compute.Snapshot(), compute.Snapshot(),],),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -843,7 +859,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.Snapshot) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -855,7 +870,7 @@ def test_set_iam_policy_rest(
     transport: str = "rest", request_type=compute.SetIamPolicySnapshotRequest
 ):
     client = SnapshotsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -881,17 +896,16 @@ def test_set_iam_policy_rest(
             rules=[compute.Rule(action=compute.Rule.Action.ALLOW)],
             version=774,
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Policy.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.set_iam_policy(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Policy)
     assert response.audit_configs == [
         compute.AuditConfig(
@@ -902,7 +916,6 @@ def test_set_iam_policy_rest(
     ]
     assert response.bindings == [compute.Binding(binding_id="binding_id_value")]
     assert response.etag == "etag_value"
-
     assert response.iam_owned is True
     assert response.rules == [compute.Rule(action=compute.Rule.Action.ALLOW)]
     assert response.version == 774
@@ -913,7 +926,7 @@ def test_set_iam_policy_rest_from_dict():
 
 
 def test_set_iam_policy_rest_flattened():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -932,7 +945,6 @@ def test_set_iam_policy_rest_flattened():
         global_set_policy_request_resource = compute.GlobalSetPolicyRequest(
             bindings=[compute.Binding(binding_id="binding_id_value")]
         )
-
         client.set_iam_policy(
             project="project_value",
             resource="resource_value",
@@ -944,11 +956,8 @@ def test_set_iam_policy_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "resource_value" in http_call[1] + str(body)
-
         assert compute.GlobalSetPolicyRequest.to_json(
             global_set_policy_request_resource,
             including_default_value_fields=False,
@@ -957,7 +966,7 @@ def test_set_iam_policy_rest_flattened():
 
 
 def test_set_iam_policy_rest_flattened_error():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -976,7 +985,7 @@ def test_set_labels_rest(
     transport: str = "rest", request_type=compute.SetLabelsSnapshotRequest
 ):
     client = SnapshotsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1011,17 +1020,16 @@ def test_set_labels_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.set_labels(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1055,7 +1063,7 @@ def test_set_labels_rest_from_dict():
 
 
 def test_set_labels_rest_flattened():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1074,7 +1082,6 @@ def test_set_labels_rest_flattened():
         global_set_labels_request_resource = compute.GlobalSetLabelsRequest(
             label_fingerprint="label_fingerprint_value"
         )
-
         client.set_labels(
             project="project_value",
             resource="resource_value",
@@ -1086,11 +1093,8 @@ def test_set_labels_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "resource_value" in http_call[1] + str(body)
-
         assert compute.GlobalSetLabelsRequest.to_json(
             global_set_labels_request_resource,
             including_default_value_fields=False,
@@ -1099,7 +1103,7 @@ def test_set_labels_rest_flattened():
 
 
 def test_set_labels_rest_flattened_error():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1118,7 +1122,7 @@ def test_test_iam_permissions_rest(
     transport: str = "rest", request_type=compute.TestIamPermissionsSnapshotRequest
 ):
     client = SnapshotsClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1131,17 +1135,16 @@ def test_test_iam_permissions_rest(
         return_value = compute.TestPermissionsResponse(
             permissions=["permissions_value"],
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.TestPermissionsResponse.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.test_iam_permissions(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.TestPermissionsResponse)
     assert response.permissions == ["permissions_value"]
 
@@ -1151,7 +1154,7 @@ def test_test_iam_permissions_rest_from_dict():
 
 
 def test_test_iam_permissions_rest_flattened():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1170,7 +1173,6 @@ def test_test_iam_permissions_rest_flattened():
         test_permissions_request_resource = compute.TestPermissionsRequest(
             permissions=["permissions_value"]
         )
-
         client.test_iam_permissions(
             project="project_value",
             resource="resource_value",
@@ -1182,11 +1184,8 @@ def test_test_iam_permissions_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "resource_value" in http_call[1] + str(body)
-
         assert compute.TestPermissionsRequest.to_json(
             test_permissions_request_resource,
             including_default_value_fields=False,
@@ -1195,7 +1194,7 @@ def test_test_iam_permissions_rest_flattened():
 
 
 def test_test_iam_permissions_rest_flattened_error():
-    client = SnapshotsClient(credentials=credentials.AnonymousCredentials(),)
+    client = SnapshotsClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1213,16 +1212,16 @@ def test_test_iam_permissions_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.SnapshotsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = SnapshotsClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.SnapshotsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = SnapshotsClient(
@@ -1232,7 +1231,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.SnapshotsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = SnapshotsClient(
@@ -1243,7 +1242,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.SnapshotsRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = SnapshotsClient(transport=transport)
     assert client.transport is transport
@@ -1252,17 +1251,17 @@ def test_transport_instance():
 @pytest.mark.parametrize("transport_class", [transports.SnapshotsRestTransport,])
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_snapshots_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.SnapshotsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1274,7 +1273,7 @@ def test_snapshots_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.SnapshotsTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1293,15 +1292,40 @@ def test_snapshots_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_snapshots_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.snapshots.transports.SnapshotsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.SnapshotsTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_snapshots_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.snapshots.transports.SnapshotsTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.SnapshotsTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1317,19 +1341,36 @@ def test_snapshots_base_transport_with_credentials_file():
 
 def test_snapshots_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.snapshots.transports.SnapshotsTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.SnapshotsTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_snapshots_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        SnapshotsClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_snapshots_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         SnapshotsClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1341,7 +1382,7 @@ def test_snapshots_auth_adc():
 
 
 def test_snapshots_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1353,7 +1394,7 @@ def test_snapshots_http_transport_client_cert_source_for_mtls():
 
 def test_snapshots_host_no_port():
     client = SnapshotsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1363,7 +1404,7 @@ def test_snapshots_host_no_port():
 
 def test_snapshots_host_with_port():
     client = SnapshotsClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1373,7 +1414,6 @@ def test_snapshots_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1394,7 +1434,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = SnapshotsClient.common_folder_path(folder)
     assert expected == actual
@@ -1413,7 +1452,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = SnapshotsClient.common_organization_path(organization)
     assert expected == actual
@@ -1432,7 +1470,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = SnapshotsClient.common_project_path(project)
     assert expected == actual
@@ -1452,7 +1489,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1479,7 +1515,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.SnapshotsTransport, "_prep_wrapped_messages"
     ) as prep:
         client = SnapshotsClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1488,6 +1524,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = SnapshotsClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
