@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,61 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.ssl_policies import SslPoliciesClient
 from google.cloud.compute_v1.services.ssl_policies import pagers
 from google.cloud.compute_v1.services.ssl_policies import transports
+from google.cloud.compute_v1.services.ssl_policies.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.ssl_policies.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -82,31 +111,35 @@ def test__get_default_mtls_endpoint():
     assert SslPoliciesClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-def test_ssl_policies_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [SslPoliciesClient,])
+def test_ssl_policies_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = SslPoliciesClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [SslPoliciesClient,])
 def test_ssl_policies_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -134,7 +167,7 @@ def test_ssl_policies_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(SslPoliciesClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -370,7 +403,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeleteSslPolicyRequest
 ):
     client = SslPoliciesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -405,17 +438,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -449,7 +481,7 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -474,14 +506,12 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "ssl_policy_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -495,7 +525,7 @@ def test_delete_rest_flattened_error():
 
 def test_get_rest(transport: str = "rest", request_type=compute.GetSslPolicyRequest):
     client = SslPoliciesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -519,17 +549,16 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetSslPolicyRequ
             self_link="self_link_value",
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.SslPolicy.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.SslPolicy)
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.custom_features == ["custom_features_value"]
@@ -552,7 +581,7 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -577,14 +606,12 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "ssl_policy_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -600,7 +627,7 @@ def test_insert_rest(
     transport: str = "rest", request_type=compute.InsertSslPolicyRequest
 ):
     client = SslPoliciesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -635,17 +662,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -679,7 +705,7 @@ def test_insert_rest_from_dict():
 
 
 def test_insert_rest_flattened():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -698,7 +724,6 @@ def test_insert_rest_flattened():
         ssl_policy_resource = compute.SslPolicy(
             creation_timestamp="creation_timestamp_value"
         )
-
         client.insert(
             project="project_value", ssl_policy_resource=ssl_policy_resource,
         )
@@ -708,9 +733,7 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert compute.SslPolicy.to_json(
             ssl_policy_resource,
             including_default_value_fields=False,
@@ -719,7 +742,7 @@ def test_insert_rest_flattened():
 
 
 def test_insert_rest_flattened_error():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -737,7 +760,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListSslPoliciesRequest
 ):
     client = SslPoliciesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -755,17 +778,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.SslPoliciesList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [
@@ -782,7 +804,7 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -805,12 +827,11 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -821,12 +842,11 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.SslPoliciesList(
                 items=[compute.SslPolicy(), compute.SslPolicy(), compute.SslPolicy(),],
@@ -838,7 +858,6 @@ def test_list_pager():
             ),
             compute.SslPoliciesList(items=[compute.SslPolicy(), compute.SslPolicy(),],),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -857,7 +876,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.SslPolicy) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -870,7 +888,7 @@ def test_list_available_features_rest(
     request_type=compute.ListAvailableFeaturesSslPoliciesRequest,
 ):
     client = SslPoliciesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -883,6 +901,7 @@ def test_list_available_features_rest(
         return_value = compute.SslPoliciesListAvailableFeaturesResponse(
             features=["features_value"],
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.SslPoliciesListAvailableFeaturesResponse.to_json(
             return_value
@@ -891,11 +910,9 @@ def test_list_available_features_rest(
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list_available_features(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.SslPoliciesListAvailableFeaturesResponse)
     assert response.features == ["features_value"]
 
@@ -905,7 +922,7 @@ def test_list_available_features_rest_from_dict():
 
 
 def test_list_available_features_rest_flattened():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -930,12 +947,11 @@ def test_list_available_features_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_list_available_features_rest_flattened_error():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -949,7 +965,7 @@ def test_patch_rest(
     transport: str = "rest", request_type=compute.PatchSslPolicyRequest
 ):
     client = SslPoliciesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -984,17 +1000,16 @@ def test_patch_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.patch(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1028,7 +1043,7 @@ def test_patch_rest_from_dict():
 
 
 def test_patch_rest_flattened():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1047,7 +1062,6 @@ def test_patch_rest_flattened():
         ssl_policy_resource = compute.SslPolicy(
             creation_timestamp="creation_timestamp_value"
         )
-
         client.patch(
             project="project_value",
             ssl_policy="ssl_policy_value",
@@ -1059,11 +1073,8 @@ def test_patch_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "ssl_policy_value" in http_call[1] + str(body)
-
         assert compute.SslPolicy.to_json(
             ssl_policy_resource,
             including_default_value_fields=False,
@@ -1072,7 +1083,7 @@ def test_patch_rest_flattened():
 
 
 def test_patch_rest_flattened_error():
-    client = SslPoliciesClient(credentials=credentials.AnonymousCredentials(),)
+    client = SslPoliciesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1090,16 +1101,16 @@ def test_patch_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.SslPoliciesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = SslPoliciesClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.SslPoliciesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = SslPoliciesClient(
@@ -1109,7 +1120,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.SslPoliciesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = SslPoliciesClient(
@@ -1120,7 +1131,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.SslPoliciesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = SslPoliciesClient(transport=transport)
     assert client.transport is transport
@@ -1129,17 +1140,17 @@ def test_transport_instance():
 @pytest.mark.parametrize("transport_class", [transports.SslPoliciesRestTransport,])
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_ssl_policies_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.SslPoliciesTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1151,7 +1162,7 @@ def test_ssl_policies_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.SslPoliciesTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1169,15 +1180,40 @@ def test_ssl_policies_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_ssl_policies_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.ssl_policies.transports.SslPoliciesTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.SslPoliciesTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_ssl_policies_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.ssl_policies.transports.SslPoliciesTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.SslPoliciesTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1193,19 +1229,36 @@ def test_ssl_policies_base_transport_with_credentials_file():
 
 def test_ssl_policies_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.ssl_policies.transports.SslPoliciesTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.SslPoliciesTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_ssl_policies_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        SslPoliciesClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_ssl_policies_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         SslPoliciesClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1217,7 +1270,7 @@ def test_ssl_policies_auth_adc():
 
 
 def test_ssl_policies_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1229,7 +1282,7 @@ def test_ssl_policies_http_transport_client_cert_source_for_mtls():
 
 def test_ssl_policies_host_no_port():
     client = SslPoliciesClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1239,7 +1292,7 @@ def test_ssl_policies_host_no_port():
 
 def test_ssl_policies_host_with_port():
     client = SslPoliciesClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1249,7 +1302,6 @@ def test_ssl_policies_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1270,7 +1322,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = SslPoliciesClient.common_folder_path(folder)
     assert expected == actual
@@ -1289,7 +1340,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = SslPoliciesClient.common_organization_path(organization)
     assert expected == actual
@@ -1308,7 +1358,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = SslPoliciesClient.common_project_path(project)
     assert expected == actual
@@ -1328,7 +1377,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1355,7 +1403,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.SslPoliciesTransport, "_prep_wrapped_messages"
     ) as prep:
         client = SslPoliciesClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1364,6 +1412,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = SslPoliciesClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
