@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,61 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.target_http_proxies import TargetHttpProxiesClient
 from google.cloud.compute_v1.services.target_http_proxies import pagers
 from google.cloud.compute_v1.services.target_http_proxies import transports
+from google.cloud.compute_v1.services.target_http_proxies.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.target_http_proxies.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -86,31 +115,35 @@ def test__get_default_mtls_endpoint():
     )
 
 
-def test_target_http_proxies_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [TargetHttpProxiesClient,])
+def test_target_http_proxies_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = TargetHttpProxiesClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [TargetHttpProxiesClient,])
 def test_target_http_proxies_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -140,7 +173,7 @@ def test_target_http_proxies_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(TargetHttpProxiesClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -388,7 +421,7 @@ def test_aggregated_list_rest(
     transport: str = "rest", request_type=compute.AggregatedListTargetHttpProxiesRequest
 ):
     client = TargetHttpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -414,17 +447,16 @@ def test_aggregated_list_rest(
             self_link="self_link_value",
             unreachables=["unreachables_value"],
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.TargetHttpProxyAggregatedList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.aggregated_list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.AggregatedListPager)
     assert response.id == "id_value"
     assert response.items == {
@@ -445,7 +477,7 @@ def test_aggregated_list_rest_from_dict():
 
 
 def test_aggregated_list_rest_flattened():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -468,12 +500,11 @@ def test_aggregated_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_aggregated_list_rest_flattened_error():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -484,12 +515,11 @@ def test_aggregated_list_rest_flattened_error():
 
 
 def test_aggregated_list_pager():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.TargetHttpProxyAggregatedList(
                 items={
@@ -511,7 +541,6 @@ def test_aggregated_list_pager():
                 },
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -535,7 +564,6 @@ def test_aggregated_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, tuple) for i in results)
         for result in results:
             assert isinstance(result, tuple)
@@ -556,7 +584,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeleteTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -591,17 +619,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -635,7 +662,7 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -660,14 +687,12 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "target_http_proxy_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -683,7 +708,7 @@ def test_get_rest(
     transport: str = "rest", request_type=compute.GetTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -705,17 +730,16 @@ def test_get_rest(
             self_link="self_link_value",
             url_map="url_map_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.TargetHttpProxy.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.TargetHttpProxy)
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
@@ -723,7 +747,6 @@ def test_get_rest(
     assert response.id == "id_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
-
     assert response.proxy_bind is True
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
@@ -735,7 +758,7 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -760,14 +783,12 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "target_http_proxy_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -783,7 +804,7 @@ def test_insert_rest(
     transport: str = "rest", request_type=compute.InsertTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -818,17 +839,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -862,7 +882,7 @@ def test_insert_rest_from_dict():
 
 
 def test_insert_rest_flattened():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -881,7 +901,6 @@ def test_insert_rest_flattened():
         target_http_proxy_resource = compute.TargetHttpProxy(
             creation_timestamp="creation_timestamp_value"
         )
-
         client.insert(
             project="project_value",
             target_http_proxy_resource=target_http_proxy_resource,
@@ -892,9 +911,7 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert compute.TargetHttpProxy.to_json(
             target_http_proxy_resource,
             including_default_value_fields=False,
@@ -903,7 +920,7 @@ def test_insert_rest_flattened():
 
 
 def test_insert_rest_flattened_error():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -921,7 +938,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListTargetHttpProxiesRequest
 ):
     client = TargetHttpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -941,17 +958,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.TargetHttpProxyList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [
@@ -968,7 +984,7 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -991,12 +1007,11 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1007,12 +1022,11 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.TargetHttpProxyList(
                 items=[
@@ -1030,7 +1044,6 @@ def test_list_pager():
                 items=[compute.TargetHttpProxy(), compute.TargetHttpProxy(),],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -1049,7 +1062,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.TargetHttpProxy) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -1061,7 +1073,7 @@ def test_patch_rest(
     transport: str = "rest", request_type=compute.PatchTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1096,17 +1108,16 @@ def test_patch_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.patch(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1140,7 +1151,7 @@ def test_patch_rest_from_dict():
 
 
 def test_patch_rest_flattened():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1159,7 +1170,6 @@ def test_patch_rest_flattened():
         target_http_proxy_resource = compute.TargetHttpProxy(
             creation_timestamp="creation_timestamp_value"
         )
-
         client.patch(
             project="project_value",
             target_http_proxy="target_http_proxy_value",
@@ -1171,11 +1181,8 @@ def test_patch_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "target_http_proxy_value" in http_call[1] + str(body)
-
         assert compute.TargetHttpProxy.to_json(
             target_http_proxy_resource,
             including_default_value_fields=False,
@@ -1184,7 +1191,7 @@ def test_patch_rest_flattened():
 
 
 def test_patch_rest_flattened_error():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1203,7 +1210,7 @@ def test_set_url_map_rest(
     transport: str = "rest", request_type=compute.SetUrlMapTargetHttpProxyRequest
 ):
     client = TargetHttpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1238,17 +1245,16 @@ def test_set_url_map_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.set_url_map(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1282,7 +1288,7 @@ def test_set_url_map_rest_from_dict():
 
 
 def test_set_url_map_rest_flattened():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1299,7 +1305,6 @@ def test_set_url_map_rest_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         url_map_reference_resource = compute.UrlMapReference(url_map="url_map_value")
-
         client.set_url_map(
             project="project_value",
             target_http_proxy="target_http_proxy_value",
@@ -1311,11 +1316,8 @@ def test_set_url_map_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "target_http_proxy_value" in http_call[1] + str(body)
-
         assert compute.UrlMapReference.to_json(
             url_map_reference_resource,
             including_default_value_fields=False,
@@ -1324,7 +1326,7 @@ def test_set_url_map_rest_flattened():
 
 
 def test_set_url_map_rest_flattened_error():
-    client = TargetHttpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetHttpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1340,16 +1342,16 @@ def test_set_url_map_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.TargetHttpProxiesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = TargetHttpProxiesClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.TargetHttpProxiesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = TargetHttpProxiesClient(
@@ -1359,7 +1361,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.TargetHttpProxiesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = TargetHttpProxiesClient(
@@ -1370,7 +1372,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.TargetHttpProxiesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = TargetHttpProxiesClient(transport=transport)
     assert client.transport is transport
@@ -1381,17 +1383,17 @@ def test_transport_instance():
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_target_http_proxies_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.TargetHttpProxiesTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1403,7 +1405,7 @@ def test_target_http_proxies_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.TargetHttpProxiesTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1422,15 +1424,40 @@ def test_target_http_proxies_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_target_http_proxies_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.target_http_proxies.transports.TargetHttpProxiesTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.TargetHttpProxiesTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_target_http_proxies_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.target_http_proxies.transports.TargetHttpProxiesTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.TargetHttpProxiesTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1446,19 +1473,36 @@ def test_target_http_proxies_base_transport_with_credentials_file():
 
 def test_target_http_proxies_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.target_http_proxies.transports.TargetHttpProxiesTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.TargetHttpProxiesTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_target_http_proxies_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        TargetHttpProxiesClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_target_http_proxies_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         TargetHttpProxiesClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1470,7 +1514,7 @@ def test_target_http_proxies_auth_adc():
 
 
 def test_target_http_proxies_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1482,7 +1526,7 @@ def test_target_http_proxies_http_transport_client_cert_source_for_mtls():
 
 def test_target_http_proxies_host_no_port():
     client = TargetHttpProxiesClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1492,7 +1536,7 @@ def test_target_http_proxies_host_no_port():
 
 def test_target_http_proxies_host_with_port():
     client = TargetHttpProxiesClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1502,7 +1546,6 @@ def test_target_http_proxies_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1523,7 +1566,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = TargetHttpProxiesClient.common_folder_path(folder)
     assert expected == actual
@@ -1542,7 +1584,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = TargetHttpProxiesClient.common_organization_path(organization)
     assert expected == actual
@@ -1561,7 +1602,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = TargetHttpProxiesClient.common_project_path(project)
     assert expected == actual
@@ -1581,7 +1621,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1608,7 +1647,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.TargetHttpProxiesTransport, "_prep_wrapped_messages"
     ) as prep:
         client = TargetHttpProxiesClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1617,6 +1656,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = TargetHttpProxiesClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
