@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,61 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
+
 from requests import Response
 from requests.sessions import Session
 
-from google import auth
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.target_tcp_proxies import TargetTcpProxiesClient
 from google.cloud.compute_v1.services.target_tcp_proxies import pagers
 from google.cloud.compute_v1.services.target_tcp_proxies import transports
+from google.cloud.compute_v1.services.target_tcp_proxies.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.compute_v1.services.target_tcp_proxies.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.compute_v1.types import compute
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -86,31 +115,35 @@ def test__get_default_mtls_endpoint():
     )
 
 
-def test_target_tcp_proxies_client_from_service_account_info():
-    creds = credentials.AnonymousCredentials()
+@pytest.mark.parametrize("client_class", [TargetTcpProxiesClient,])
+def test_target_tcp_proxies_client_from_service_account_info(client_class):
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = TargetTcpProxiesClient.from_service_account_info(info)
+        client = client_class.from_service_account_info(info)
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
 
 @pytest.mark.parametrize("client_class", [TargetTcpProxiesClient,])
 def test_target_tcp_proxies_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         client = client_class.from_service_account_json("dummy/file/path.json")
         assert client.transport._credentials == creds
+        assert isinstance(client, client_class)
 
         assert client.transport._host == "compute.googleapis.com:443"
 
@@ -140,7 +173,7 @@ def test_target_tcp_proxies_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(TargetTcpProxiesClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -388,7 +421,7 @@ def test_delete_rest(
     transport: str = "rest", request_type=compute.DeleteTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -423,17 +456,16 @@ def test_delete_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.delete(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -467,7 +499,7 @@ def test_delete_rest_from_dict():
 
 
 def test_delete_rest_flattened():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -492,14 +524,12 @@ def test_delete_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "target_tcp_proxy_value" in http_call[1] + str(body)
 
 
 def test_delete_rest_flattened_error():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -515,7 +545,7 @@ def test_get_rest(
     transport: str = "rest", request_type=compute.GetTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -535,17 +565,16 @@ def test_get_rest(
             self_link="self_link_value",
             service="service_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.TargetTcpProxy.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.get(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.TargetTcpProxy)
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
@@ -562,7 +591,7 @@ def test_get_rest_from_dict():
 
 
 def test_get_rest_flattened():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -587,14 +616,12 @@ def test_get_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "target_tcp_proxy_value" in http_call[1] + str(body)
 
 
 def test_get_rest_flattened_error():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -610,7 +637,7 @@ def test_insert_rest(
     transport: str = "rest", request_type=compute.InsertTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -645,17 +672,16 @@ def test_insert_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.insert(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -689,7 +715,7 @@ def test_insert_rest_from_dict():
 
 
 def test_insert_rest_flattened():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -708,7 +734,6 @@ def test_insert_rest_flattened():
         target_tcp_proxy_resource = compute.TargetTcpProxy(
             creation_timestamp="creation_timestamp_value"
         )
-
         client.insert(
             project="project_value",
             target_tcp_proxy_resource=target_tcp_proxy_resource,
@@ -719,9 +744,7 @@ def test_insert_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert compute.TargetTcpProxy.to_json(
             target_tcp_proxy_resource,
             including_default_value_fields=False,
@@ -730,7 +753,7 @@ def test_insert_rest_flattened():
 
 
 def test_insert_rest_flattened_error():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -748,7 +771,7 @@ def test_list_rest(
     transport: str = "rest", request_type=compute.ListTargetTcpProxiesRequest
 ):
     client = TargetTcpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -768,17 +791,16 @@ def test_list_rest(
             self_link="self_link_value",
             warning=compute.Warning(code=compute.Warning.Code.CLEANUP_FAILED),
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.TargetTcpProxyList.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.list(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, pagers.ListPager)
     assert response.id == "id_value"
     assert response.items == [
@@ -795,7 +817,7 @@ def test_list_rest_from_dict():
 
 
 def test_list_rest_flattened():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -818,12 +840,11 @@ def test_list_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
 
 
 def test_list_rest_flattened_error():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -834,12 +855,11 @@ def test_list_rest_flattened_error():
 
 
 def test_list_pager():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
         # Set the response as a series of pages
-
         response = (
             compute.TargetTcpProxyList(
                 items=[
@@ -857,7 +877,6 @@ def test_list_pager():
                 items=[compute.TargetTcpProxy(), compute.TargetTcpProxy(),],
             ),
         )
-
         # Two responses for two calls
         response = response + response
 
@@ -876,7 +895,6 @@ def test_list_pager():
 
         results = list(pager)
         assert len(results) == 6
-
         assert all(isinstance(i, compute.TargetTcpProxy) for i in results)
 
         pages = list(client.list(request={}).pages)
@@ -888,7 +906,7 @@ def test_set_backend_service_rest(
     transport: str = "rest", request_type=compute.SetBackendServiceTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -923,17 +941,16 @@ def test_set_backend_service_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.set_backend_service(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -967,7 +984,7 @@ def test_set_backend_service_rest_from_dict():
 
 
 def test_set_backend_service_rest_flattened():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -986,7 +1003,6 @@ def test_set_backend_service_rest_flattened():
         target_tcp_proxies_set_backend_service_request_resource = compute.TargetTcpProxiesSetBackendServiceRequest(
             service="service_value"
         )
-
         client.set_backend_service(
             project="project_value",
             target_tcp_proxy="target_tcp_proxy_value",
@@ -998,11 +1014,8 @@ def test_set_backend_service_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "target_tcp_proxy_value" in http_call[1] + str(body)
-
         assert compute.TargetTcpProxiesSetBackendServiceRequest.to_json(
             target_tcp_proxies_set_backend_service_request_resource,
             including_default_value_fields=False,
@@ -1011,7 +1024,7 @@ def test_set_backend_service_rest_flattened():
 
 
 def test_set_backend_service_rest_flattened_error():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1030,7 +1043,7 @@ def test_set_proxy_header_rest(
     transport: str = "rest", request_type=compute.SetProxyHeaderTargetTcpProxyRequest
 ):
     client = TargetTcpProxiesClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1065,17 +1078,16 @@ def test_set_proxy_header_rest(
             warnings=[compute.Warnings(code=compute.Warnings.Code.CLEANUP_FAILED)],
             zone="zone_value",
         )
+
         # Wrap the value into a proper Response obj
         json_return_value = compute.Operation.to_json(return_value)
         response_value = Response()
         response_value.status_code = 200
         response_value._content = json_return_value.encode("UTF-8")
         req.return_value = response_value
-
         response = client.set_proxy_header(request)
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, compute.Operation)
     assert response.client_operation_id == "client_operation_id_value"
     assert response.creation_timestamp == "creation_timestamp_value"
@@ -1109,7 +1121,7 @@ def test_set_proxy_header_rest_from_dict():
 
 
 def test_set_proxy_header_rest_flattened():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the http request call within the method and fake a response.
     with mock.patch.object(Session, "request") as req:
@@ -1128,7 +1140,6 @@ def test_set_proxy_header_rest_flattened():
         target_tcp_proxies_set_proxy_header_request_resource = compute.TargetTcpProxiesSetProxyHeaderRequest(
             proxy_header=compute.TargetTcpProxiesSetProxyHeaderRequest.ProxyHeader.NONE
         )
-
         client.set_proxy_header(
             project="project_value",
             target_tcp_proxy="target_tcp_proxy_value",
@@ -1140,11 +1151,8 @@ def test_set_proxy_header_rest_flattened():
         assert len(req.mock_calls) == 1
         _, http_call, http_params = req.mock_calls[0]
         body = http_params.get("data")
-
         assert "project_value" in http_call[1] + str(body)
-
         assert "target_tcp_proxy_value" in http_call[1] + str(body)
-
         assert compute.TargetTcpProxiesSetProxyHeaderRequest.to_json(
             target_tcp_proxies_set_proxy_header_request_resource,
             including_default_value_fields=False,
@@ -1153,7 +1161,7 @@ def test_set_proxy_header_rest_flattened():
 
 
 def test_set_proxy_header_rest_flattened_error():
-    client = TargetTcpProxiesClient(credentials=credentials.AnonymousCredentials(),)
+    client = TargetTcpProxiesClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1171,16 +1179,16 @@ def test_set_proxy_header_rest_flattened_error():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.TargetTcpProxiesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = TargetTcpProxiesClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.TargetTcpProxiesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = TargetTcpProxiesClient(
@@ -1190,7 +1198,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.TargetTcpProxiesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = TargetTcpProxiesClient(
@@ -1201,7 +1209,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.TargetTcpProxiesRestTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = TargetTcpProxiesClient(transport=transport)
     assert client.transport is transport
@@ -1210,17 +1218,17 @@ def test_transport_instance():
 @pytest.mark.parametrize("transport_class", [transports.TargetTcpProxiesRestTransport,])
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_target_tcp_proxies_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.TargetTcpProxiesTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1232,7 +1240,7 @@ def test_target_tcp_proxies_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.TargetTcpProxiesTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1250,15 +1258,40 @@ def test_target_tcp_proxies_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_target_tcp_proxies_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.compute_v1.services.target_tcp_proxies.transports.TargetTcpProxiesTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.TargetTcpProxiesTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_target_tcp_proxies_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.compute_v1.services.target_tcp_proxies.transports.TargetTcpProxiesTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.TargetTcpProxiesTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1274,19 +1307,36 @@ def test_target_tcp_proxies_base_transport_with_credentials_file():
 
 def test_target_tcp_proxies_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.compute_v1.services.target_tcp_proxies.transports.TargetTcpProxiesTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.TargetTcpProxiesTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_target_tcp_proxies_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        TargetTcpProxiesClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/compute",
+                "https://www.googleapis.com/auth/cloud-platform",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_target_tcp_proxies_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         TargetTcpProxiesClient()
         adc.assert_called_once_with(
             scopes=(
@@ -1298,7 +1348,7 @@ def test_target_tcp_proxies_auth_adc():
 
 
 def test_target_tcp_proxies_http_transport_client_cert_source_for_mtls():
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
     with mock.patch(
         "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
     ) as mock_configure_mtls_channel:
@@ -1310,7 +1360,7 @@ def test_target_tcp_proxies_http_transport_client_cert_source_for_mtls():
 
 def test_target_tcp_proxies_host_no_port():
     client = TargetTcpProxiesClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com"
         ),
@@ -1320,7 +1370,7 @@ def test_target_tcp_proxies_host_no_port():
 
 def test_target_tcp_proxies_host_with_port():
     client = TargetTcpProxiesClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="compute.googleapis.com:8000"
         ),
@@ -1330,7 +1380,6 @@ def test_target_tcp_proxies_host_with_port():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1351,7 +1400,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = TargetTcpProxiesClient.common_folder_path(folder)
     assert expected == actual
@@ -1370,7 +1418,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = TargetTcpProxiesClient.common_organization_path(organization)
     assert expected == actual
@@ -1389,7 +1436,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = TargetTcpProxiesClient.common_project_path(project)
     assert expected == actual
@@ -1409,7 +1455,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1436,7 +1481,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.TargetTcpProxiesTransport, "_prep_wrapped_messages"
     ) as prep:
         client = TargetTcpProxiesClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1445,6 +1490,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = TargetTcpProxiesClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
